<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

require_once('settings/config.php');

define('IN_PHPBB', true);
$phpbb_root_path = './forum/';
$phpEx = substr(strrchr(__FILE__, '.'), 1);
require($phpbb_root_path . 'common.' . $phpEx);
require($phpbb_root_path . 'includes/functions_user.' . $phpEx);
require($phpbb_root_path . 'includes/functions_admin.' . $phpEx);
if (!class_exists('acp_forums'))
{
  global $phpbb_root_path, $phpEx;
  include($phpbb_root_path . 'includes/acp/acp_forums.' . $phpEx);
}
require($phpbb_root_path . 'includes/functions_module.' . $phpEx);


/**
* Checks whatever or not a variable is OK for use in the Database
* param mixed $value_ary An array of the form array(array('lang' => ..., 'value' => ..., 'column_type' =>))'
* param mixed $error The error array
*/
function validate_range($value_ary, &$error)
{
    global $user;
    
    $column_types = array(
        'BOOL'    => array('php_type' => 'int',         'min' => 0,                 'max' => 1),
        'USINT'    => array('php_type' => 'int',        'min' => 0,                 'max' => 65535),
        'UINT'    => array('php_type' => 'int',         'min' => 0,                 'max' => (int) 0x7fffffff),
        'INT'    => array('php_type' => 'int',         'min' => (int) 0x80000000,     'max' => (int) 0x7fffffff),
        'TINT'    => array('php_type' => 'int',        'min' => -128,                'max' => 127),
        
        'VCHAR'    => array('php_type' => 'string',     'min' => 0,                 'max' => 255),
    );
    foreach ($value_ary as $value)
    {
        $column = explode(':', $value['column_type']);
        $max = $min = 0;
        $type = 0;
        if (!isset($column_types[$column[0]]))
        {
            continue;
        }
        else
        {
            $type = $column_types[$column[0]];
        }

        switch ($type['php_type'])
        {
            case 'string' :
                $max = (isset($column[1])) ? min($column[1],$type['max']) : $type['max'];
                if (strlen($value['value']) > $max)
                {
                    $error[] = sprintf($user->lang['SETTING_TOO_LONG'], $user->lang[$value['lang']], $max);
                }
            break;

            case 'int': 
                $min = (isset($column[1])) ? max($column[1],$type['min']) : $type['min'];
                $max = (isset($column[2])) ? min($column[2],$type['max']) : $type['max'];
                if ($value['value'] < $min)
                {
                    $error[] = sprintf($user->lang['SETTING_TOO_LOW'], $user->lang[$value['lang']], $min);
                }
                else if ($value['value'] > $max)
                {
                    $error[] = sprintf($user->lang['SETTING_TOO_BIG'], $user->lang[$value['lang']], $max);
                }
            break;
        }
    }
}


/**
* Create a forum
*
* inspiration: http://www.phpbb.com/community/viewtopic.php?f=71&t=758985
*/
function create_forum($forum_perm_from = false)
{
   $forum_data = array(
      'parent_id'               => 0,
      'left_id'               => 0,
      'right_id'               => 0,
      'forum_parents'            => '',
      'forum_name'            => 'test',
      'forum_desc'            => '',
      'forum_desc_bitfield'      => '',
      'forum_desc_options'      => 7,
      'forum_desc_uid'         => '',
      'forum_link'            => '',
      'forum_password'         => '',
      'forum_style'            => 0,
      'forum_image'            => '',
      'forum_rules'            => '',
      'forum_rules_link'         => '',
      'forum_rules_bitfield'      => '',
      'forum_rules_options'      => 7,
      'forum_rules_uid'         => '',
      'forum_topics_per_page'      => 0,
      'forum_type'            => 1,
      'forum_status'            => 0,
      'forum_posts'            => 0,
      'forum_topics'            => 0,
      'forum_topics_real'         => 0,
      'forum_last_post_id'      => 0,
      'forum_last_poster_id'      => 0,
      'forum_last_post_subject'   => '',
      'forum_last_post_time'      => 0,
      'forum_last_poster_name'   => '',
      'forum_last_poster_colour'   => '',
      'forum_flags'            => 32,
      'display_on_index'         => false,
      'enable_indexing'         => true,
      'enable_icons'            => false,
      'enable_prune'            => false,
      'prune_next'            => 0,
      'prune_days'            => 7,
      'prune_viewed'            => 7,
      'prune_freq'            => 1,
   );

   $forums_admin = new acp_forums();
   $forums_admin->update_forum_data($forum_data);

   if ($forum_perm_from)
   {
      global $auth, $db;

      $auth->acl_clear_prefetch();

      $users_sql_ary = $groups_sql_ary = array();

      // Copy permisisons from/to the acl users table (only forum_id gets changed)
      $sql = 'SELECT user_id, auth_option_id, auth_role_id, auth_setting
         FROM ' . ACL_USERS_TABLE . '
         WHERE forum_id = ' . $forum_perm_from;
      $result = $db->sql_query($sql);
      while ($row = $db->sql_fetchrow($result))
      {
         $users_sql_ary[] = array(
            'user_id'         => (int) $row['user_id'],
            'forum_id'         => (int) $forum_data['forum_id'],
            'auth_option_id'   => (int) $row['auth_option_id'],
            'auth_role_id'      => (int) $row['auth_role_id'],
            'auth_setting'      => (int) $row['auth_setting'],
         );
      }
      $db->sql_freeresult($result);

      // Copy permisisons from/to the acl groups table (only forum_id gets changed)
      $sql = 'SELECT group_id, auth_option_id, auth_role_id, auth_setting
         FROM ' . ACL_GROUPS_TABLE . '
         WHERE forum_id = ' . $forum_perm_from;
      $result = $db->sql_query($sql);
      while ($row = $db->sql_fetchrow($result))
      {
         $groups_sql_ary[] = array(
            'group_id'         => (int) $row['group_id'],
            'forum_id'         => (int) $forum_data['forum_id'],
            'auth_option_id'   => (int) $row['auth_option_id'],
            'auth_role_id'      => (int) $row['auth_role_id'],
            'auth_setting'      => (int) $row['auth_setting']
         );
      }
      $db->sql_freeresult($result);

      // Now insert the data
      $db->sql_multi_insert(ACL_USERS_TABLE, $users_sql_ary);
      $db->sql_multi_insert(ACL_GROUPS_TABLE, $groups_sql_ary);
      cache_moderators();
   }
}

create_forum(4);
    
exit('Done, Sir.');