<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class BlogEntry extends Entity
{
	public $BlogEntryID			= -1;
	public $UserID				= -1;
	public $BlogEntrySubject	= '';
	public $BlogEntryMessage	= '';
	public $BlogEntryKeywords	= '';
	public $BlogEntryDate		= '';
	public $OnlyMyFlag			= 0;


	public function saveToDB()
	{
		if ($this->BlogEntryID == -1)
		{
			$this->BlogEntryDate = CURRENT_TIME;
		}
		parent::saveToDB();
	}

    public function populateFromArray($data)
    {
        parent::populateFromArray($data);
        $this->BlogEntryMessage = html_entity_decode($this->BlogEntryMessage);
    }

	public function getUser()
	{
		return new User($this->UserID);
	}

	public function getComments()
	{
		return BlogComment::getBlogEntryComments($this->BlogEntryID);
	}

	public static function getUserBlogEntries($userID)
	{
		$return = array();

		$db = DBConnect::getInstance();
		$result = $db->query('select * from blogentry where UserID = %d ORDER BY BlogEntryDate DESC', $userID);
		foreach ($result->Data as $row)
		{
			$blogEntry = new BlogEntry();
			$blogEntry->populateFromArray($row);
			$return[] = $blogEntry;
		}
		return $return;
	}

	public static function getUserBlogEntryCount($userID)
	{
		$db = DBConnect::getInstance();
		$result = $db->query('select count(*) as cnt from blogentry where UserID = %d group by UserID', $userID);
		return $result->Data[0]['cnt'];
	}

	public static function getAllBlogEntriesCount()
    {
        $db = DBConnect::getInstance();
        $result = $db->query('SELECT COUNT(*) AS cnt FROM `blogentry`');
        return $result->Data[0]['cnt'];
    }

    public function getTags()
    {
    	return Tag::getTags(TAG_TYPE_BLOG_ENTRY, $this->BlogEntryID);
    }

	public static function getUsersWithBlogs()
	{
		$return = array();

		$db = DBConnect::getInstance();
		$result = $db->query('select u.* from blogentry e inner join user u on u.UserID = e.UserID');
		foreach ($result->Data as $row)
		{
			$user = new User();
			$user->populateFromArray($row);
			$return[] = $user;
		}
		return $return;
	}

	public function userIsAllowedToReadEntry($user_id)
	{
		if ($user_id == $this->UserID)
		{
			return true;
		}
		else
		{
			$entry_id = $this->BlogEntryID;
			$db = DBConnect::getInstance();

			$rs = $db->query("SELECT OnlyMyFlag FROM `blogentry` WHERE BlogEntryID=%d", $entry_id);
			if ($rs->Data[0]['OnlyMyFlag'] == 0)
			{
				return true;
			}

			$rs = $db->query("SELECT COUNT(*) AS cnt FROM `blogentryprivacyconnection` WHERE BlogEntryID=%d", $entry_id);
			if ($rs->Data[0]['cnt'] == 0)
			{
				return false;
			}

			$rs = $db->query("
				SELECT count(*) as cnt FROM `blogentryprivacyconnection` AS bepc
				left JOIN `connection` AS c ON c.GroupID = bepc.GroupID AND bepc.GroupID <> -1 and c.UserID=%d and
				(c.ConnectionType = %d or c.ConnectionType = %d or c.ConnectionType = %d)
				WHERE bepc.BlogEntryID=%d and (bepc.UserID=%d or c.ConnectionID is not null and PrivacyFlag = %d)
				group by bepc.BlogEntryID",
				$user_id, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_MEMBER,
				$entry_id, $user_id, PRIVACY_FLAG_BLOGENTRY_SET);

			if ($rs->Data[0]['cnt'] > 0)
			{
				return true;
			}
			return false;
		}
	}

	public static function removeAllPrivacyConnectionsOfThisEntry($entry_id)
	{
		$db = DBConnect::getInstance();
		$db->delete('blogentryprivacyconnection', 'BlogEntryID=%d', $entry_id);
	}

	public static function togglePrivacyFlagState($entry_id, $state)
	{
		$db = DBConnect::getInstance();
		$db->update('blogentry', array('OnlyMyFlag' => $state), 'BlogEntryID=%d', $entry_id);
	}

	public static function allowGroupMembersToReadThisEntry($group_id, $entry_id)
	{
		$db = DBConnect::getInstance();
		$db->insert('blogentryprivacyconnection', array('BlogEntryID' => $entry_id, 'UserID' => -1, 'GroupID' => $group_id, 'PrivacyFlag' => PRIVACY_FLAG_BLOGENTRY_SET));
	}

	public static function allowUserToReadThisEntry($user_id, $entry_id)
	{
		$db = DBConnect::getInstance();
		$db->insert('blogentryprivacyconnection', array('BlogEntryID' => $entry_id, 'UserID' => $user_id, 'GroupID' => -1, 'PrivacyFlag' => PRIVACY_FLAG_BLOGENTRY_SET));
	}
}