<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 

class Community extends ConnectionEntity
{
	public $CommunityID 		 = -1;
	public $CommunityName 	     = "";
    public $CommunityKeywords    = "";
    public $CommunityPicture     = "";
    public $CommunityDescription = "";
    public $CommunityCreated	 = '';
    public $CommunityUpdated	 = '';
    public $CommunityPageEdits	 = 0;
    public $CommunityForumID	 = -1;


    public function __construct($entity_id = -1)
    {
    	parent::__construct($entity_id);
    	foreach ($this as $field_id => $field)
    	{
    		if (is_string($field))
    		{
    			$this->{$field_id} = html_entity_decode($field);
    		}
    	}
    }

	public function isJoinRequested()
    {
    	return false;
    }

	public function getConnections($where = array(), $order = array(), $limit = 0)
	{
		$where['CommunityID'] = $this->CommunityID;
		return Connection::getConnections($where, $order, $limit);
    }

	public function getNewFilesCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT COUNT(SharedFileID) AS sf FROM `sharedfile` WHERE (CommunityID = %s) AND (DATEDIFF(CURDATE(), Updated) <= %d)", $this->CommunityID, PROFILE_UPDATE_PERIOD);
		return $query->Data['0']['sf'];
	}

	public function getSharedFiles($maxcount = '')
	{
		$shared_files = SharedFile::getCommunityFiles($this->CommunityID);
		if (!empty($maxcount))
		{
			$shared_files = array_slice($shared_files, 0, $maxcount);
		}

		return $shared_files;
	}

	public function removeMember($userID)
    {
        $connections = Connection::getConnections(array(
            'ConnectionType' => array(CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER),
            'UserID' => $userID, 'CommunityID' => $this->CommunityID));

        foreach ($connections as $connection)
        {
            $connection->delete();
        }
    }

    public function checkCalendarPrivacy()
    {
        return true;
	}

    public function isPublic()
    {
        return true;
	}

    public function saveToDB()
	{
		$this->CommunityUpdated = 'now()';
		$this->CommunityPageEdits = $this->CommunityPageEdits ? ++$this->CommunityPageEdits : 1;
		parent::saveToDB();
	}

    public function userIsAdmin($userID)
    {
        return true;
	}

	public function getEvents()
	{
		return Event::getCommunityEvents($this->CommunityID);
	}


    public static function getByCommunityName($name)
	{
		$obj = new Community();

		if ($name != '')
		{
			$db = DBConnect::getInstance();
			$res = $db->query('SELECT * FROM community WHERE CommunityName = %s', $name);

			if ($res->Size > 0)
			{
				$obj->populateFromArray($res->Data[0]);
			}
		}

		return $obj;
	}

	public function hasMember($userID)
    {
    	$connections = Connection::getConnections(array('ConnectionType' => array(CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER),
    		'UserID' => $userID, 'CommunityID' => $this->CommunityID));
    	return (count($connections) > 0);
    }

    public function isOwner($userID)
    {
    	return ($this->getOwnerID() == $userID) || User::checkEmployer($userID);
    }

    public function getOwnerID()
	{
        $cons = Connection::getConnections(array('CommunityID' => $this->CommunityID, 'ConnectionType' => CONNECTIONTYPE_OWNER));
       	return $cons[0]->UserID;
	}

	public static function search($name, $keyword)
	{
		$return = array();
		$db = DBConnect::getInstance();
		$res = $db->query('select * from community where CommunityName like %s and CommunityKeywords like %s', '%' . $name . '%', '%' . $keyword . '%');
		foreach ($res->Data as $row)
		{
			$object = new Community();
			$object->populateFromArray($row);
			$return[] = $object;
		}
		return $return;
	}

	public function getCommunityMembersCount()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("select count(ConnectionID) as cc from `connection` where (UserID <> '-1') and (CommunityID = %d)", $this->CommunityID);
		return $query->Data['0']['cc'];
	}

    public function getMembers()
    {
    	return $this->getCommunityMembers();
    }

	public function getCommunityMembers()
	{
		$db = DBConnect::getInstance();
		$result = $db->query("SELECT u.* FROM `connection` c inner join user u on c.UserID = u.UserID where (c.CommunityID = %s and c.ConnectionType in (%d, %d, %d))", $this->CommunityID, CONNECTIONTYPE_OWNER, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_ADMIN);
		$return = array();
		foreach ($result->Data as $row)
		{
			$user = new User();
			$user->populateFromArray($row);
			$return[] = $user;
		}
		return $return;
	}

	public function getCommunityPageEditsRank()
	{
		$db = DBConnect::getInstance();
		$query = $db->query("SELECT (%d / COUNT(CommunityPageEdits) * 100) AS rank FROM `community`", $this->CommunityPageEdits);
		return sprintf("%d", $query->Data[0]['rank']);
	}

	public static function getUserCommunities($userID, $owneronly = false)
    {
    	$db = DBConnect::getInstance();
    	if ($owneronly)
    	{
    		$result = $db->query('SELECT cm.* FROM `connection` AS cn INNER JOIN `community` AS cm ON cm.CommunityID = cn.CommunityID ' .
    			'WHERE cn.UserID = %d AND cn.CommunityID IS NOT NULL AND (cn.ConnectionType = %d or cn.ConnectionType = %d)',
    			$userID, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_OWNER);
		}
		else
		{
    		$result = $db->query('SELECT cm.* FROM `connection` AS cn INNER JOIN `community` AS cm ON cm.CommunityID = cn.CommunityID ' .
    			'WHERE cn.UserID = %d AND cn.CommunityID IS NOT NULL AND (cn.ConnectionType = %d OR cn.ConnectionType = %d OR cn.ConnectionType = %d)',
    			$userID, CONNECTIONTYPE_ADMIN, CONNECTIONTYPE_MEMBER, CONNECTIONTYPE_OWNER);
		}
    	$return = array();

    	foreach ($result->Data as $row)
    	{
    		$com = new Community();
    		$com->populateFromArray($row);
    		$return[] = $com;
    	}
    	return $return;
    }

	public function hasOrganization($orgID)
	{
		$return = false;
		$org = new Organization($orgID);
		if ($org->OrganizationID != -1)
		{
			$return = $org->hasCommunity($this->CommunityID);
		}
		return $return;
	}

	public function hasGroup($groupID)
	{
		$return = false;
		$group = new Group($groupID);
		if ($group->GroupID != -1)
		{
			$return = $group->hasCommunity($this->CommunityID);
		}
		return $return;
	}


    public function addMember($userID)
    {
		if (!$this->hasMember($userID))
		{
			$member = new User($userID);
			if ($member->UserID != -1)
			{
				$connection = new Connection(-1);
   				$connection->UserID = $userID;
		        $connection->CommunityID = $this->CommunityID;
		        $connection->ConnectionType = CONNECTIONTYPE_MEMBER;
		        $connection->saveToDB();
			}
		}
    }

    public function getOwner()
    {
    	$cons = Connection::getConnections(array('CommunityID' => $this->CommunityID, 'ConnectionType' => CONNECTIONTYPE_OWNER));
        if ($cons[0]->UserID != -1)
        {
        	return new User($cons[0]->UserID);
		}
		return new User(-1);
    }

    public function getOwnerConnection()
    {
        $cons = Connection::getConnections(array('CommunityID' => $this->CommunityID, 'ConnectionType' => CONNECTIONTYPE_OWNER));
        return $cons[0];
    }

    public function setOwner($ownerid)
    {
        $connections = Connection::getConnections(array('UserID' => $ownerid, 'CommunityID' => $this->CommunityID));
        $connection = count($connections) ? $connections[0] : new Connection();
        $connection->UserID = $ownerid;
        $connection->CommunityID = $this->CommunityID;
        $connection->ConnectionType = CONNECTIONTYPE_OWNER;
        $connection->saveToDB();
    }

	public function getCommunityPhotos($maxcount = 6)
	{
		$db = DBConnect::getInstance();
		$query = $db->query("select p.PhotoID, p.AlbumID, p.PhotoName, p.PhotoPath, p.PhotoStatus, p.PhotoIsCover FROM photo p INNER JOIN album a ON (a.AlbumID = p.AlbumID) AND (a.CommunityID = %s) ORDER BY PhotoID DESC limit $maxcount", $this->CommunityID);

		$return = array();
		foreach ($query->Data as $row)
		{
			$photo = new Photo();
			$photo->populateFromArray($row);
			$return[] = $photo;
		}
		return $return;
	}

	public function getPhotos($maxcount = 6)
	{
		return $this->getCommunityPhotos($maxcount);
	}

	public function getCommunityVideos($maxcount = 6)
	{
		$return = array();

		$db = DBConnect::getInstance();
		$result = $db->query('select v.* from video as v inner join `videoalbum` as a on a.VideoAlbumID = v.VideoAlbumID and a.CommunityID = %d order by `VideoID` limit ' . $maxcount, $this->CommunityID);

		foreach ($result->Data as $row)
		{
			$video = new Video();
			$video->populateFromArray($row);

			$return[] = $video;
		}

		return $return;
	}

	public function getVideos($maxcount = 6)
	{
		return $this->getCommunityVideos($maxcount);
	}

	public function getCommunityFiles($maxcount = 6)
	{
		$return = array();

		$db = DBConnect::getInstance();
		$result = $db->query('select * from file where CommunityID = %d order by `FileID` limit ' . $maxcount, $this->GroupID);

		foreach ($result->Data as $row)
		{
			$file = new File();
			$file->populateFromArray($row);

			$return[] = $file;
		}

		return $return;
	}

	public function getCommunityNews()
	{
		return News::getCommunityNews($this->CommunityID);
	}

	public function getCommunityNewsDrafts()
	{
		return News::getCommunityNewsDrafts($this->CommunityID);
	}

	public function deleteNews($news_id)
	{
		global $user;

        if ($this->hasMember($user->UserID))
        {
	        $news = new News($news_id);
			$news->deleteNews();
		}
	}

	public function getName()
	{
		return $this->CommunityName;
	}
}