<?php
/*
NetworX - open-source social networks platform
Copyright (C) 2009 SocialABC, Inc. http://www.socialabc.com
This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with this program in a file called LICENSE; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
*/ 


function io_get_string($name, $method = 'get', $required = false)
{
	$method = strtoupper($method);
	if (!in_array($method, array('GET', 'POST', 'REQUEST', 'COOKIES')))
	{
		throw new IOMethodException("Unknown request method '" . $method . "'");
	}
	$source =& $GLOBALS["_" . $method];
	if (isset($source[$name]))
	{
		$result = $source[$name];
	}
	else
	{
		$args = func_get_args();
		if (count($args) > 3)
		{
			$result = $args[3];
		}
		else
		{
			if ($required)
			{
				throw new IORequestParameterException("Parameter '$name' not found");
			}
			else
			{
				$result = null;
			}
		}
	}
	if (!is_null($result))
	{
		$result = strval($result);
	}
	return $result;
}

function io_get_int($name, $method = 'get', $required = false, $default = 0)
{
	$result = io_get_string($name, $method, $required, $default);
	if (!is_numeric($result))
	{
		$result = $default;
	}
	return intval($result);
}

function io_get_bool($name, $method = 'get', $required = false, $default = false)
{
	$result = (boolean)io_get_string($name, $method, $required, $default);
	return $result;
}

function io_get_float($name, $method = 'get', $required = false, $default = 0.0)
{
	$result = io_get_string($name, $method, $required, $default);
	if (!is_numeric($result))
	{
		$result = $default;
	}
	return floatval($result);
}

function io_array($name, $method = 'get')
{
	$method = strtoupper($method);
	if (!in_array($method, array('GET', 'POST', 'REQUEST', 'COOKIES')))
	{
		throw new IOMethodException("Unknown request method '" . $method . "'");
	}
	$source =& $GLOBALS["_" . $method];
	$result = isset($source[$name]) ? $source[$name] : array();
	return $result;
}

function io_file($name)
{
	$result = null;
	if (isset($_FILES[$name]))
	{
		if (is_array($_FILES[$name]['name']))
		{
			$result = array();
			for ($i = 0; $i < count($_FILES[$name]['name']); $i++)
			{
				if ($_FILES[$name]['error'][$i] === UPLOAD_ERR_OK)
				{
					$result[] = new UploadedFileInfo($_FILES[$name]['name'][$i],
							$_FILES[$name]['type'][$i],
							$_FILES[$name]['tmp_name'][$i],
							$_FILES[$name]['size'][$i],
							$_FILES[$name]['error'][$i]);
				}
			}
		}
		else
		{
			if ($_FILES[$name]['error'][$i] === UPLOAD_ERR_OK)
			{
				$result[] = new UploadedFileInfo($_FILES[$name]['name'][$i],
						$_FILES[$name]['type'][$i],
						$_FILES[$name]['tmp_name'][$i],
						$_FILES[$name]['size'][$i],
						$_FILES[$name]['error'][$i]);
			}
		}
	}
	return $result;
}

// -------------------------------------------------------------------------------------------------
// Validator-functions
//
// Function name/signature format:
// iov_<type>_<v_name>($name, $method = 'get'[, v_arg1[, v_arg2[,...]]])
//
// <type> stands for user supplied parameter type (integer | string | boolean | float | array);
// <v_name> - name of your validator;
// <v_argN> - validator specific arguments.
//
//
// Return value:
// true, if validation succeedes, or false, otherwise
//
// Errors:
// In case of incorrect validator parameters values IOIncorrectValidatorException must be thrown.
//
// -------------------------------------------------------------------------------------------------

function iov_string_length($name, $method = 'get', $min_length = 0, $max_length = 0)
{
	$result = true;
	if (!is_integer($min_length) || !is_integer($max_length))
	{
		throw new IOIncorrectValidatorException("Min and max length limits must be integers");
	}
	if ($max_length != 0 && $min_length > $max_length)
	{
		throw new IOIncorrectValidatorException("Min length limit cannot be greater than max limit");
	}
	$value = io_get_string($name, $method);
	$length = strlen($value);
	if ($length < $min_length || ($max_length != 0 && $length > $max_length))
	{
		$result = false;
	}
	return $result;
}

function iov_string_pattern($name, $method = 'get', $pattern = '^(.+)$')
{
	if (empty($pattern))
	{
		throw new IOIncorrectValidatorException("Pattern is empty");
	}
	$value = io_get_string($name, $method);
	$result = preg_match('/' . $pattern . '/', $value) > 0;
	return $result;
}