DROP TABLE IF EXISTS `program`;
CREATE TABLE `program` (
  `ProgramID` int(11) NOT NULL auto_increment,
  `ProgramName` varchar(32) NOT NULL,
  `ProgramStatus` smallint(6) default '0',
  `ProgramDateCreated` datetime NOT NULL,
  `ProgramShortDescription` varchar(128) NULL,
  `ProgramDateNeeded` datetime NULL,
  `ProgramAmountNeeded` float unsigned NOT NULL default '0',
  `ProgramReceiptTemplate` text,
  PRIMARY KEY  (`ProgramID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
insert into `program` (ProgramID, ProgramName, ProgramStatus, ProgramDateCreated) VALUES (1, 'Organization', 3, now());

DROP TABLE IF EXISTS `order`;
CREATE TABLE `order` (
  `OrderID` int(11) NOT NULL auto_increment,
  `UserID` int(11) NOT NULL,
  `ProgramID` int(11) default NULL,
  `OrderDate` datetime NOT NULL,
  `OrderTotal` float unsigned NOT NULL default '0',
  `OrderStatus` smallint(6) default NULL,
  `OrderBillingFirstName` varchar(32) default NULL,
  `OrderBillingLastName` varchar(32) default NULL,
  `OrderBillingAddress1` varchar(32) default NULL,
  `OrderBillingAddress2` varchar(32) default NULL,
  `OrderBillingCity` varchar(32) default NULL,
  `OrderBillingState` varchar(2) default NULL,
  `OrderBillingCountry` varchar(2) default NULL,
  `OrderBillingZip` varchar(16) default NULL,
  `OrderBillingPhone` varchar(16) default NULL,
  `OrderPaymentType` smallint(6) default NULL,
  `OrderPaymentCC` varchar(32) default NULL,
  `OrderPaymentCVV` varchar(16) default NULL,
  `OrderPaymentCCType` smallint(6) default NULL,
  `OrderPaymentCCName` varchar(32) default NULL,
  `OrderPaymentCCExpMonth` int(11) default NULL,
  `OrderPaymentCCExpYear` int(11) default NULL,
  `OrderPaymentCheck` varchar(32) default NULL,
  `OrderPaymentCheckName` varchar(32) default NULL,
  `OrderPaymentCheckRouting` varchar(32) default NULL,
  `OrderPaymentCheckAccount` varchar(32) default NULL,
  `OrderPaypalID` varchar(17) default NULL,
  PRIMARY KEY  (`OrderID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `additionalstorage`;
CREATE TABLE `additionalstorage` (
  `AdditionalStorageID` int(11) NOT NULL auto_increment,
  `ProductID` int(11) NOT NULL default '0',
  `AdditionalStorageSize` varchar(16) default NULL,
  `AdditionalStoragePrice` float unsigned NOT NULL default '0',
  `AdditionalStoragePeriod` int(11) NOT NULL default '0',
  PRIMARY KEY  (`AdditionalStorageID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `sentinvitation`;
CREATE TABLE `sentinvitation` (
  `SentInvitationID` int(11) NOT NULL auto_increment,
  `UserID` int(11) default NULL,
  `GroupID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `SentInvitationEmail` varchar(255) default NULL,
  PRIMARY KEY  (`SentInvitationID`),
  UNIQUE KEY `UserID` (`UserID`,`SentInvitationEmail`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `complaint`;
CREATE TABLE `complaint` (
  `ComplaintID` int(11) NOT NULL auto_increment,
  `UserID` int(11) NOT NULL default '0',
  `ToUserID` int(11) default NULL,
  `ComplaintSourceID` int(11) NOT NULL default '0',
  `ComplaintSource` int(11) NOT NULL default '0',
  `ComplaintMessage` text,
  `ComplaintStatus` int(11) NOT NULL default '0',
  `ComplaintComments` text,
  PRIMARY KEY  (`ComplaintID`),
  KEY `FK_ComplaintToUser` (`UserID`),
  KEY `FK_ComplaintToEmployer` (`ToUserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `album`;
CREATE TABLE IF NOT EXISTS `album` (
  `AlbumID` int(11) NOT NULL auto_increment,
  `GroupID` int(11) default NULL,
  `UserID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `CommunityID` int(11) default NULL,
  `AlbumName` varchar(128) NOT NULL default '',
  `AlbumDescription` varchar(255) default NULL,
  `AlbumPrivacy` int(11) default NULL,
  PRIMARY KEY  (`AlbumID`),
  KEY `FK_AlbumToGroup` (`GroupID`),
  KEY `FK_AlbumToOrganization` (`OrganizationID`),
  KEY `FK_ComminutyToAlbum` (`CommunityID`),
  KEY `FK_UserToAlbum` (`UserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `albumprivacyconnection`;
CREATE TABLE `albumprivacyconnection` (
  `AlbumID` int(11) NOT NULL default '0',
  `UserID` int(11) NOT NULL default '-1',
  `GroupID` int(11) NOT NULL default '-1',
  `OrganizationID` int(11) NOT NULL default '-1',
  `CommunityID` int(11) NOT NULL default '-1',
  `PrivacyFlag` tinyint NOT NULL default '0',
  KEY `FK_AlbumToUser` (`UserID`),
  KEY `FK_AlbumToGroup` (`GroupID`),
  KEY `FK_AlbumToOrganization` (`OrganizationID`),
  KEY `FK_AlbumToCommunity` (`CommunityID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `blogcomment`;
CREATE TABLE `blogcomment` (
  `BlogCommentID` int(11) NOT NULL auto_increment,
  `BlogEntryID` int(11) NOT NULL default '0',
  `UserID` int(11) NOT NULL default '0',
  `BlogCommentDate` datetime NOT NULL,
  `BlogCommentMessage` text NOT NULL,
  PRIMARY KEY  (`BlogCommentID`),
  KEY `FK_BlogCommentToUser` (`UserID`),
  KEY `FK_BlogCommentToBlogEntry` (`BlogEntryID`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `blogentry`;
CREATE TABLE `blogentry` (
  `BlogEntryID` int(11) NOT NULL auto_increment,
  `UserID` int(11) NOT NULL default '0',
  `BlogEntrySubject` varchar(255) NOT NULL,
  `BlogEntryMessage` text,
  `BlogEntryKeywords` varchar(255) default NULL,
  `BlogEntryDate` date NOT NULL,
  `OnlyMyFlag` tinyint(1) NOT NULL default '0',
  PRIMARY KEY  (`BlogEntryID`),
  KEY `FK_BlogEntyToUser` (`UserID`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `blogentryprivacyconnection`;
CREATE TABLE `blogentryprivacyconnection` (
  `BlogEntryID` int(11) NOT NULL default '0',
  `UserID` int(11) NOT NULL default '0',
  `GroupID` int(11) NOT NULL default '0',
  `PrivacyFlag` tinyint NOT NULL,
  KEY `FK_BlogEntyToUser` (`UserID`),
  KEY `FK_BlogEntyToGroup` (`GroupID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `campaign`;
CREATE TABLE `campaign` (
  `CampaignID` int(11) NOT NULL auto_increment,
  `AdAccountID` int(11) NOT NULL,
  `CampaignName` varchar(128) NOT NULL,
  `CampaignNumber` varchar(16) NOT NULL,
  `CampaignStartDate` date NOT NULL,
  `CampaignEndDate` date NOT NULL,
  `CampaignBudget` decimal(10,2) NOT NULL,
  `CampaignContactName` varchar(32) default NULL,
  `CampaignContactAddress1` varchar(32) default NULL,
  `CampaignContactAddress2` varchar(32) default NULL,
  `CampaignContactCity` varchar(32) default NULL,
  `CampaignContactState` varchar(2) default NULL,
  `CampaignContactCountry` varchar(2) default NULL,
  `CampaignContactZip` varchar(16) default NULL,
  `CampaignContactPhone` varchar(16) default NULL,
  `CampaignContactEmail` varchar(128) default NULL,
  PRIMARY KEY  (`CampaignID`),
  KEY `FK_AdAccountToCampaign` (`AdAccountID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


#
# Table structure for certificate status
#

DROP TABLE IF EXISTS `certificate`;
CREATE TABLE `certificate` (
  `CertificateID` int(11) NOT NULL auto_increment,
  `FromUserID` int(11) NOT NULL default '-1',
  `FromGroupID` int(11) NOT NULL default '-1',
  `FromOrganizationID` int(11) NOT NULL default '-1',
  `ToUserID` int(11) NOT NULL default '-1',
  `ToGroupID` int(11) NOT NULL default '-1',
  `ToOrganizationID` int(11) NOT NULL default '-1',
  `CertificateStatus` int(11) NOT NULL default '0',  
  `CertificateUpdated` timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,  
PRIMARY KEY (`CertificateID`)
) ENGINE=InnoDB;


#
# Table structure for table comment
#

DROP TABLE IF EXISTS `comment`;
CREATE TABLE `comment` (
  `CommentID` int(11) NOT NULL auto_increment,
  `ProductID` int(11) default NULL,
  `MarketID` int(11) default NULL,
  `UserID` int(11) NOT NULL,
  `PhotoID` int(11) default NULL,
  `VideoID` int(11) default NULL,
  `CommentType` smallint(6) NOT NULL,
  `CommentText` text NOT NULL,
  `CommentDate` datetime NOT NULL,
  PRIMARY KEY  (`CommentID`),
  KEY `FK_ProductToComment` (`ProductID`),
  KEY `FK_SellerToComment` (`MarketID`),
  KEY `FK_UserToComment` (`UserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

#
# Dumping data for table comment
#


#
# Table structure for table community
#

DROP TABLE IF EXISTS `community`;
CREATE TABLE `community` (
  `CommunityID` int(11) NOT NULL auto_increment,
  `CommunityName` varchar(128) NOT NULL,
  `CommunityKeywords` varchar(255) default NULL,
  `CommunityPicture` varchar(255) default NULL,
  `CommunityDescription` varchar(750),
  `CommunityCreated` timestamp NOT NULL default CURRENT_TIMESTAMP,
  `CommunityUpdated` timestamp NULL default '0000-00-00 00:00:00',
  `CommunityPageEdits` int(11),
  `CommunityForumID` int(11),
  PRIMARY KEY  (`CommunityID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `company`;
CREATE TABLE `company` (
  `CompanyID` int(11) NOT NULL auto_increment,
  `UserID` int(11) NOT NULL,
  `CompanyName` varchar(128) NOT NULL,
  `CompanyUserTitle` varchar(128) NOT NULL,
  `CompanyStartDate` date NOT NULL,
  `CompanyEndDate` date default NULL,
  `CompanyDescription` varchar(255) default NULL,
  PRIMARY KEY  (`CompanyID`),
  KEY `FK_CompanyToUser` (`UserID`)
) ENGINE=InnoDB;


#
# Table structure for table complaint
#

DROP TABLE IF EXISTS `complaint`;
CREATE TABLE `complaint` (
  `ComplaintID` int(11) NOT NULL auto_increment,
  `UserID` int(11) NOT NULL default '0',
  `ToUserID` int(11) default NULL,
  `ComplaintSourceID` int(11) NOT NULL default '0',
  `ComplaintSource` int(11) NOT NULL default '0',
  `ComplaintMessage` text,
  `ComplaintStatus` int(11) NOT NULL default '0',
  `ComplaintComments` text,
  PRIMARY KEY  (`ComplaintID`),
  KEY `FK_ComplaintToUser` (`UserID`),
  KEY `FK_ComplaintToEmployer` (`ToUserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

#
# Dumping data for table complaint
#


#
# Table structure for table connection
#

DROP TABLE IF EXISTS `connection`;
CREATE TABLE `connection` (
  `ConnectionID` int(11) NOT NULL auto_increment,
  `CommunityID` int(11) default NULL,
  `ToCommunityID` int(11) default NULL,
  `AlbumID` int(11) default NULL,            
  `VideoAlbumID` int(11) default NULL,              
  `UserID` int(11) default NULL,
  `ToUserID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `ToOrganizationID` int(11) default NULL,
  `GroupID` int(11) default NULL,
  `ToGroupID` int(11) default NULL,
  `ConnectionType` smallint(6) NOT NULL,
  `UserStatus` tinyint(4) default '1',
  `Flags` bigint(20) NOT NULL,
  `PrivacyFlags` bigint(20) NOT NULL default '0',
  `Created` timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (`ConnectionID`),
  KEY `FK_AlbumToConnection` (`AlbumID`),
  KEY `FK_VideoAlbumToConnection` (`VideoAlbumID`),  
  KEY `FK_CommunityToConnection` (`CommunityID`),
  KEY `FK_ConnectionToUser` (`UserID`),
  KEY `FK_GroupToConnection` (`GroupID`),
  KEY `FK_OrganizationToConnection` (`OrganizationID`),
  KEY `FK_UserToConnection` (`ToUserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

#
# Table structure for table country
#

DROP TABLE IF EXISTS `country`;
CREATE TABLE `country` (
  `CountryID` int(11) NOT NULL auto_increment,
  `CountryName` varchar(255) default NULL,
  `CountryCode` varchar(2) default NULL,
  PRIMARY KEY  (`CountryID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

#
# Dumping data for table country
#



#
# Table structure for table event
#

DROP TABLE IF EXISTS `event`;
CREATE TABLE `event` (
  `EventID` int(11) NOT NULL auto_increment,
  `OrganizationID` int(11) default NULL,
  `UserID` int(11) default NULL,
  `CommunityID` int(11) default NULL,
  `GroupID` int(11) default NULL,
  `EventName` varchar(255) default NULL,
  `EventDescription` text,
  `EventStartDate` datetime NOT NULL,
  `EventEndDate` datetime default NULL,
  `EventType` smallint(6),
  `EventSubType` varchar(64),  
  `EventReminder` smallint(6),
  `EventReminderType` smallint(6),
  `EventAvailability` smallint(6),
  `EventCost` decimal(10,2) default NULL,
  `EventPicture1` varchar(128) default NULL,
  `EventPicture2` varchar(128) default NULL,
  `EventPicture3` varchar(128) default NULL,
  `EventPicture4` varchar(128) default NULL,
  `EventLocationName` varchar(128) default NULL,
  `EventLocationStreet` varchar(128) default NULL,
  `EventLocationCountry` char(2) default NULL,
  `EventLocationState` char(2) default NULL,
  `EventLocationCity` varchar(64) default NULL,
  `EventLocationZip` varchar(16) default NULL,
  `EventContactPhone` varchar(16) default NULL,
  `EventContactEmail` varchar(64) default NULL,
  PRIMARY KEY  (`EventID`),
  KEY `FK_CommunityToEvent` (`CommunityID`),
  KEY `FK_EventToGroup` (`GroupID`),
  KEY `FK_EventToOrganization` (`OrganizationID`),
  KEY `FK_EventToUser` (`UserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `eventcategory`;
CREATE TABLE `eventcategory` (
  `EventCategoryID` int(11) NOT NULL auto_increment,
  `EventCategoryName` varchar(255) default NULL,
  PRIMARY KEY  (`EventCategoryID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `eventtoparticipant`;
CREATE TABLE `eventtoparticipant` (
  `EventID` int(11) NOT NULL,
  `UserID` int(11) NOT NULL,
  `EventToParticipantStatus` int(11) NOT NULL,       
  PRIMARY KEY  (`EventID`,`UserID`),
  KEY `FK_EventToParticipant` (`UserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `file`;
CREATE TABLE `file` (
  `FileID` int(11) NOT NULL auto_increment,
  `UserID` int(11) default NULL,
  `GroupID` int(11) default NULL,
  `CommunityID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `FileName` varchar(128) default NULL,
  `FilePath` varchar(255) NOT NULL,
  `FileDescription` text,
  PRIMARY KEY  (`FileID`),
  KEY `FK_ComminutyToFile` (`CommunityID`),
  KEY `FK_FileToGroup` (`GroupID`),
  KEY `FK_FileToOrganization` (`OrganizationID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `form`;
CREATE TABLE `form` (
  `FormID` int(11) NOT NULL auto_increment,
  `GroupID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `FormName` varchar(128) default NULL,
  `FormDescription` text NOT NULL,
  `FormStatus` tinyint,
  `FormStartDate` date NOT NULL,
  `FormEndDate` date default NULL,
  `FormPrivacy` tinyint,
  PRIMARY KEY  (`FormID`),
  KEY `FK_FileToGroup` (`GroupID`),
  KEY `FK_FileToOrganization` (`OrganizationID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `formfield`;
CREATE TABLE `formfield` (
  `FormFieldID` int(11) NOT NULL auto_increment,
  `FormID` int(11) default NULL,
  `FormFieldName` varchar(128) default NULL,
  `FormFieldType` tinyint,
  PRIMARY KEY  (`FormFieldID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `formfieldoption`;
CREATE TABLE `formfieldoption` (
  `FormFieldOptionID` int(11) NOT NULL auto_increment,
  `FormFieldID` int(11) default NULL,
  `FormFieldOptionValue` varchar(128) default NULL,
  PRIMARY KEY  (`FormFieldOptionID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `formsubmission`;
CREATE TABLE `formsubmission` (
  `FormSubmissionID` int(11) NOT NULL auto_increment,
  `UserID` int(11) default NULL,
  `FormID` int(11) default NULL,
  `FormFieldID` int(11) default NULL,
  `FormFieldValue` varchar(128) default NULL,
  `FormFieldOptionID` int(11) default NULL,
  `FormSubmissionStatus` tinyint,
  `FormSubmissionDate` datetime default NULL,
  PRIMARY KEY  (`FormSubmissionID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `group`;
CREATE TABLE IF NOT EXISTS `group` (
  `GroupID` int(11) NOT NULL auto_increment,
  `GroupName` varchar(64) NOT NULL default '',
  `GroupDescription` varchar(750) default NULL,
  `GroupKeywords` varchar(255) default NULL,
  `GroupStatus` smallint(6) NOT NULL default '0',
  `GroupAddress1` varchar(255) default NULL,
  `GroupAddress2` varchar(255) default NULL,
  `GroupCity` varchar(255) default NULL,
  `GroupState` char(2) default '0',
  `GroupCountry` char(2) default '0',
  `GroupZip` varchar(16) default NULL,
  `GroupEmail` varchar(128) default NULL,
  `GroupWebAddress` varchar(255) default NULL,
  `GroupPhone` varchar(16) default NULL,
  `GroupFax` varchar(16) default NULL,
  `GroupFavouriteWebsites` varchar(255) default NULL,
  `GroupForumID` int(11),
  `GroupPermissions` int(11) default NULL,
  `GroupOwner` int(11) default NULL,
  `GroupPicture` varchar(255) default NULL,
  `GroupCalendarPrivacy` smallint(6) default '0',  
  `GroupIsNonForProfit` BOOL NOT NULL default 0,  
  `GroupCreated` timestamp NOT NULL default CURRENT_TIMESTAMP,
  `GroupUpdated` timestamp NULL default '0000-00-00 00:00:00',  
  `Created` timestamp,
  PRIMARY KEY  (`GroupID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `invitation`;
CREATE TABLE IF NOT EXISTS `invitation` (
  `InvitationID` int(11) NOT NULL auto_increment,
  `GroupID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `FromUserID` int(11) default NULL,
  `ToUserID` int(11) default NULL,
  `InvitationPermissions` int(11) default NULL,
  PRIMARY KEY  (`InvitationID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `location`;
CREATE TABLE `location` (
  `LocationID` int(11) NOT NULL auto_increment,
  `GroupID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `LocationCountry` char(2) default NULL,
  `LocationName` varchar(64) default NULL,
  `LocationStreet` varchar(255) default '',
  `LocationCity` varchar(64) default '',
  `LocationState` char(2) default NULL,
  PRIMARY KEY  (`LocationID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;


DROP TABLE IF EXISTS `message`;
CREATE TABLE `message` (
  `MessageID` int(11) NOT NULL auto_increment,
  `OrganizationID` int(11) default NULL,
  `CommunityID` int(11) default NULL,
  `UserID` int(11) NOT NULL,
  `GroupID` int(11) default NULL,
  `use_UserID` int(11) default NULL,
  `MessageSubject` varchar(255) NOT NULL,
  `MessageRecipient` varchar(255) NOT NULL,
  `MessageText` text,
  `MessageHtml` text,
  `MessageDate` datetime NOT NULL,
  `MessageStatus` smallint(6) NOT NULL,
  `MessageFlags` smallint(6) NOT NULL,
  `MessageType` int(11) NOT NULL,
  `MessageFile` varchar(255) default NULL,
  `ObjectID` int(11) default NULL,
  PRIMARY KEY  (`MessageID`),
  KEY `FK_CommunityAuthorToMessage` (`CommunityID`),
  KEY `FK_OrganizationAuthorToMessage` (`OrganizationID`),
  KEY `FK_ReceiverToMessage` (`UserID`),
  KEY `FK_GroupAuthorToMessage` (`GroupID`),
  KEY `FK_UserAuthorToMessage` (`use_UserID`)
) ENGINE=InnoDB AUTO_INCREMENT=2 DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `news`;
CREATE TABLE `news` (
  `NewsID` int(11) NOT NULL auto_increment,
  `GroupID` int(11) default NULL,
  `UserID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `CommunityID` int(11) default NULL,
  `NewsDate` datetime NOT NULL,
  `NewsName` varchar(128) NOT NULL,
  `NewsKeywords` varchar(255) default NULL,
  `NewsText` text,
  `NewsViewingPrivacy` int(11),
  `NewsEditingPrivacy` int(11),
  PRIMARY KEY  (`NewsID`),
  KEY `FK_CommunityToNews` (`CommunityID`),
  KEY `FK_NewsToOrganization` (`OrganizationID`),
  KEY `FK_newsToGroups` (`GroupID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `newsdraft`;
CREATE TABLE `newsdraft` (
  `NewsDraftID` int(11) NOT NULL auto_increment,
  `GroupID` int(11) default NULL,
  `UserID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `CommunityID` int(11) default NULL,
  `NewsDate` datetime NOT NULL,
  `NewsName` varchar(128) NOT NULL,
  `NewsKeywords` varchar(255) default NULL,
  `NewsText` text,
  PRIMARY KEY  (`NewsDraftID`),
  KEY `FK_CommunityToNews` (`CommunityID`),
  KEY `FK_NewsToOrganization` (`OrganizationID`),
  KEY `FK_newsToGroups` (`GroupID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `newsversion`;
CREATE TABLE `newsversion` (
  `NewsVersionID` int(11) NOT NULL auto_increment,
  `NewsID` int(11) default NULL,
  `NewsVersionDate` datetime NOT NULL,
  `NewsVersionName` varchar(128) NOT NULL,
  `NewsVersionKeywords` varchar(255) default NULL,
  `NewsVersionText` text,
  PRIMARY KEY  (`NewsVersionID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `organization`;
CREATE TABLE `organization` (
  `OrganizationID` int(11) NOT NULL auto_increment,
  `OrganizationName` varchar(128) NOT NULL,
  `OrganizationDescription` varchar(750) default NULL,
  `OrganizationKeywords` varchar(255) default NULL,
  `OrganizationType` smallint(6) NOT NULL,
  `OrganizationStatus` smallint(6) NOT NULL,
  `OrganizationActive` smallint(6) default '1',
  `OrganizationAddress1` varchar(255) default NULL,
  `OrganizationAddress2` varchar(255) default NULL,
  `OrganizationCity` varchar(255) default NULL,
  `OrganizationState` char(2) default '0',
  `OrganizationCountry` char(2) default '0',
  `OrganizationZip` varchar(16) default NULL,
  `OrganizationEmail` varchar(128) default NULL,
  `OrganizationWebAddress` varchar(255) default NULL,
  `OrganizationPhone` varchar(16) default NULL,
  `OrganizationFax` varchar(16) default NULL,
  `OrganizationFavouriteWebsites` varchar(255) default NULL,
  `OrganizationPermissions` int(11) default NULL,
  `OrganizationPicture` varchar(255) default NULL,
  `OrganizationOwner` int(11) default NULL,
  `OrganizationCalendarPrivacy` smallint(6) default '0',  
  `OrganizationIsNonForProfit` BOOL NOT NULL default 0,    
  `OrganizationCreated` timestamp NULL default CURRENT_TIMESTAMP,
  `OrganizationUpdated` timestamp NULL default '0000-00-00 00:00:00',  
  `OrganizationForumID` int(11),
  PRIMARY KEY  (`OrganizationID`)
) ENGINE=InnoDB;


DROP TABLE IF EXISTS `photo`;
CREATE TABLE IF NOT EXISTS `photo` (
  `PhotoID` int(11) NOT NULL auto_increment,
  `AlbumID` int(11) NOT NULL default '0',
  `PhotoName` varchar(255) default NULL,
  `PhotoPath` varchar(255) default NULL,
  `PhotoStatus` int(11) NOT NULL default '0',
  `PhotoIsCover` smallint(6) NOT NULL default '0',
  `PhotoCreated` timestamp NOT NULL default CURRENT_TIMESTAMP,  
  PRIMARY KEY  (`PhotoID`),
  KEY `FK_PhotoToAlbum` (`AlbumID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `serverspace`;
CREATE TABLE IF NOT EXISTS `serverspace` (
  `ServerSpaceID` int(11) NOT NULL auto_increment,
  `UserID` int(11) UNIQUE NOT NULL default '0',
  `ServerSpaceLimit` float NOT NULL default 0,
  `ServerSpaceUsed` float NOT NULL default 0,
  PRIMARY KEY  (`ServerSpaceID`),
  KEY `FK_SessionToUser` (`UserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `session`;
CREATE TABLE IF NOT EXISTS `session` (
  `SessionID` int(11) NOT NULL auto_increment,
  `UserID` int(11) NOT NULL default '0',
  `UserOnlineStatus` int(11) NOT NULL default '0',
  `UserOnlineStatusOther` varchar(64) default NULL,  
  `UserAwayMessage` varchar(255) default NULL,
  `Created` datetime NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY  (`SessionID`),
  KEY `FK_SessionToUser` (`UserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `skill`;
CREATE TABLE `skill` (
  `SkillID` int(11) NOT NULL auto_increment,
  `UserID` int(11) default NULL,
  `SkillName` varchar(255) default NULL,
  PRIMARY KEY  (`SkillID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `socialgroup`;
CREATE TABLE `socialgroup` (
  `SocialGroupID` int(11) NOT NULL auto_increment,
  `GroupID` int(11) default NULL,
  `UserID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `SocialGroupName` varchar(255) default NULL,
  `SocialGroupURL` varchar(255) default NULL,
  PRIMARY KEY  (`SocialGroupID`)
) ENGINE=InnoDB;


#
# Table structure for table state
#

DROP TABLE IF EXISTS `state`;
CREATE TABLE `state` (
  `StateID` int(11) NOT NULL auto_increment,
  `CountryID` int(11) NOT NULL default '0',
  `StateName` varchar(255) default NULL,
  `StateCode` varchar(3) default NULL,
  PRIMARY KEY  (`StateID`),
  KEY `FK_StateToCountry` (`CountryID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

#
# Dumping data for table state
#


DROP TABLE IF EXISTS `tag`;
CREATE TABLE `tag` (
  `TagID` int(11) NOT NULL auto_increment,
  `TagName` varchar(64) default NULL,
  `ObjectID` int(11) NOT NULL default '0',
  `UserID` int(11) NOT NULL default '0',
  `GroupID` int(11) NOT NULL default '0',
  `OrganizationID` int(11) NOT NULL default '0',
  `CommunityID` int(11) NOT NULL default '0',
  `TagKeywords` varchar(255) default NULL,
  `TagType` int(16) NOT NULL default '0',
  `TagConnectionPrivacyFlag` tinyint(1) NOT NULL default '0',
  `TagUserPrivacyStatus` tinyint(1) NOT NULL default '0',
  `TagGroupPrivacyStatus` tinyint(1) NOT NULL default '0',
  `TagOrganizationPrivacyStatus` tinyint(1) NOT NULL default '0',
PRIMARY KEY (`TagID`)
) ENGINE=InnoDB;


DROP TABLE IF EXISTS `taglocation`;
CREATE TABLE `taglocation` (
  `TagLocationID` int(11) NOT NULL auto_increment,
  `TagID` int(11) NOT NULL default '0',
  `TagLocationCountry` char(2) default '',
  `TagLocationState` char(2) default '',  
  `TagLocationCity` varchar(128) default NULL,    
  `TagLocationNeighborhood` varchar(255) default NULL,
PRIMARY KEY (`TagLocationID`)
) ENGINE=InnoDB;


DROP TABLE IF EXISTS `tagprivacyconnection`;
CREATE TABLE `tagprivacyconnection` (
  `TagID` int(11) NOT NULL default '0',
  `UserID` int(11) NOT NULL default '0',
  `GroupID` int(11) NOT NULL default '0',
  `OrganizationID` int(11) NOT NULL default '0',  
  `PrivacyFlag` tinyint NOT NULL,
  KEY `FK_TagToUser` (`UserID`),
  KEY `FK_TagToGroup` (`GroupID`),  
  KEY `FK_TagToOrganization` (`OrganizationID`)
) ENGINE=InnoDB;


DROP TABLE IF EXISTS `team`;
CREATE TABLE `team` (
  `TeamID` int(11) NOT NULL auto_increment,
  `GroupID` int(11) NOT NULL default '0',
  `OrganizationID` int(11) NOT NULL default '0',
  `TeamName` varchar(128) NOT NULL default '',
  `TeamDescription` varchar(255) NOT NULL default '',
  `TeamPermissions` int(11) default NULL,
  PRIMARY KEY  (`TeamID`),
  KEY `FK_TeamToGroup` (`GroupID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `todo`;
CREATE TABLE IF NOT EXISTS `todo` (
  `TodoID` int(11) NOT NULL auto_increment,
  `GroupID` int(11) NOT NULL default '0',
  `OrganizationID` int(11) NOT NULL default '0',
  `UserID` int(11) default NULL,
  `TodoName` varchar(128) NOT NULL default '',
  `TodoDescription` varchar(255) NOT NULL default '',
  `TodoStatus` int(11) default NULL,
  PRIMARY KEY  (`TodoID`),
  KEY `FK_TodoToGroup` (`GroupID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `school`;
CREATE TABLE `school` (
  `SchoolID` int(11) NOT NULL auto_increment,
  `UserID` int(11) NOT NULL,
  `SchoolName` varchar(128) NOT NULL,
  `SchoolStartDate` date NOT NULL,
  `SchoolEndDate` date default NULL,
  `SchoolDescription` varchar(255) default NULL,
  `SchoolDegree` varchar(255) default NULL,
  PRIMARY KEY  (`SchoolID`),
  KEY `FK_SchoolToUser` (`UserID`)
) ENGINE=InnoDB;


DROP TABLE IF EXISTS `sharedfile`;
CREATE TABLE `sharedfile` (
  `SharedFileID` int(11) NOT NULL auto_increment,
  `UserID` int(11) default NULL,
  `GroupID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `CommunityID` int(11) default NULL,  
  `FileName` varchar(128) default NULL,
  `FilePath` varchar(255) NOT NULL,
  `FileMIMEType` varchar(16) NOT NULL default '', 
  `FileDescription` text,
  `Updated` timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (`SharedFileID`),
  KEY `FK_FileToGroup` (`GroupID`),
  KEY `FK_FileToOrganization` (`OrganizationID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `user`;
CREATE TABLE IF NOT EXISTS `user` (
  `UserID` int(11) NOT NULL auto_increment,
  `Username` varchar(32) default NULL,
  `Password` varchar(32) NOT NULL default '',
  `UserFirstname` varchar(32) default NULL,
  `UserLastname` varchar(32) default NULL,
  `UserTitle` varchar(64) default NULL,
  `UserEmail` varchar(128) NOT NULL default '',
  `UserAddress1` varchar(128) default NULL,
  `UserAddress2` varchar(128) default NULL,
  `UserCity` varchar(32) default NULL,
  `UserZip` char(16) default NULL,
  `UserState` char(2) default NULL,
  `UserCountry` char(2) default NULL,
  `UserPhone` varchar(24) default NULL,
  `UserMobilePhone` varchar(16) default NULL,
  `UserFax` varchar(16) default NULL,
  `UserPicture` varchar(255) default NULL,
  `UserInterests` int(11) default NULL,
  `UserStorage` bigint(20) NOT NULL,
  `UserStorageExpDate` date default NULL,
  `UserFavouriteMovies` varchar(255) default NULL,
  `UserFavouriteBooks` varchar(255) default NULL,
  `UserFavouriteFood` varchar(255) default NULL,
  `UserFavouriteInterests` varchar(255) default NULL,
  `UserFavouriteActivities` varchar(255) default NULL,
  `UserFavouriteWebsites` varchar(255) default NULL,
  `UserResume` varchar(255) default NULL,
  `UserRegistrationDate` date default NULL,
  `UserFavoritesPrivacy` smallint(6) default '0',
  `UserEducationPrivacy` smallint(6) default '0',
  `UserWorkPrivacy` smallint(6) default '0',
  `UserJobPrivacy` smallint(6) default '0',
  `UserCalendarPrivacy` smallint(6) default '0',  
  `UserStatus` smallint(6) default NULL,
  `UserInterestsOther` varchar(255) default NULL,
  `UserYahoo` varchar(64) default NULL,
  `UserSkype` varchar(64) default NULL,
  `UserMSN` varchar(64) default NULL,
  `UserAOL` varchar(64) default NULL,
  `OnlyMyFlags` tinyint(1) NOT NULL default '0',
  `UserType` smallint(6) default '0',  
  `UserMessagingCredit` decimal(10,2) default NULL,  
  `UserPermissions` smallint(6) default '0',  
  `UserUpdated` timestamp NULL default '0000-00-00 00:00:00',  
  `UserForumID` int(11),
  PRIMARY KEY  (`UserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO `user`
SET `UserID`= 1,
 `Username` = 'admin',
 `Password` = 'd9d1b168eac8f197e0576b56cfc23ece',
 `UserFirstname` = 'admin',
 `UserLastname` = 'admin',
 `UserTitle` = 'admin',
 `UserEmail` = 'admin',
 `UserAddress1` = NULL,
 `UserAddress2` = NULL,
 `UserCity` = NULL,
 `UserZip` = NULL,
 `UserState` = NULL,
 `UserCountry` = NULL,
 `UserPhone` = NULL,
 `UserMobilePhone` = NULL,
 `UserFax` = NULL,
 `UserPicture` = NULL,
 `UserInterests` = NULL,
 `UserStorage` = 0,
 `UserStorageExpDate` = NULL,
 `UserFavouriteMovies` = NULL,
 `UserFavouriteBooks` = NULL,
 `UserFavouriteFood` = NULL,
 `UserFavouriteInterests` = NULL,
 `UserFavouriteActivities` = NULL,
 `UserFavouriteWebsites` = NULL,
 `UserResume` = NULL,
 `UserRegistrationDate` = NULL,
 `UserFavoritesPrivacy` = 0,
 `UserEducationPrivacy` = 0,
 `UserWorkPrivacy` = 0,
 `UserJobPrivacy` = 0,
 `UserCalendarPrivacy` = 0,  
 `UserStatus` = NULL,
 `UserInterestsOther` = NULL,
 `UserYahoo` = NULL,
 `UserSkype` = NULL,
 `UserMSN` = NULL,
 `UserAOL` = NULL,
 `OnlyMyFlags` = 0,
 `UserType` = 1,  
 `UserMessagingCredit` = NULL,  
 `UserPermissions` = 1023,  
 `UserUpdated` = '0000-00-00 00:00:00',  
 `UserForumID` = NULL;
 

DROP TABLE IF EXISTS `usertoteam`;
CREATE TABLE IF NOT EXISTS `usertoteam` (
  `UserID` int(11) NOT NULL default '0',
  `TeamID` int(11) NOT NULL default '0'
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `video`;
CREATE TABLE `video` (
  `VideoID` int(11) NOT NULL auto_increment,
  `CommunityID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `GroupID` int(11) default NULL,
  `UserID` int(11) default NULL,
  `VideoAlbumID` int(11) NOT NULL,
  `VideoStatus` int(11) NOT NULL,
  `VideoName` varchar(128) default NULL,
  `VideoPath` varchar(255) NOT NULL,
  `VideoDescription` varchar(255) default NULL,
  `VideoToken` varchar(32) default NULL,
  `VideoIsCover` smallint(6) NOT NULL default '0',
  `VideoCreated` timestamp NOT NULL default CURRENT_TIMESTAMP,    
  PRIMARY KEY  (`VideoID`),
  KEY `FK_CommunityToVideo` (`CommunityID`),
  KEY `FK_VideoToGroup` (`GroupID`),
  KEY `FK_VideoToOrganization` (`OrganizationID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

#
# Table structure for table phpbb_acl_groups
#

DROP TABLE IF EXISTS `phpbb_acl_groups`;
CREATE TABLE `phpbb_acl_groups` (
  `group_id` mediumint(8) unsigned NOT NULL default '0',
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `auth_option_id` mediumint(8) unsigned NOT NULL default '0',
  `auth_role_id` mediumint(8) unsigned NOT NULL default '0',
  `auth_setting` tinyint(2) NOT NULL default '0',
  KEY `group_id` (`group_id`),
  KEY `auth_opt_id` (`auth_option_id`),
  KEY `auth_role_id` (`auth_role_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_acl_groups
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_acl_groups` VALUES (1,0,85,0,1);
INSERT INTO `phpbb_acl_groups` VALUES (1,0,93,0,1);
INSERT INTO `phpbb_acl_groups` VALUES (1,0,110,0,1);
INSERT INTO `phpbb_acl_groups` VALUES (5,0,0,5,0);
INSERT INTO `phpbb_acl_groups` VALUES (5,0,0,1,0);
INSERT INTO `phpbb_acl_groups` VALUES (2,0,0,6,0);
INSERT INTO `phpbb_acl_groups` VALUES (3,0,0,6,0);
INSERT INTO `phpbb_acl_groups` VALUES (4,0,0,5,0);
INSERT INTO `phpbb_acl_groups` VALUES (4,0,0,10,0);
INSERT INTO `phpbb_acl_groups` VALUES (5,3,0,14,0);
INSERT INTO `phpbb_acl_groups` VALUES (6,3,0,19,0);
INSERT INTO `phpbb_acl_groups` VALUES (4,3,0,20,0);
INSERT INTO `phpbb_acl_groups` VALUES (1,3,0,17,0);
INSERT INTO `phpbb_acl_groups` VALUES (2,3,0,21,0);
INSERT INTO `phpbb_acl_groups` VALUES (5,4,0,14,0);
INSERT INTO `phpbb_acl_groups` VALUES (6,4,0,19,0);
INSERT INTO `phpbb_acl_groups` VALUES (4,4,0,20,0);
INSERT INTO `phpbb_acl_groups` VALUES (1,4,0,17,0);
INSERT INTO `phpbb_acl_groups` VALUES (2,4,0,21,0);
INSERT INTO `phpbb_acl_groups` VALUES (5,5,0,14,0);
INSERT INTO `phpbb_acl_groups` VALUES (6,5,0,19,0);
INSERT INTO `phpbb_acl_groups` VALUES (4,5,0,20,0);
INSERT INTO `phpbb_acl_groups` VALUES (1,5,0,17,0);
INSERT INTO `phpbb_acl_groups` VALUES (2,5,0,21,0);
INSERT INTO `phpbb_acl_groups` VALUES (5,6,0,14,0);
INSERT INTO `phpbb_acl_groups` VALUES (6,6,0,19,0);
INSERT INTO `phpbb_acl_groups` VALUES (4,6,0,20,0);
INSERT INTO `phpbb_acl_groups` VALUES (1,6,0,17,0);
INSERT INTO `phpbb_acl_groups` VALUES (2,6,0,21,0);
INSERT INTO `phpbb_acl_groups` VALUES (5,7,0,14,0);
INSERT INTO `phpbb_acl_groups` VALUES (6,7,0,19,0);
INSERT INTO `phpbb_acl_groups` VALUES (4,7,0,20,0);
INSERT INTO `phpbb_acl_groups` VALUES (1,7,0,17,0);
INSERT INTO `phpbb_acl_groups` VALUES (2,7,0,21,0);
INSERT INTO `phpbb_acl_groups` VALUES (5,8,0,14,0);
INSERT INTO `phpbb_acl_groups` VALUES (6,8,0,19,0);
INSERT INTO `phpbb_acl_groups` VALUES (4,8,0,20,0);
INSERT INTO `phpbb_acl_groups` VALUES (1,8,0,17,0);
INSERT INTO `phpbb_acl_groups` VALUES (2,8,0,21,0);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_acl_options
#

DROP TABLE IF EXISTS `phpbb_acl_options`;
CREATE TABLE `phpbb_acl_options` (
  `auth_option_id` mediumint(8) unsigned NOT NULL auto_increment,
  `auth_option` varchar(50) collate utf8_bin NOT NULL default '',
  `is_global` tinyint(1) unsigned NOT NULL default '0',
  `is_local` tinyint(1) unsigned NOT NULL default '0',
  `founder_only` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`auth_option_id`),
  KEY `auth_option` (`auth_option`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_acl_options
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_acl_options` VALUES (1,'f_',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (2,'f_announce',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (3,'f_attach',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (4,'f_bbcode',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (5,'f_bump',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (6,'f_delete',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (7,'f_download',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (8,'f_edit',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (9,'f_email',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (10,'f_flash',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (11,'f_icons',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (12,'f_ignoreflood',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (13,'f_img',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (14,'f_list',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (15,'f_noapprove',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (16,'f_poll',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (17,'f_post',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (18,'f_postcount',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (19,'f_print',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (20,'f_read',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (21,'f_reply',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (22,'f_report',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (23,'f_search',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (24,'f_sigs',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (25,'f_smilies',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (26,'f_sticky',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (27,'f_subscribe',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (28,'f_user_lock',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (29,'f_vote',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (30,'f_votechg',0,1,0);
INSERT INTO `phpbb_acl_options` VALUES (31,'m_',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (32,'m_approve',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (33,'m_chgposter',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (34,'m_delete',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (35,'m_edit',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (36,'m_info',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (37,'m_lock',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (38,'m_merge',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (39,'m_move',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (40,'m_report',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (41,'m_split',1,1,0);
INSERT INTO `phpbb_acl_options` VALUES (42,'m_ban',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (43,'m_warn',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (44,'a_',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (45,'a_aauth',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (46,'a_attach',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (47,'a_authgroups',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (48,'a_authusers',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (49,'a_backup',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (50,'a_ban',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (51,'a_bbcode',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (52,'a_board',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (53,'a_bots',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (54,'a_clearlogs',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (55,'a_email',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (56,'a_fauth',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (57,'a_forum',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (58,'a_forumadd',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (59,'a_forumdel',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (60,'a_group',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (61,'a_groupadd',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (62,'a_groupdel',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (63,'a_icons',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (64,'a_jabber',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (65,'a_language',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (66,'a_mauth',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (67,'a_modules',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (68,'a_names',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (69,'a_phpinfo',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (70,'a_profile',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (71,'a_prune',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (72,'a_ranks',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (73,'a_reasons',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (74,'a_roles',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (75,'a_search',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (76,'a_server',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (77,'a_styles',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (78,'a_switchperm',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (79,'a_uauth',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (80,'a_user',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (81,'a_userdel',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (82,'a_viewauth',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (83,'a_viewlogs',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (84,'a_words',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (85,'u_',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (86,'u_attach',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (87,'u_chgavatar',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (88,'u_chgcensors',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (89,'u_chgemail',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (90,'u_chggrp',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (91,'u_chgname',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (92,'u_chgpasswd',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (93,'u_download',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (94,'u_hideonline',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (95,'u_ignoreflood',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (96,'u_masspm',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (97,'u_pm_attach',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (98,'u_pm_bbcode',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (99,'u_pm_delete',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (100,'u_pm_download',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (101,'u_pm_edit',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (102,'u_pm_emailpm',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (103,'u_pm_flash',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (104,'u_pm_forward',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (105,'u_pm_img',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (106,'u_pm_printpm',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (107,'u_pm_smilies',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (108,'u_readpm',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (109,'u_savedrafts',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (110,'u_search',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (111,'u_sendemail',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (112,'u_sendim',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (113,'u_sendpm',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (114,'u_sig',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (115,'u_viewonline',1,0,0);
INSERT INTO `phpbb_acl_options` VALUES (116,'u_viewprofile',1,0,0);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_acl_roles
#

DROP TABLE IF EXISTS `phpbb_acl_roles`;
CREATE TABLE `phpbb_acl_roles` (
  `role_id` mediumint(8) unsigned NOT NULL auto_increment,
  `role_name` varchar(255) collate utf8_bin NOT NULL default '',
  `role_description` text collate utf8_bin NOT NULL,
  `role_type` varchar(10) collate utf8_bin NOT NULL default '',
  `role_order` smallint(4) unsigned NOT NULL default '0',
  PRIMARY KEY  (`role_id`),
  KEY `role_type` (`role_type`),
  KEY `role_order` (`role_order`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_acl_roles
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_acl_roles` VALUES (1,'ROLE_ADMIN_STANDARD','ROLE_DESCRIPTION_ADMIN_STANDARD','a_',1);
INSERT INTO `phpbb_acl_roles` VALUES (2,'ROLE_ADMIN_FORUM','ROLE_DESCRIPTION_ADMIN_FORUM','a_',3);
INSERT INTO `phpbb_acl_roles` VALUES (3,'ROLE_ADMIN_USERGROUP','ROLE_DESCRIPTION_ADMIN_USERGROUP','a_',4);
INSERT INTO `phpbb_acl_roles` VALUES (4,'ROLE_ADMIN_FULL','ROLE_DESCRIPTION_ADMIN_FULL','a_',2);
INSERT INTO `phpbb_acl_roles` VALUES (5,'ROLE_USER_FULL','ROLE_DESCRIPTION_USER_FULL','u_',3);
INSERT INTO `phpbb_acl_roles` VALUES (6,'ROLE_USER_STANDARD','ROLE_DESCRIPTION_USER_STANDARD','u_',1);
INSERT INTO `phpbb_acl_roles` VALUES (7,'ROLE_USER_LIMITED','ROLE_DESCRIPTION_USER_LIMITED','u_',2);
INSERT INTO `phpbb_acl_roles` VALUES (8,'ROLE_USER_NOPM','ROLE_DESCRIPTION_USER_NOPM','u_',4);
INSERT INTO `phpbb_acl_roles` VALUES (9,'ROLE_USER_NOAVATAR','ROLE_DESCRIPTION_USER_NOAVATAR','u_',5);
INSERT INTO `phpbb_acl_roles` VALUES (10,'ROLE_MOD_FULL','ROLE_DESCRIPTION_MOD_FULL','m_',3);
INSERT INTO `phpbb_acl_roles` VALUES (11,'ROLE_MOD_STANDARD','ROLE_DESCRIPTION_MOD_STANDARD','m_',1);
INSERT INTO `phpbb_acl_roles` VALUES (12,'ROLE_MOD_SIMPLE','ROLE_DESCRIPTION_MOD_SIMPLE','m_',2);
INSERT INTO `phpbb_acl_roles` VALUES (13,'ROLE_MOD_QUEUE','ROLE_DESCRIPTION_MOD_QUEUE','m_',4);
INSERT INTO `phpbb_acl_roles` VALUES (14,'ROLE_FORUM_FULL','ROLE_DESCRIPTION_FORUM_FULL','f_',7);
INSERT INTO `phpbb_acl_roles` VALUES (15,'ROLE_FORUM_STANDARD','ROLE_DESCRIPTION_FORUM_STANDARD','f_',5);
INSERT INTO `phpbb_acl_roles` VALUES (16,'ROLE_FORUM_NOACCESS','ROLE_DESCRIPTION_FORUM_NOACCESS','f_',1);
INSERT INTO `phpbb_acl_roles` VALUES (17,'ROLE_FORUM_READONLY','ROLE_DESCRIPTION_FORUM_READONLY','f_',2);
INSERT INTO `phpbb_acl_roles` VALUES (18,'ROLE_FORUM_LIMITED','ROLE_DESCRIPTION_FORUM_LIMITED','f_',3);
INSERT INTO `phpbb_acl_roles` VALUES (19,'ROLE_FORUM_BOT','ROLE_DESCRIPTION_FORUM_BOT','f_',9);
INSERT INTO `phpbb_acl_roles` VALUES (20,'ROLE_FORUM_ONQUEUE','ROLE_DESCRIPTION_FORUM_ONQUEUE','f_',8);
INSERT INTO `phpbb_acl_roles` VALUES (21,'ROLE_FORUM_POLLS','ROLE_DESCRIPTION_FORUM_POLLS','f_',6);
INSERT INTO `phpbb_acl_roles` VALUES (22,'ROLE_FORUM_LIMITED_POLLS','ROLE_DESCRIPTION_FORUM_LIMITED_POLLS','f_',4);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_acl_roles_data
#

DROP TABLE IF EXISTS `phpbb_acl_roles_data`;
CREATE TABLE `phpbb_acl_roles_data` (
  `role_id` mediumint(8) unsigned NOT NULL default '0',
  `auth_option_id` mediumint(8) unsigned NOT NULL default '0',
  `auth_setting` tinyint(2) NOT NULL default '0',
  PRIMARY KEY  (`role_id`,`auth_option_id`),
  KEY `ath_op_id` (`auth_option_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_acl_roles_data
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_acl_roles_data` VALUES (1,44,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,46,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,47,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,48,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,50,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,51,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,52,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,56,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,57,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,58,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,59,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,60,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,61,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,62,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,63,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,66,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,68,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,70,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,71,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,72,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,73,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,79,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,80,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,81,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,82,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,83,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (1,84,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,44,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,47,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,48,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,56,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,57,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,58,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,59,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,66,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,71,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,79,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,82,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (2,83,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,44,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,47,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,48,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,50,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,60,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,61,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,62,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,72,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,79,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,80,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,82,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (3,83,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,44,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,45,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,46,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,47,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,48,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,49,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,50,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,51,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,52,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,53,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,54,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,55,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,56,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,57,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,58,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,59,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,60,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,61,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,62,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,63,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,64,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,65,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,66,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,67,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,68,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,69,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,70,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,71,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,72,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,73,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,74,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,75,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,76,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,77,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,78,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,79,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,80,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,81,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,82,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,83,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (4,84,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,85,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,86,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,87,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,88,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,89,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,90,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,91,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,92,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,93,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,94,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,95,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,96,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,97,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,98,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,99,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,100,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,101,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,102,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,103,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,104,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,105,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,106,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,107,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,108,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,109,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,110,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,111,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,112,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,113,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,114,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,115,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (5,116,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,85,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,86,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,87,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,88,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,89,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,92,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,93,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,94,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,96,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,97,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,98,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,99,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,100,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,101,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,102,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,105,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,106,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,107,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,108,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,109,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,110,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,111,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,112,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,113,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,114,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (6,116,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,85,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,87,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,88,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,89,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,92,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,93,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,94,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,96,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,98,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,99,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,100,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,101,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,104,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,105,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,106,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,107,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,108,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,113,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,114,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (7,116,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,85,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,87,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,88,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,89,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,92,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,93,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,94,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,96,0);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,108,0);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,113,0);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,114,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (8,116,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,85,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,87,0);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,88,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,89,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,92,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,93,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,94,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,96,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,98,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,99,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,100,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,101,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,104,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,105,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,106,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,107,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,108,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,113,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,114,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (9,116,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,31,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,32,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,33,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,34,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,35,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,36,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,37,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,38,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,39,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,40,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,41,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,42,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (10,43,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,31,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,32,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,34,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,35,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,36,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,37,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,38,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,39,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,40,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,41,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (11,43,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (12,31,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (12,34,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (12,35,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (12,36,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (12,40,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (13,31,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (13,32,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (13,35,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,1,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,2,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,3,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,4,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,5,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,6,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,7,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,8,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,9,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,10,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,11,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,12,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,13,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,14,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,15,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,16,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,17,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,18,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,19,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,20,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,21,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,22,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,23,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,24,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,25,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,26,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,27,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,28,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,29,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (14,30,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,1,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,3,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,4,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,5,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,6,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,7,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,8,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,9,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,11,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,13,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,14,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,15,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,17,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,18,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,19,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,20,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,21,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,22,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,23,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,24,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,25,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,27,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,29,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (15,30,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (16,1,0);
INSERT INTO `phpbb_acl_roles_data` VALUES (17,1,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (17,7,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (17,14,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (17,19,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (17,20,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (17,23,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (17,27,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,1,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,4,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,7,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,8,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,9,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,13,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,14,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,15,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,17,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,18,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,19,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,20,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,21,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,22,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,23,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,24,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,25,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,27,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (18,29,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (19,1,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (19,7,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (19,14,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (19,19,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (19,20,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,1,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,3,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,4,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,7,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,8,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,9,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,13,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,14,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,15,0);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,17,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,18,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,19,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,20,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,21,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,22,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,23,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,24,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,25,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,27,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (20,29,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,1,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,3,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,4,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,5,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,6,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,7,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,8,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,9,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,11,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,13,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,14,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,15,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,16,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,17,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,18,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,19,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,20,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,21,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,22,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,23,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,24,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,25,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,27,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,29,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (21,30,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,1,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,4,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,7,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,8,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,9,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,13,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,14,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,15,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,16,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,17,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,18,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,19,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,20,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,21,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,22,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,23,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,24,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,25,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,27,1);
INSERT INTO `phpbb_acl_roles_data` VALUES (22,29,1);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_acl_users
#

DROP TABLE IF EXISTS `phpbb_acl_users`;
CREATE TABLE `phpbb_acl_users` (
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `auth_option_id` mediumint(8) unsigned NOT NULL default '0',
  `auth_role_id` mediumint(8) unsigned NOT NULL default '0',
  `auth_setting` tinyint(2) NOT NULL default '0',
  KEY `user_id` (`user_id`),
  KEY `auth_option_id` (`auth_option_id`),
  KEY `auth_role_id` (`auth_role_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_acl_users
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_acl_users` VALUES (2,0,0,5,0);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_attachments
#

DROP TABLE IF EXISTS `phpbb_attachments`;
CREATE TABLE `phpbb_attachments` (
  `attach_id` mediumint(8) unsigned NOT NULL auto_increment,
  `post_msg_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_id` mediumint(8) unsigned NOT NULL default '0',
  `in_message` tinyint(1) unsigned NOT NULL default '0',
  `poster_id` mediumint(8) unsigned NOT NULL default '0',
  `is_orphan` tinyint(1) unsigned NOT NULL default '1',
  `physical_filename` varchar(255) collate utf8_bin NOT NULL default '',
  `real_filename` varchar(255) collate utf8_bin NOT NULL default '',
  `download_count` mediumint(8) unsigned NOT NULL default '0',
  `attach_comment` text collate utf8_bin NOT NULL,
  `extension` varchar(100) collate utf8_bin NOT NULL default '',
  `mimetype` varchar(100) collate utf8_bin NOT NULL default '',
  `filesize` int(20) unsigned NOT NULL default '0',
  `filetime` int(11) unsigned NOT NULL default '0',
  `thumbnail` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`attach_id`),
  KEY `filetime` (`filetime`),
  KEY `post_msg_id` (`post_msg_id`),
  KEY `topic_id` (`topic_id`),
  KEY `poster_id` (`poster_id`),
  KEY `is_orphan` (`is_orphan`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_attachments
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_banlist
#

DROP TABLE IF EXISTS `phpbb_banlist`;
CREATE TABLE `phpbb_banlist` (
  `ban_id` mediumint(8) unsigned NOT NULL auto_increment,
  `ban_userid` mediumint(8) unsigned NOT NULL default '0',
  `ban_ip` varchar(40) collate utf8_bin NOT NULL default '',
  `ban_email` varchar(100) collate utf8_bin NOT NULL default '',
  `ban_start` int(11) unsigned NOT NULL default '0',
  `ban_end` int(11) unsigned NOT NULL default '0',
  `ban_exclude` tinyint(1) unsigned NOT NULL default '0',
  `ban_reason` varchar(255) collate utf8_bin NOT NULL default '',
  `ban_give_reason` varchar(255) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`ban_id`),
  KEY `ban_end` (`ban_end`),
  KEY `ban_user` (`ban_userid`,`ban_exclude`),
  KEY `ban_email` (`ban_email`,`ban_exclude`),
  KEY `ban_ip` (`ban_ip`,`ban_exclude`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_banlist
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_bbcodes
#

DROP TABLE IF EXISTS `phpbb_bbcodes`;
CREATE TABLE `phpbb_bbcodes` (
  `bbcode_id` tinyint(3) NOT NULL default '0',
  `bbcode_tag` varchar(16) collate utf8_bin NOT NULL default '',
  `bbcode_helpline` varchar(255) collate utf8_bin NOT NULL default '',
  `display_on_posting` tinyint(1) unsigned NOT NULL default '0',
  `bbcode_match` text collate utf8_bin NOT NULL,
  `bbcode_tpl` mediumtext collate utf8_bin NOT NULL,
  `first_pass_match` mediumtext collate utf8_bin NOT NULL,
  `first_pass_replace` mediumtext collate utf8_bin NOT NULL,
  `second_pass_match` mediumtext collate utf8_bin NOT NULL,
  `second_pass_replace` mediumtext collate utf8_bin NOT NULL,
  PRIMARY KEY  (`bbcode_id`),
  KEY `display_on_post` (`display_on_posting`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_bbcodes
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_bookmarks
#

DROP TABLE IF EXISTS `phpbb_bookmarks`;
CREATE TABLE `phpbb_bookmarks` (
  `topic_id` mediumint(8) unsigned NOT NULL default '0',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  PRIMARY KEY  (`topic_id`,`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_bookmarks
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_bots
#

DROP TABLE IF EXISTS `phpbb_bots`;
CREATE TABLE `phpbb_bots` (
  `bot_id` mediumint(8) unsigned NOT NULL auto_increment,
  `bot_active` tinyint(1) unsigned NOT NULL default '1',
  `bot_name` varchar(255) collate utf8_bin NOT NULL default '',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `bot_agent` varchar(255) collate utf8_bin NOT NULL default '',
  `bot_ip` varchar(255) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`bot_id`),
  KEY `bot_active` (`bot_active`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_bots
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_bots` VALUES (1,1,'AdsBot [Google]',3,'AdsBot-Google','');
INSERT INTO `phpbb_bots` VALUES (2,1,'Alexa [Bot]',4,'ia_archiver','');
INSERT INTO `phpbb_bots` VALUES (3,1,'Alta Vista [Bot]',5,'Scooter/','');
INSERT INTO `phpbb_bots` VALUES (4,1,'Ask Jeeves [Bot]',6,'Ask Jeeves','');
INSERT INTO `phpbb_bots` VALUES (5,1,'Baidu [Spider]',7,'Baiduspider+(','');
INSERT INTO `phpbb_bots` VALUES (6,1,'Exabot [Bot]',8,'Exabot/','');
INSERT INTO `phpbb_bots` VALUES (7,1,'FAST Enterprise [Crawler]',9,'FAST Enterprise Crawler','');
INSERT INTO `phpbb_bots` VALUES (8,1,'FAST WebCrawler [Crawler]',10,'FAST-WebCrawler/','');
INSERT INTO `phpbb_bots` VALUES (9,1,'Francis [Bot]',11,'http://www.neomo.de/','');
INSERT INTO `phpbb_bots` VALUES (10,1,'Gigabot [Bot]',12,'Gigabot/','');
INSERT INTO `phpbb_bots` VALUES (11,1,'Google Adsense [Bot]',13,'Mediapartners-Google','');
INSERT INTO `phpbb_bots` VALUES (12,1,'Google Desktop',14,'Google Desktop','');
INSERT INTO `phpbb_bots` VALUES (13,1,'Google Feedfetcher',15,'Feedfetcher-Google','');
INSERT INTO `phpbb_bots` VALUES (14,1,'Google [Bot]',16,'Googlebot','');
INSERT INTO `phpbb_bots` VALUES (15,1,'Heise IT-Markt [Crawler]',17,'heise-IT-Markt-Crawler','');
INSERT INTO `phpbb_bots` VALUES (16,1,'Heritrix [Crawler]',18,'heritrix/1.','');
INSERT INTO `phpbb_bots` VALUES (17,1,'IBM Research [Bot]',19,'ibm.com/cs/crawler','');
INSERT INTO `phpbb_bots` VALUES (18,1,'ICCrawler - ICjobs',20,'ICCrawler - ICjobs','');
INSERT INTO `phpbb_bots` VALUES (19,1,'ichiro [Crawler]',21,'ichiro/2','');
INSERT INTO `phpbb_bots` VALUES (20,1,'Majestic-12 [Bot]',22,'MJ12bot/','');
INSERT INTO `phpbb_bots` VALUES (21,1,'Metager [Bot]',23,'MetagerBot/','');
INSERT INTO `phpbb_bots` VALUES (22,1,'MSN NewsBlogs',24,'msnbot-NewsBlogs/','');
INSERT INTO `phpbb_bots` VALUES (23,1,'MSN [Bot]',25,'msnbot/','');
INSERT INTO `phpbb_bots` VALUES (24,1,'MSNbot Media',26,'msnbot-media/','');
INSERT INTO `phpbb_bots` VALUES (25,1,'NG-Search [Bot]',27,'NG-Search/','');
INSERT INTO `phpbb_bots` VALUES (26,1,'Nutch [Bot]',28,'http://lucene.apache.org/nutch/','');
INSERT INTO `phpbb_bots` VALUES (27,1,'Nutch/CVS [Bot]',29,'NutchCVS/','');
INSERT INTO `phpbb_bots` VALUES (28,1,'OmniExplorer [Bot]',30,'OmniExplorer_Bot/','');
INSERT INTO `phpbb_bots` VALUES (29,1,'Online link [Validator]',31,'online link validator','');
INSERT INTO `phpbb_bots` VALUES (30,1,'psbot [Picsearch]',32,'psbot/0','');
INSERT INTO `phpbb_bots` VALUES (31,1,'Seekport [Bot]',33,'Seekbot/','');
INSERT INTO `phpbb_bots` VALUES (32,1,'Sensis [Crawler]',34,'Sensis Web Crawler','');
INSERT INTO `phpbb_bots` VALUES (33,1,'SEO Crawler',35,'SEO search Crawler/','');
INSERT INTO `phpbb_bots` VALUES (34,1,'Seoma [Crawler]',36,'Seoma [SEO Crawler]','');
INSERT INTO `phpbb_bots` VALUES (35,1,'SEOSearch [Crawler]',37,'SEOsearch/','');
INSERT INTO `phpbb_bots` VALUES (36,1,'Snappy [Bot]',38,'Snappy/1.1 ( http://www.urltrends.com/ )','');
INSERT INTO `phpbb_bots` VALUES (37,1,'Steeler [Crawler]',39,'http://www.tkl.iis.u-tokyo.ac.jp/~crawler/','');
INSERT INTO `phpbb_bots` VALUES (38,1,'Synoo [Bot]',40,'SynooBot/','');
INSERT INTO `phpbb_bots` VALUES (39,1,'Telekom [Bot]',41,'crawleradmin.t-info@telekom.de','');
INSERT INTO `phpbb_bots` VALUES (40,1,'TurnitinBot [Bot]',42,'TurnitinBot/','');
INSERT INTO `phpbb_bots` VALUES (41,1,'Voyager [Bot]',43,'voyager/1.0','');
INSERT INTO `phpbb_bots` VALUES (42,1,'W3 [Sitesearch]',44,'W3 SiteSearch Crawler','');
INSERT INTO `phpbb_bots` VALUES (43,1,'W3C [Linkcheck]',45,'W3C-checklink/','');
INSERT INTO `phpbb_bots` VALUES (44,1,'W3C [Validator]',46,'W3C_*Validator','');
INSERT INTO `phpbb_bots` VALUES (45,1,'WiseNut [Bot]',47,'http://www.WISEnutbot.com','');
INSERT INTO `phpbb_bots` VALUES (46,1,'YaCy [Bot]',48,'yacybot','');
INSERT INTO `phpbb_bots` VALUES (47,1,'Yahoo MMCrawler [Bot]',49,'Yahoo-MMCrawler/','');
INSERT INTO `phpbb_bots` VALUES (48,1,'Yahoo Slurp [Bot]',50,'Yahoo! DE Slurp','');
INSERT INTO `phpbb_bots` VALUES (49,1,'Yahoo [Bot]',51,'Yahoo! Slurp','');
INSERT INTO `phpbb_bots` VALUES (50,1,'YahooSeeker [Bot]',52,'YahooSeeker/','');

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_config
#

DROP TABLE IF EXISTS `phpbb_config`;
CREATE TABLE `phpbb_config` (
  `config_name` varchar(255) collate utf8_bin NOT NULL default '',
  `config_value` varchar(255) collate utf8_bin NOT NULL default '',
  `is_dynamic` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`config_name`),
  KEY `is_dynamic` (`is_dynamic`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_config
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_config` VALUES ('active_sessions','0',0);
INSERT INTO `phpbb_config` VALUES ('allow_attachments','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_autologin','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_avatar_local','0',0);
INSERT INTO `phpbb_config` VALUES ('allow_avatar_remote','0',0);
INSERT INTO `phpbb_config` VALUES ('allow_avatar_upload','0',0);
INSERT INTO `phpbb_config` VALUES ('allow_bbcode','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_birthdays','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_bookmarks','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_emailreuse','0',0);
INSERT INTO `phpbb_config` VALUES ('allow_forum_notify','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_mass_pm','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_name_chars','USERNAME_CHARS_ANY',0);
INSERT INTO `phpbb_config` VALUES ('allow_namechange','0',0);
INSERT INTO `phpbb_config` VALUES ('allow_nocensors','0',0);
INSERT INTO `phpbb_config` VALUES ('allow_pm_attach','0',0);
INSERT INTO `phpbb_config` VALUES ('allow_post_flash','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_post_links','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_privmsg','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_sig','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_sig_bbcode','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_sig_flash','0',0);
INSERT INTO `phpbb_config` VALUES ('allow_sig_img','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_sig_links','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_sig_pm','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_sig_smilies','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_smilies','1',0);
INSERT INTO `phpbb_config` VALUES ('allow_topic_notify','1',0);
INSERT INTO `phpbb_config` VALUES ('attachment_quota','52428800',0);
INSERT INTO `phpbb_config` VALUES ('auth_bbcode_pm','1',0);
INSERT INTO `phpbb_config` VALUES ('auth_flash_pm','0',0);
INSERT INTO `phpbb_config` VALUES ('auth_img_pm','1',0);
INSERT INTO `phpbb_config` VALUES ('auth_method','db',0);
INSERT INTO `phpbb_config` VALUES ('auth_smilies_pm','1',0);
INSERT INTO `phpbb_config` VALUES ('avatar_filesize','6144',0);
INSERT INTO `phpbb_config` VALUES ('avatar_gallery_path','images/avatars/gallery',0);
INSERT INTO `phpbb_config` VALUES ('avatar_max_height','90',0);
INSERT INTO `phpbb_config` VALUES ('avatar_max_width','90',0);
INSERT INTO `phpbb_config` VALUES ('avatar_min_height','20',0);
INSERT INTO `phpbb_config` VALUES ('avatar_min_width','20',0);
INSERT INTO `phpbb_config` VALUES ('avatar_path','images/avatars/upload',0);
INSERT INTO `phpbb_config` VALUES ('avatar_salt','6362e446d81b094b74451b2363cce123',0);
INSERT INTO `phpbb_config` VALUES ('board_contact','mikes@solovatsoft.com',0);
INSERT INTO `phpbb_config` VALUES ('board_disable','0',0);
INSERT INTO `phpbb_config` VALUES ('board_disable_msg','',0);
INSERT INTO `phpbb_config` VALUES ('board_dst','0',0);
INSERT INTO `phpbb_config` VALUES ('board_email','mikes@solovatsoft.com',0);
INSERT INTO `phpbb_config` VALUES ('board_email_form','0',0);
INSERT INTO `phpbb_config` VALUES ('board_email_sig','Thanks, The Management',0);
INSERT INTO `phpbb_config` VALUES ('board_hide_emails','1',0);
INSERT INTO `phpbb_config` VALUES ('board_startdate','1213196049',0);
INSERT INTO `phpbb_config` VALUES ('board_timezone','0',0);
INSERT INTO `phpbb_config` VALUES ('browser_check','1',0);
INSERT INTO `phpbb_config` VALUES ('bump_interval','10',0);
INSERT INTO `phpbb_config` VALUES ('bump_type','d',0);
INSERT INTO `phpbb_config` VALUES ('cache_gc','7200',0);
INSERT INTO `phpbb_config` VALUES ('cache_last_gc','0',1);
INSERT INTO `phpbb_config` VALUES ('captcha_gd','1',0);
INSERT INTO `phpbb_config` VALUES ('captcha_gd_foreground_noise','0',0);
INSERT INTO `phpbb_config` VALUES ('captcha_gd_x_grid','25',0);
INSERT INTO `phpbb_config` VALUES ('captcha_gd_y_grid','25',0);
INSERT INTO `phpbb_config` VALUES ('check_dnsbl','0',0);
INSERT INTO `phpbb_config` VALUES ('chg_passforce','0',0);
INSERT INTO `phpbb_config` VALUES ('cookie_domain','205.234.253.37',0);
INSERT INTO `phpbb_config` VALUES ('cookie_name','phpbb3_9k36u',0);
INSERT INTO `phpbb_config` VALUES ('cookie_path','/',0);
INSERT INTO `phpbb_config` VALUES ('cookie_secure','0',0);
INSERT INTO `phpbb_config` VALUES ('coppa_enable','0',0);
INSERT INTO `phpbb_config` VALUES ('coppa_fax','',0);
INSERT INTO `phpbb_config` VALUES ('coppa_mail','',0);
INSERT INTO `phpbb_config` VALUES ('cron_lock','0',1);
INSERT INTO `phpbb_config` VALUES ('database_gc','604800',0);
INSERT INTO `phpbb_config` VALUES ('database_last_gc','0',1);
INSERT INTO `phpbb_config` VALUES ('default_dateformat','D M d, Y g:i a',0);
INSERT INTO `phpbb_config` VALUES ('default_lang','en',0);
INSERT INTO `phpbb_config` VALUES ('default_style','1',0);
INSERT INTO `phpbb_config` VALUES ('display_last_edited','1',0);
INSERT INTO `phpbb_config` VALUES ('display_order','0',0);
INSERT INTO `phpbb_config` VALUES ('edit_time','0',0);
INSERT INTO `phpbb_config` VALUES ('email_check_mx','1',0);
INSERT INTO `phpbb_config` VALUES ('email_enable','1',0);
INSERT INTO `phpbb_config` VALUES ('email_function_name','mail',0);
INSERT INTO `phpbb_config` VALUES ('email_package_size','50',0);
INSERT INTO `phpbb_config` VALUES ('enable_confirm','1',0);
INSERT INTO `phpbb_config` VALUES ('enable_pm_icons','1',0);
INSERT INTO `phpbb_config` VALUES ('enable_post_confirm','1',0);
INSERT INTO `phpbb_config` VALUES ('flood_interval','15',0);
INSERT INTO `phpbb_config` VALUES ('force_server_vars','0',0);
INSERT INTO `phpbb_config` VALUES ('form_token_lifetime','7200',0);
INSERT INTO `phpbb_config` VALUES ('form_token_mintime','0',0);
INSERT INTO `phpbb_config` VALUES ('form_token_sid_guests','1',0);
INSERT INTO `phpbb_config` VALUES ('forward_pm','1',0);
INSERT INTO `phpbb_config` VALUES ('forwarded_for_check','0',0);
INSERT INTO `phpbb_config` VALUES ('full_folder_action','2',0);
INSERT INTO `phpbb_config` VALUES ('fulltext_mysql_max_word_len','254',0);
INSERT INTO `phpbb_config` VALUES ('fulltext_mysql_min_word_len','4',0);
INSERT INTO `phpbb_config` VALUES ('fulltext_native_common_thres','5',0);
INSERT INTO `phpbb_config` VALUES ('fulltext_native_load_upd','1',0);
INSERT INTO `phpbb_config` VALUES ('fulltext_native_max_chars','14',0);
INSERT INTO `phpbb_config` VALUES ('fulltext_native_min_chars','3',0);
INSERT INTO `phpbb_config` VALUES ('gzip_compress','0',0);
INSERT INTO `phpbb_config` VALUES ('hot_threshold','25',0);
INSERT INTO `phpbb_config` VALUES ('icons_path','images/icons',0);
INSERT INTO `phpbb_config` VALUES ('img_create_thumbnail','0',0);
INSERT INTO `phpbb_config` VALUES ('img_display_inlined','1',0);
INSERT INTO `phpbb_config` VALUES ('img_imagick','/usr/local/bin/',0);
INSERT INTO `phpbb_config` VALUES ('img_link_height','0',0);
INSERT INTO `phpbb_config` VALUES ('img_link_width','0',0);
INSERT INTO `phpbb_config` VALUES ('img_max_height','0',0);
INSERT INTO `phpbb_config` VALUES ('img_max_thumb_width','400',0);
INSERT INTO `phpbb_config` VALUES ('img_max_width','0',0);
INSERT INTO `phpbb_config` VALUES ('img_min_thumb_filesize','12000',0);
INSERT INTO `phpbb_config` VALUES ('ip_check','3',0);
INSERT INTO `phpbb_config` VALUES ('jab_enable','0',0);
INSERT INTO `phpbb_config` VALUES ('jab_host','',0);
INSERT INTO `phpbb_config` VALUES ('jab_package_size','20',0);
INSERT INTO `phpbb_config` VALUES ('jab_password','',0);
INSERT INTO `phpbb_config` VALUES ('jab_port','5222',0);
INSERT INTO `phpbb_config` VALUES ('jab_use_ssl','0',0);
INSERT INTO `phpbb_config` VALUES ('jab_username','',0);
INSERT INTO `phpbb_config` VALUES ('last_queue_run','0',1);
INSERT INTO `phpbb_config` VALUES ('ldap_base_dn','',0);
INSERT INTO `phpbb_config` VALUES ('ldap_email','',0);
INSERT INTO `phpbb_config` VALUES ('ldap_password','',0);
INSERT INTO `phpbb_config` VALUES ('ldap_port','',0);
INSERT INTO `phpbb_config` VALUES ('ldap_server','',0);
INSERT INTO `phpbb_config` VALUES ('ldap_uid','',0);
INSERT INTO `phpbb_config` VALUES ('ldap_user','',0);
INSERT INTO `phpbb_config` VALUES ('ldap_user_filter','',0);
INSERT INTO `phpbb_config` VALUES ('limit_load','0',0);
INSERT INTO `phpbb_config` VALUES ('limit_search_load','0',0);
INSERT INTO `phpbb_config` VALUES ('load_anon_lastread','0',0);
INSERT INTO `phpbb_config` VALUES ('load_birthdays','1',0);
INSERT INTO `phpbb_config` VALUES ('load_cpf_memberlist','0',0);
INSERT INTO `phpbb_config` VALUES ('load_cpf_viewprofile','1',0);
INSERT INTO `phpbb_config` VALUES ('load_cpf_viewtopic','0',0);
INSERT INTO `phpbb_config` VALUES ('load_db_lastread','1',0);
INSERT INTO `phpbb_config` VALUES ('load_db_track','1',0);
INSERT INTO `phpbb_config` VALUES ('load_jumpbox','1',0);
INSERT INTO `phpbb_config` VALUES ('load_moderators','1',0);
INSERT INTO `phpbb_config` VALUES ('load_online','1',0);
INSERT INTO `phpbb_config` VALUES ('load_online_guests','1',0);
INSERT INTO `phpbb_config` VALUES ('load_online_time','5',0);
INSERT INTO `phpbb_config` VALUES ('load_onlinetrack','1',0);
INSERT INTO `phpbb_config` VALUES ('load_search','1',0);
INSERT INTO `phpbb_config` VALUES ('load_tplcompile','0',0);
INSERT INTO `phpbb_config` VALUES ('load_user_activity','1',0);
INSERT INTO `phpbb_config` VALUES ('max_attachments','3',0);
INSERT INTO `phpbb_config` VALUES ('max_attachments_pm','1',0);
INSERT INTO `phpbb_config` VALUES ('max_autologin_time','0',0);
INSERT INTO `phpbb_config` VALUES ('max_filesize','262144',0);
INSERT INTO `phpbb_config` VALUES ('max_filesize_pm','262144',0);
INSERT INTO `phpbb_config` VALUES ('max_login_attempts','3',0);
INSERT INTO `phpbb_config` VALUES ('max_name_chars','20',0);
INSERT INTO `phpbb_config` VALUES ('max_pass_chars','30',0);
INSERT INTO `phpbb_config` VALUES ('max_poll_options','10',0);
INSERT INTO `phpbb_config` VALUES ('max_post_chars','60000',0);
INSERT INTO `phpbb_config` VALUES ('max_post_font_size','200',0);
INSERT INTO `phpbb_config` VALUES ('max_post_img_height','0',0);
INSERT INTO `phpbb_config` VALUES ('max_post_img_width','0',0);
INSERT INTO `phpbb_config` VALUES ('max_post_smilies','0',0);
INSERT INTO `phpbb_config` VALUES ('max_post_urls','0',0);
INSERT INTO `phpbb_config` VALUES ('max_quote_depth','3',0);
INSERT INTO `phpbb_config` VALUES ('max_reg_attempts','5',0);
INSERT INTO `phpbb_config` VALUES ('max_sig_chars','255',0);
INSERT INTO `phpbb_config` VALUES ('max_sig_font_size','200',0);
INSERT INTO `phpbb_config` VALUES ('max_sig_img_height','0',0);
INSERT INTO `phpbb_config` VALUES ('max_sig_img_width','0',0);
INSERT INTO `phpbb_config` VALUES ('max_sig_smilies','0',0);
INSERT INTO `phpbb_config` VALUES ('max_sig_urls','5',0);
INSERT INTO `phpbb_config` VALUES ('min_name_chars','3',0);
INSERT INTO `phpbb_config` VALUES ('min_pass_chars','6',0);
INSERT INTO `phpbb_config` VALUES ('min_search_author_chars','3',0);
INSERT INTO `phpbb_config` VALUES ('min_time_reg','0',0);
INSERT INTO `phpbb_config` VALUES ('min_time_terms','0',0);
INSERT INTO `phpbb_config` VALUES ('newest_user_colour','',1);
INSERT INTO `phpbb_config` VALUES ('newest_user_id','55',1);
INSERT INTO `phpbb_config` VALUES ('newest_username','test@test.com',1);
INSERT INTO `phpbb_config` VALUES ('num_files','0',1);
INSERT INTO `phpbb_config` VALUES ('num_posts','0',1);
INSERT INTO `phpbb_config` VALUES ('num_topics','0',1);
INSERT INTO `phpbb_config` VALUES ('num_users','4',1);
INSERT INTO `phpbb_config` VALUES ('override_user_style','0',0);
INSERT INTO `phpbb_config` VALUES ('pass_complex','PASS_TYPE_ANY',0);
INSERT INTO `phpbb_config` VALUES ('pm_edit_time','0',0);
INSERT INTO `phpbb_config` VALUES ('pm_max_boxes','4',0);
INSERT INTO `phpbb_config` VALUES ('pm_max_msgs','50',0);
INSERT INTO `phpbb_config` VALUES ('posts_per_page','10',0);
INSERT INTO `phpbb_config` VALUES ('print_pm','1',0);
INSERT INTO `phpbb_config` VALUES ('queue_interval','600',0);
INSERT INTO `phpbb_config` VALUES ('rand_seed','f3df97cb37652400b01bb1b232290dec',1);
INSERT INTO `phpbb_config` VALUES ('rand_seed_last_update','1219070191',1);
INSERT INTO `phpbb_config` VALUES ('ranks_path','images/ranks',0);
INSERT INTO `phpbb_config` VALUES ('record_online_date','1219066355',1);
INSERT INTO `phpbb_config` VALUES ('record_online_users','2',1);
INSERT INTO `phpbb_config` VALUES ('require_activation','0',0);
INSERT INTO `phpbb_config` VALUES ('script_path','/cc/forum',0);
INSERT INTO `phpbb_config` VALUES ('search_anonymous_interval','0',0);
INSERT INTO `phpbb_config` VALUES ('search_block_size','250',0);
INSERT INTO `phpbb_config` VALUES ('search_gc','7200',0);
INSERT INTO `phpbb_config` VALUES ('search_indexing_state','',0);
INSERT INTO `phpbb_config` VALUES ('search_interval','0',0);
INSERT INTO `phpbb_config` VALUES ('search_last_gc','0',1);
INSERT INTO `phpbb_config` VALUES ('search_store_results','1800',0);
INSERT INTO `phpbb_config` VALUES ('search_type','fulltext_native',0);
INSERT INTO `phpbb_config` VALUES ('secure_allow_deny','1',0);
INSERT INTO `phpbb_config` VALUES ('secure_allow_empty_referer','1',0);
INSERT INTO `phpbb_config` VALUES ('secure_downloads','0',0);
INSERT INTO `phpbb_config` VALUES ('server_name','205.234.253.37',0);
INSERT INTO `phpbb_config` VALUES ('server_port','80',0);
INSERT INTO `phpbb_config` VALUES ('server_protocol','http://',0);
INSERT INTO `phpbb_config` VALUES ('session_gc','3600',0);
INSERT INTO `phpbb_config` VALUES ('session_last_gc','0',1);
INSERT INTO `phpbb_config` VALUES ('session_length','3600',0);
INSERT INTO `phpbb_config` VALUES ('site_desc','A short text to describe your forum',0);
INSERT INTO `phpbb_config` VALUES ('sitename','yourdomain.com',0);
INSERT INTO `phpbb_config` VALUES ('smilies_path','images/smilies',0);
INSERT INTO `phpbb_config` VALUES ('smtp_auth_method','PLAIN',0);
INSERT INTO `phpbb_config` VALUES ('smtp_delivery','0',0);
INSERT INTO `phpbb_config` VALUES ('smtp_host','',0);
INSERT INTO `phpbb_config` VALUES ('smtp_password','',0);
INSERT INTO `phpbb_config` VALUES ('smtp_port','25',0);
INSERT INTO `phpbb_config` VALUES ('smtp_username','',0);
INSERT INTO `phpbb_config` VALUES ('topics_per_page','25',0);
INSERT INTO `phpbb_config` VALUES ('tpl_allow_php','0',0);
INSERT INTO `phpbb_config` VALUES ('upload_dir_size','0',1);
INSERT INTO `phpbb_config` VALUES ('upload_icons_path','images/upload_icons',0);
INSERT INTO `phpbb_config` VALUES ('upload_path','files',0);
INSERT INTO `phpbb_config` VALUES ('version','3.0.1',0);
INSERT INTO `phpbb_config` VALUES ('warnings_expire_days','90',0);
INSERT INTO `phpbb_config` VALUES ('warnings_gc','14400',0);
INSERT INTO `phpbb_config` VALUES ('warnings_last_gc','0',1);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_confirm
#

DROP TABLE IF EXISTS `phpbb_confirm`;
CREATE TABLE `phpbb_confirm` (
  `confirm_id` char(32) collate utf8_bin NOT NULL default '',
  `session_id` char(32) collate utf8_bin NOT NULL default '',
  `confirm_type` tinyint(3) NOT NULL default '0',
  `code` varchar(8) collate utf8_bin NOT NULL default '',
  `seed` int(10) unsigned NOT NULL default '0',
  PRIMARY KEY  (`session_id`,`confirm_id`),
  KEY `confirm_type` (`confirm_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_confirm
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_disallow
#

DROP TABLE IF EXISTS `phpbb_disallow`;
CREATE TABLE `phpbb_disallow` (
  `disallow_id` mediumint(8) unsigned NOT NULL auto_increment,
  `disallow_username` varchar(255) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`disallow_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_disallow
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_drafts
#

DROP TABLE IF EXISTS `phpbb_drafts`;
CREATE TABLE `phpbb_drafts` (
  `draft_id` mediumint(8) unsigned NOT NULL auto_increment,
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_id` mediumint(8) unsigned NOT NULL default '0',
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `save_time` int(11) unsigned NOT NULL default '0',
  `draft_subject` varchar(100) collate utf8_bin NOT NULL default '',
  `draft_message` mediumtext collate utf8_bin NOT NULL,
  PRIMARY KEY  (`draft_id`),
  KEY `save_time` (`save_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_drafts
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_extension_groups
#

DROP TABLE IF EXISTS `phpbb_extension_groups`;
CREATE TABLE `phpbb_extension_groups` (
  `group_id` mediumint(8) unsigned NOT NULL auto_increment,
  `group_name` varchar(255) collate utf8_bin NOT NULL default '',
  `cat_id` tinyint(2) NOT NULL default '0',
  `allow_group` tinyint(1) unsigned NOT NULL default '0',
  `download_mode` tinyint(1) unsigned NOT NULL default '1',
  `upload_icon` varchar(255) collate utf8_bin NOT NULL default '',
  `max_filesize` int(20) unsigned NOT NULL default '0',
  `allowed_forums` text collate utf8_bin NOT NULL,
  `allow_in_pm` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`group_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_extension_groups
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_extension_groups` VALUES (1,'Images',1,1,1,'',0,'',0);
INSERT INTO `phpbb_extension_groups` VALUES (2,'Archives',0,1,1,'',0,'',0);
INSERT INTO `phpbb_extension_groups` VALUES (3,'Plain Text',0,0,1,'',0,'',0);
INSERT INTO `phpbb_extension_groups` VALUES (4,'Documents',0,0,1,'',0,'',0);
INSERT INTO `phpbb_extension_groups` VALUES (5,'Real Media',3,0,1,'',0,'',0);
INSERT INTO `phpbb_extension_groups` VALUES (6,'Windows Media',2,0,1,'',0,'',0);
INSERT INTO `phpbb_extension_groups` VALUES (7,'Flash Files',5,0,1,'',0,'',0);
INSERT INTO `phpbb_extension_groups` VALUES (8,'Quicktime Media',6,0,1,'',0,'',0);
INSERT INTO `phpbb_extension_groups` VALUES (9,'Downloadable Files',0,0,1,'',0,'',0);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_extensions
#

DROP TABLE IF EXISTS `phpbb_extensions`;
CREATE TABLE `phpbb_extensions` (
  `extension_id` mediumint(8) unsigned NOT NULL auto_increment,
  `group_id` mediumint(8) unsigned NOT NULL default '0',
  `extension` varchar(100) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`extension_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_extensions
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_extensions` VALUES (1,1,'gif');
INSERT INTO `phpbb_extensions` VALUES (2,1,'png');
INSERT INTO `phpbb_extensions` VALUES (3,1,'jpeg');
INSERT INTO `phpbb_extensions` VALUES (4,1,'jpg');
INSERT INTO `phpbb_extensions` VALUES (5,1,'tif');
INSERT INTO `phpbb_extensions` VALUES (6,1,'tiff');
INSERT INTO `phpbb_extensions` VALUES (7,1,'tga');
INSERT INTO `phpbb_extensions` VALUES (8,2,'gtar');
INSERT INTO `phpbb_extensions` VALUES (9,2,'gz');
INSERT INTO `phpbb_extensions` VALUES (10,2,'tar');
INSERT INTO `phpbb_extensions` VALUES (11,2,'zip');
INSERT INTO `phpbb_extensions` VALUES (12,2,'rar');
INSERT INTO `phpbb_extensions` VALUES (13,2,'ace');
INSERT INTO `phpbb_extensions` VALUES (14,2,'torrent');
INSERT INTO `phpbb_extensions` VALUES (15,2,'tgz');
INSERT INTO `phpbb_extensions` VALUES (16,2,'bz2');
INSERT INTO `phpbb_extensions` VALUES (17,2,'7z');
INSERT INTO `phpbb_extensions` VALUES (18,3,'txt');
INSERT INTO `phpbb_extensions` VALUES (19,3,'c');
INSERT INTO `phpbb_extensions` VALUES (20,3,'h');
INSERT INTO `phpbb_extensions` VALUES (21,3,'cpp');
INSERT INTO `phpbb_extensions` VALUES (22,3,'hpp');
INSERT INTO `phpbb_extensions` VALUES (23,3,'diz');
INSERT INTO `phpbb_extensions` VALUES (24,3,'csv');
INSERT INTO `phpbb_extensions` VALUES (25,3,'ini');
INSERT INTO `phpbb_extensions` VALUES (26,3,'log');
INSERT INTO `phpbb_extensions` VALUES (27,3,'js');
INSERT INTO `phpbb_extensions` VALUES (28,3,'xml');
INSERT INTO `phpbb_extensions` VALUES (29,4,'xls');
INSERT INTO `phpbb_extensions` VALUES (30,4,'xlsx');
INSERT INTO `phpbb_extensions` VALUES (31,4,'xlsm');
INSERT INTO `phpbb_extensions` VALUES (32,4,'xlsb');
INSERT INTO `phpbb_extensions` VALUES (33,4,'doc');
INSERT INTO `phpbb_extensions` VALUES (34,4,'docx');
INSERT INTO `phpbb_extensions` VALUES (35,4,'docm');
INSERT INTO `phpbb_extensions` VALUES (36,4,'dot');
INSERT INTO `phpbb_extensions` VALUES (37,4,'dotx');
INSERT INTO `phpbb_extensions` VALUES (38,4,'dotm');
INSERT INTO `phpbb_extensions` VALUES (39,4,'pdf');
INSERT INTO `phpbb_extensions` VALUES (40,4,'ai');
INSERT INTO `phpbb_extensions` VALUES (41,4,'ps');
INSERT INTO `phpbb_extensions` VALUES (42,4,'ppt');
INSERT INTO `phpbb_extensions` VALUES (43,4,'pptx');
INSERT INTO `phpbb_extensions` VALUES (44,4,'pptm');
INSERT INTO `phpbb_extensions` VALUES (45,4,'odg');
INSERT INTO `phpbb_extensions` VALUES (46,4,'odp');
INSERT INTO `phpbb_extensions` VALUES (47,4,'ods');
INSERT INTO `phpbb_extensions` VALUES (48,4,'odt');
INSERT INTO `phpbb_extensions` VALUES (49,4,'rtf');
INSERT INTO `phpbb_extensions` VALUES (50,5,'rm');
INSERT INTO `phpbb_extensions` VALUES (51,5,'ram');
INSERT INTO `phpbb_extensions` VALUES (52,6,'wma');
INSERT INTO `phpbb_extensions` VALUES (53,6,'wmv');
INSERT INTO `phpbb_extensions` VALUES (54,7,'swf');
INSERT INTO `phpbb_extensions` VALUES (55,8,'mov');
INSERT INTO `phpbb_extensions` VALUES (56,8,'m4v');
INSERT INTO `phpbb_extensions` VALUES (57,8,'m4a');
INSERT INTO `phpbb_extensions` VALUES (58,8,'mp4');
INSERT INTO `phpbb_extensions` VALUES (59,8,'3gp');
INSERT INTO `phpbb_extensions` VALUES (60,8,'3g2');
INSERT INTO `phpbb_extensions` VALUES (61,8,'qt');
INSERT INTO `phpbb_extensions` VALUES (62,9,'mpeg');
INSERT INTO `phpbb_extensions` VALUES (63,9,'mpg');
INSERT INTO `phpbb_extensions` VALUES (64,9,'mp3');
INSERT INTO `phpbb_extensions` VALUES (65,9,'ogg');
INSERT INTO `phpbb_extensions` VALUES (66,9,'ogm');

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_forums
#

DROP TABLE IF EXISTS `phpbb_forums`;
CREATE TABLE `phpbb_forums` (
  `forum_id` mediumint(8) unsigned NOT NULL auto_increment,
  `parent_id` mediumint(8) unsigned NOT NULL default '0',
  `left_id` mediumint(8) unsigned NOT NULL default '0',
  `right_id` mediumint(8) unsigned NOT NULL default '0',
  `forum_parents` mediumtext collate utf8_bin NOT NULL,
  `forum_name` varchar(255) collate utf8_bin NOT NULL default '',
  `forum_desc` text collate utf8_bin NOT NULL,
  `forum_desc_bitfield` varchar(255) collate utf8_bin NOT NULL default '',
  `forum_desc_options` int(11) unsigned NOT NULL default '7',
  `forum_desc_uid` varchar(8) collate utf8_bin NOT NULL default '',
  `forum_link` varchar(255) collate utf8_bin NOT NULL default '',
  `forum_password` varchar(40) collate utf8_bin NOT NULL default '',
  `forum_style` smallint(4) unsigned NOT NULL default '0',
  `forum_image` varchar(255) collate utf8_bin NOT NULL default '',
  `forum_rules` text collate utf8_bin NOT NULL,
  `forum_rules_link` varchar(255) collate utf8_bin NOT NULL default '',
  `forum_rules_bitfield` varchar(255) collate utf8_bin NOT NULL default '',
  `forum_rules_options` int(11) unsigned NOT NULL default '7',
  `forum_rules_uid` varchar(8) collate utf8_bin NOT NULL default '',
  `forum_topics_per_page` tinyint(4) NOT NULL default '0',
  `forum_type` tinyint(4) NOT NULL default '0',
  `forum_status` tinyint(4) NOT NULL default '0',
  `forum_posts` mediumint(8) unsigned NOT NULL default '0',
  `forum_topics` mediumint(8) unsigned NOT NULL default '0',
  `forum_topics_real` mediumint(8) unsigned NOT NULL default '0',
  `forum_last_post_id` mediumint(8) unsigned NOT NULL default '0',
  `forum_last_poster_id` mediumint(8) unsigned NOT NULL default '0',
  `forum_last_post_subject` varchar(100) collate utf8_bin NOT NULL default '',
  `forum_last_post_time` int(11) unsigned NOT NULL default '0',
  `forum_last_poster_name` varchar(255) collate utf8_bin NOT NULL default '',
  `forum_last_poster_colour` varchar(6) collate utf8_bin NOT NULL default '',
  `forum_flags` tinyint(4) NOT NULL default '32',
  `display_subforum_list` tinyint(1) unsigned NOT NULL default '1',
  `display_on_index` tinyint(1) unsigned NOT NULL default '1',
  `enable_indexing` tinyint(1) unsigned NOT NULL default '1',
  `enable_icons` tinyint(1) unsigned NOT NULL default '1',
  `enable_prune` tinyint(1) unsigned NOT NULL default '0',
  `prune_next` int(11) unsigned NOT NULL default '0',
  `prune_days` mediumint(8) unsigned NOT NULL default '0',
  `prune_viewed` mediumint(8) unsigned NOT NULL default '0',
  `prune_freq` mediumint(8) unsigned NOT NULL default '0',
  PRIMARY KEY  (`forum_id`),
  KEY `left_right_id` (`left_id`,`right_id`),
  KEY `forum_lastpost_id` (`forum_last_post_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_forums
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_forums` VALUES (3,0,1,2,'','General forum','','',7,'','','',0,'','','','',7,'',0,1,0,0,0,0,0,0,'',0,'','',32,1,0,1,0,0,0,7,7,1);
INSERT INTO `phpbb_forums` VALUES (4,0,3,12,'','Community Forums','','',7,'','','',0,'','','','',7,'',0,1,0,0,0,0,0,0,'',0,'','',32,1,0,1,0,0,0,7,7,1);
INSERT INTO `phpbb_forums` VALUES (5,4,4,5,'','Individuals','','',7,'','','',0,'','','','',7,'',0,1,0,0,0,0,0,0,'',0,'','',32,1,0,1,0,0,0,7,7,1);
INSERT INTO `phpbb_forums` VALUES (6,4,6,7,'','Groups','','',7,'','','',0,'','','','',7,'',0,1,0,0,0,0,0,0,'',0,'','',32,1,0,1,0,0,0,7,7,1);
INSERT INTO `phpbb_forums` VALUES (7,4,8,9,'','Organizations','','',7,'','','',0,'','','','',7,'',0,1,0,0,0,0,0,0,'',0,'','',32,1,0,1,0,0,0,7,7,1);
INSERT INTO `phpbb_forums` VALUES (8,4,10,11,'','Communities','','',7,'','','',0,'','','','',7,'',0,1,0,0,0,0,0,0,'',0,'','',32,1,0,1,0,0,0,7,7,1);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_forums_access
#

DROP TABLE IF EXISTS `phpbb_forums_access`;
CREATE TABLE `phpbb_forums_access` (
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `session_id` char(32) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`forum_id`,`user_id`,`session_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_forums_access
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_forums_track
#

DROP TABLE IF EXISTS `phpbb_forums_track`;
CREATE TABLE `phpbb_forums_track` (
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `mark_time` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`user_id`,`forum_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_forums_track
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_forums_watch
#

DROP TABLE IF EXISTS `phpbb_forums_watch`;
CREATE TABLE `phpbb_forums_watch` (
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `notify_status` tinyint(1) unsigned NOT NULL default '0',
  KEY `forum_id` (`forum_id`),
  KEY `user_id` (`user_id`),
  KEY `notify_stat` (`notify_status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_forums_watch
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_groups
#

DROP TABLE IF EXISTS `phpbb_groups`;
CREATE TABLE `phpbb_groups` (
  `group_id` mediumint(8) unsigned NOT NULL auto_increment,
  `group_type` tinyint(4) NOT NULL default '1',
  `group_founder_manage` tinyint(1) unsigned NOT NULL default '0',
  `group_name` varchar(255) collate utf8_bin NOT NULL default '',
  `group_desc` text collate utf8_bin NOT NULL,
  `group_desc_bitfield` varchar(255) collate utf8_bin NOT NULL default '',
  `group_desc_options` int(11) unsigned NOT NULL default '7',
  `group_desc_uid` varchar(8) collate utf8_bin NOT NULL default '',
  `group_display` tinyint(1) unsigned NOT NULL default '0',
  `group_avatar` varchar(255) collate utf8_bin NOT NULL default '',
  `group_avatar_type` tinyint(2) NOT NULL default '0',
  `group_avatar_width` smallint(4) unsigned NOT NULL default '0',
  `group_avatar_height` smallint(4) unsigned NOT NULL default '0',
  `group_rank` mediumint(8) unsigned NOT NULL default '0',
  `group_colour` varchar(6) collate utf8_bin NOT NULL default '',
  `group_sig_chars` mediumint(8) unsigned NOT NULL default '0',
  `group_receive_pm` tinyint(1) unsigned NOT NULL default '0',
  `group_message_limit` mediumint(8) unsigned NOT NULL default '0',
  `group_legend` tinyint(1) unsigned NOT NULL default '1',
  PRIMARY KEY  (`group_id`),
  KEY `group_legend_name` (`group_legend`,`group_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_groups
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_groups` VALUES (1,3,0,'GUESTS','','',7,'',0,'',0,0,0,0,'',0,0,0,0);
INSERT INTO `phpbb_groups` VALUES (2,3,0,'REGISTERED','','',7,'',0,'',0,0,0,0,'',0,0,0,0);
INSERT INTO `phpbb_groups` VALUES (3,3,0,'REGISTERED_COPPA','','',7,'',0,'',0,0,0,0,'',0,0,0,0);
INSERT INTO `phpbb_groups` VALUES (4,3,0,'GLOBAL_MODERATORS','','',7,'',0,'',0,0,0,0,'00AA00',0,0,0,1);
INSERT INTO `phpbb_groups` VALUES (5,3,1,'ADMINISTRATORS','','',7,'',0,'',0,0,0,0,'AA0000',0,0,0,1);
INSERT INTO `phpbb_groups` VALUES (6,3,0,'BOTS','','',7,'',0,'',0,0,0,0,'9E8DA7',0,0,0,0);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_icons
#

DROP TABLE IF EXISTS `phpbb_icons`;
CREATE TABLE `phpbb_icons` (
  `icons_id` mediumint(8) unsigned NOT NULL auto_increment,
  `icons_url` varchar(255) collate utf8_bin NOT NULL default '',
  `icons_width` tinyint(4) NOT NULL default '0',
  `icons_height` tinyint(4) NOT NULL default '0',
  `icons_order` mediumint(8) unsigned NOT NULL default '0',
  `display_on_posting` tinyint(1) unsigned NOT NULL default '1',
  PRIMARY KEY  (`icons_id`),
  KEY `display_on_posting` (`display_on_posting`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_icons
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_icons` VALUES (1,'misc/fire.gif',16,16,1,1);
INSERT INTO `phpbb_icons` VALUES (2,'smile/redface.gif',16,16,9,1);
INSERT INTO `phpbb_icons` VALUES (3,'smile/mrgreen.gif',16,16,10,1);
INSERT INTO `phpbb_icons` VALUES (4,'misc/heart.gif',16,16,4,1);
INSERT INTO `phpbb_icons` VALUES (5,'misc/star.gif',16,16,2,1);
INSERT INTO `phpbb_icons` VALUES (6,'misc/radioactive.gif',16,16,3,1);
INSERT INTO `phpbb_icons` VALUES (7,'misc/thinking.gif',16,16,5,1);
INSERT INTO `phpbb_icons` VALUES (8,'smile/info.gif',16,16,8,1);
INSERT INTO `phpbb_icons` VALUES (9,'smile/question.gif',16,16,6,1);
INSERT INTO `phpbb_icons` VALUES (10,'smile/alert.gif',16,16,7,1);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_lang
#

DROP TABLE IF EXISTS `phpbb_lang`;
CREATE TABLE `phpbb_lang` (
  `lang_id` tinyint(4) NOT NULL auto_increment,
  `lang_iso` varchar(30) collate utf8_bin NOT NULL default '',
  `lang_dir` varchar(30) collate utf8_bin NOT NULL default '',
  `lang_english_name` varchar(100) collate utf8_bin NOT NULL default '',
  `lang_local_name` varchar(255) collate utf8_bin NOT NULL default '',
  `lang_author` varchar(255) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`lang_id`),
  KEY `lang_iso` (`lang_iso`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_lang
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_lang` VALUES (1,'en','en','British English','British English','phpBB Group');

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_log
#

DROP TABLE IF EXISTS `phpbb_log`;
CREATE TABLE `phpbb_log` (
  `log_id` mediumint(8) unsigned NOT NULL auto_increment,
  `log_type` tinyint(4) NOT NULL default '0',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_id` mediumint(8) unsigned NOT NULL default '0',
  `reportee_id` mediumint(8) unsigned NOT NULL default '0',
  `log_ip` varchar(40) collate utf8_bin NOT NULL default '',
  `log_time` int(11) unsigned NOT NULL default '0',
  `log_operation` text collate utf8_bin NOT NULL,
  `log_data` mediumtext collate utf8_bin NOT NULL,
  PRIMARY KEY  (`log_id`),
  KEY `log_type` (`log_type`),
  KEY `forum_id` (`forum_id`),
  KEY `topic_id` (`topic_id`),
  KEY `reportee_id` (`reportee_id`),
  KEY `user_id` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_log
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_log` VALUES (1,0,2,0,0,0,'84.53.238.18',1213196054,'LOG_INSTALL_INSTALLED','a:1:{i:0;s:5:\"3.0.1\";}');
INSERT INTO `phpbb_log` VALUES (2,0,2,0,0,0,'127.0.0.1',1219066492,'LOG_FORUM_DEL_FORUMS','a:1:{i:0;s:19:\"Your first category\";}');
INSERT INTO `phpbb_log` VALUES (3,0,2,0,0,0,'127.0.0.1',1219066602,'LOG_FORUM_ADD','a:1:{i:0;s:13:\"General forum\";}');
INSERT INTO `phpbb_log` VALUES (4,0,2,0,0,0,'127.0.0.1',1219066670,'LOG_ACL_ADD_FORUM_LOCAL_F_','a:2:{i:0;s:13:\"General forum\";i:1;s:190:\"<span class=\"sep\">Guests</span>, <span class=\"sep\">Registered users</span>, <span class=\"sep\">Global moderators</span>, <span class=\"sep\">Administrators</span>, <span class=\"sep\">Bots</span>\";}');
INSERT INTO `phpbb_log` VALUES (5,0,2,0,0,0,'127.0.0.1',1219066714,'LOG_FORUM_ADD','a:1:{i:0;s:14:\"Community Forums\";}');
INSERT INTO `phpbb_log` VALUES (6,0,2,0,0,0,'127.0.0.1',1219066784,'LOG_FORUM_ADD','a:1:{i:0;s:11:\"Individuals\";}');
INSERT INTO `phpbb_log` VALUES (7,0,2,0,0,0,'127.0.0.1',1219066813,'LOG_FORUM_ADD','a:1:{i:0;s:6:\"Groups\";}');
INSERT INTO `phpbb_log` VALUES (8,0,2,0,0,0,'127.0.0.1',1219066842,'LOG_FORUM_ADD','a:1:{i:0;s:13:\"Organizations\";}');
INSERT INTO `phpbb_log` VALUES (9,0,2,0,0,0,'127.0.0.1',1219066863,'LOG_FORUM_ADD','a:1:{i:0;s:11:\"Communities\";}');
INSERT INTO `phpbb_log` VALUES (10,0,2,0,0,0,'127.0.0.1',1219071086,'LOG_FORUM_DEL_POSTS','a:1:{i:0;s:9:\"Mike Test\";}');

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_moderator_cache
#

DROP TABLE IF EXISTS `phpbb_moderator_cache`;
CREATE TABLE `phpbb_moderator_cache` (
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `username` varchar(255) collate utf8_bin NOT NULL default '',
  `group_id` mediumint(8) unsigned NOT NULL default '0',
  `group_name` varchar(255) collate utf8_bin NOT NULL default '',
  `display_on_index` tinyint(1) unsigned NOT NULL default '1',
  KEY `disp_idx` (`display_on_index`),
  KEY `forum_id` (`forum_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_moderator_cache
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_modules
#

DROP TABLE IF EXISTS `phpbb_modules`;
CREATE TABLE `phpbb_modules` (
  `module_id` mediumint(8) unsigned NOT NULL auto_increment,
  `module_enabled` tinyint(1) unsigned NOT NULL default '1',
  `module_display` tinyint(1) unsigned NOT NULL default '1',
  `module_basename` varchar(255) collate utf8_bin NOT NULL default '',
  `module_class` varchar(10) collate utf8_bin NOT NULL default '',
  `parent_id` mediumint(8) unsigned NOT NULL default '0',
  `left_id` mediumint(8) unsigned NOT NULL default '0',
  `right_id` mediumint(8) unsigned NOT NULL default '0',
  `module_langname` varchar(255) collate utf8_bin NOT NULL default '',
  `module_mode` varchar(255) collate utf8_bin NOT NULL default '',
  `module_auth` varchar(255) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`module_id`),
  KEY `left_right_id` (`left_id`,`right_id`),
  KEY `module_enabled` (`module_enabled`),
  KEY `class_left_id` (`module_class`,`left_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_modules
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_modules` VALUES (1,1,1,'','acp',0,1,60,'ACP_CAT_GENERAL','','');
INSERT INTO `phpbb_modules` VALUES (2,1,1,'','acp',1,4,17,'ACP_QUICK_ACCESS','','');
INSERT INTO `phpbb_modules` VALUES (3,1,1,'','acp',1,18,39,'ACP_BOARD_CONFIGURATION','','');
INSERT INTO `phpbb_modules` VALUES (4,1,1,'','acp',1,40,47,'ACP_CLIENT_COMMUNICATION','','');
INSERT INTO `phpbb_modules` VALUES (5,1,1,'','acp',1,48,59,'ACP_SERVER_CONFIGURATION','','');
INSERT INTO `phpbb_modules` VALUES (6,1,1,'','acp',0,61,78,'ACP_CAT_FORUMS','','');
INSERT INTO `phpbb_modules` VALUES (7,1,1,'','acp',6,62,67,'ACP_MANAGE_FORUMS','','');
INSERT INTO `phpbb_modules` VALUES (8,1,1,'','acp',6,68,77,'ACP_FORUM_BASED_PERMISSIONS','','');
INSERT INTO `phpbb_modules` VALUES (9,1,1,'','acp',0,79,102,'ACP_CAT_POSTING','','');
INSERT INTO `phpbb_modules` VALUES (10,1,1,'','acp',9,80,91,'ACP_MESSAGES','','');
INSERT INTO `phpbb_modules` VALUES (11,1,1,'','acp',9,92,101,'ACP_ATTACHMENTS','','');
INSERT INTO `phpbb_modules` VALUES (12,1,1,'','acp',0,103,156,'ACP_CAT_USERGROUP','','');
INSERT INTO `phpbb_modules` VALUES (13,1,1,'','acp',12,104,135,'ACP_CAT_USERS','','');
INSERT INTO `phpbb_modules` VALUES (14,1,1,'','acp',12,136,143,'ACP_GROUPS','','');
INSERT INTO `phpbb_modules` VALUES (15,1,1,'','acp',12,144,155,'ACP_USER_SECURITY','','');
INSERT INTO `phpbb_modules` VALUES (16,1,1,'','acp',0,157,204,'ACP_CAT_PERMISSIONS','','');
INSERT INTO `phpbb_modules` VALUES (17,1,1,'','acp',16,160,169,'ACP_GLOBAL_PERMISSIONS','','');
INSERT INTO `phpbb_modules` VALUES (18,1,1,'','acp',16,170,179,'ACP_FORUM_BASED_PERMISSIONS','','');
INSERT INTO `phpbb_modules` VALUES (19,1,1,'','acp',16,180,189,'ACP_PERMISSION_ROLES','','');
INSERT INTO `phpbb_modules` VALUES (20,1,1,'','acp',16,190,203,'ACP_PERMISSION_MASKS','','');
INSERT INTO `phpbb_modules` VALUES (21,1,1,'','acp',0,205,218,'ACP_CAT_STYLES','','');
INSERT INTO `phpbb_modules` VALUES (22,1,1,'','acp',21,206,209,'ACP_STYLE_MANAGEMENT','','');
INSERT INTO `phpbb_modules` VALUES (23,1,1,'','acp',21,210,217,'ACP_STYLE_COMPONENTS','','');
INSERT INTO `phpbb_modules` VALUES (24,1,1,'','acp',0,219,238,'ACP_CAT_MAINTENANCE','','');
INSERT INTO `phpbb_modules` VALUES (25,1,1,'','acp',24,220,229,'ACP_FORUM_LOGS','','');
INSERT INTO `phpbb_modules` VALUES (26,1,1,'','acp',24,230,237,'ACP_CAT_DATABASE','','');
INSERT INTO `phpbb_modules` VALUES (27,1,1,'','acp',0,239,264,'ACP_CAT_SYSTEM','','');
INSERT INTO `phpbb_modules` VALUES (28,1,1,'','acp',27,240,243,'ACP_AUTOMATION','','');
INSERT INTO `phpbb_modules` VALUES (29,1,1,'','acp',27,244,255,'ACP_GENERAL_TASKS','','');
INSERT INTO `phpbb_modules` VALUES (30,1,1,'','acp',27,256,263,'ACP_MODULE_MANAGEMENT','','');
INSERT INTO `phpbb_modules` VALUES (31,1,1,'','acp',0,265,266,'ACP_CAT_DOT_MODS','','');
INSERT INTO `phpbb_modules` VALUES (32,1,1,'attachments','acp',3,19,20,'ACP_ATTACHMENT_SETTINGS','attach','acl_a_attach');
INSERT INTO `phpbb_modules` VALUES (33,1,1,'attachments','acp',11,93,94,'ACP_ATTACHMENT_SETTINGS','attach','acl_a_attach');
INSERT INTO `phpbb_modules` VALUES (34,1,1,'attachments','acp',11,95,96,'ACP_MANAGE_EXTENSIONS','extensions','acl_a_attach');
INSERT INTO `phpbb_modules` VALUES (35,1,1,'attachments','acp',11,97,98,'ACP_EXTENSION_GROUPS','ext_groups','acl_a_attach');
INSERT INTO `phpbb_modules` VALUES (36,1,1,'attachments','acp',11,99,100,'ACP_ORPHAN_ATTACHMENTS','orphan','acl_a_attach');
INSERT INTO `phpbb_modules` VALUES (37,1,1,'ban','acp',15,145,146,'ACP_BAN_EMAILS','email','acl_a_ban');
INSERT INTO `phpbb_modules` VALUES (38,1,1,'ban','acp',15,147,148,'ACP_BAN_IPS','ip','acl_a_ban');
INSERT INTO `phpbb_modules` VALUES (39,1,1,'ban','acp',15,149,150,'ACP_BAN_USERNAMES','user','acl_a_ban');
INSERT INTO `phpbb_modules` VALUES (40,1,1,'bbcodes','acp',10,81,82,'ACP_BBCODES','bbcodes','acl_a_bbcode');
INSERT INTO `phpbb_modules` VALUES (41,1,1,'board','acp',3,21,22,'ACP_BOARD_SETTINGS','settings','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (42,1,1,'board','acp',3,23,24,'ACP_BOARD_FEATURES','features','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (43,1,1,'board','acp',3,25,26,'ACP_AVATAR_SETTINGS','avatar','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (44,1,1,'board','acp',3,27,28,'ACP_MESSAGE_SETTINGS','message','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (45,1,1,'board','acp',10,83,84,'ACP_MESSAGE_SETTINGS','message','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (46,1,1,'board','acp',3,29,30,'ACP_POST_SETTINGS','post','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (47,1,1,'board','acp',3,31,32,'ACP_SIGNATURE_SETTINGS','signature','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (48,1,1,'board','acp',3,33,34,'ACP_REGISTER_SETTINGS','registration','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (49,1,1,'board','acp',4,41,42,'ACP_AUTH_SETTINGS','auth','acl_a_server');
INSERT INTO `phpbb_modules` VALUES (50,1,1,'board','acp',4,43,44,'ACP_EMAIL_SETTINGS','email','acl_a_server');
INSERT INTO `phpbb_modules` VALUES (51,1,1,'board','acp',5,49,50,'ACP_COOKIE_SETTINGS','cookie','acl_a_server');
INSERT INTO `phpbb_modules` VALUES (52,1,1,'board','acp',5,51,52,'ACP_SERVER_SETTINGS','server','acl_a_server');
INSERT INTO `phpbb_modules` VALUES (53,1,1,'board','acp',5,53,54,'ACP_SECURITY_SETTINGS','security','acl_a_server');
INSERT INTO `phpbb_modules` VALUES (54,1,1,'board','acp',5,55,56,'ACP_LOAD_SETTINGS','load','acl_a_server');
INSERT INTO `phpbb_modules` VALUES (55,1,1,'bots','acp',29,245,246,'ACP_BOTS','bots','acl_a_bots');
INSERT INTO `phpbb_modules` VALUES (56,1,1,'captcha','acp',3,35,36,'ACP_VC_SETTINGS','visual','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (57,1,0,'captcha','acp',3,37,38,'ACP_VC_CAPTCHA_DISPLAY','img','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (58,1,1,'database','acp',26,231,232,'ACP_BACKUP','backup','acl_a_backup');
INSERT INTO `phpbb_modules` VALUES (59,1,1,'database','acp',26,233,234,'ACP_RESTORE','restore','acl_a_backup');
INSERT INTO `phpbb_modules` VALUES (60,1,1,'disallow','acp',15,151,152,'ACP_DISALLOW_USERNAMES','usernames','acl_a_names');
INSERT INTO `phpbb_modules` VALUES (61,1,1,'email','acp',29,247,248,'ACP_MASS_EMAIL','email','acl_a_email');
INSERT INTO `phpbb_modules` VALUES (62,1,1,'forums','acp',7,63,64,'ACP_MANAGE_FORUMS','manage','acl_a_forum');
INSERT INTO `phpbb_modules` VALUES (63,1,1,'groups','acp',14,137,138,'ACP_GROUPS_MANAGE','manage','acl_a_group');
INSERT INTO `phpbb_modules` VALUES (64,1,1,'icons','acp',10,85,86,'ACP_ICONS','icons','acl_a_icons');
INSERT INTO `phpbb_modules` VALUES (65,1,1,'icons','acp',10,87,88,'ACP_SMILIES','smilies','acl_a_icons');
INSERT INTO `phpbb_modules` VALUES (66,1,1,'inactive','acp',13,107,108,'ACP_INACTIVE_USERS','list','acl_a_user');
INSERT INTO `phpbb_modules` VALUES (67,1,1,'jabber','acp',4,45,46,'ACP_JABBER_SETTINGS','settings','acl_a_jabber');
INSERT INTO `phpbb_modules` VALUES (68,1,1,'language','acp',29,249,250,'ACP_LANGUAGE_PACKS','lang_packs','acl_a_language');
INSERT INTO `phpbb_modules` VALUES (69,1,1,'logs','acp',25,221,222,'ACP_ADMIN_LOGS','admin','acl_a_viewlogs');
INSERT INTO `phpbb_modules` VALUES (70,1,1,'logs','acp',25,223,224,'ACP_MOD_LOGS','mod','acl_a_viewlogs');
INSERT INTO `phpbb_modules` VALUES (71,1,1,'logs','acp',25,225,226,'ACP_USERS_LOGS','users','acl_a_viewlogs');
INSERT INTO `phpbb_modules` VALUES (72,1,1,'logs','acp',25,227,228,'ACP_CRITICAL_LOGS','critical','acl_a_viewlogs');
INSERT INTO `phpbb_modules` VALUES (73,1,1,'main','acp',1,2,3,'ACP_INDEX','main','');
INSERT INTO `phpbb_modules` VALUES (74,1,1,'modules','acp',30,257,258,'ACP','acp','acl_a_modules');
INSERT INTO `phpbb_modules` VALUES (75,1,1,'modules','acp',30,259,260,'UCP','ucp','acl_a_modules');
INSERT INTO `phpbb_modules` VALUES (76,1,1,'modules','acp',30,261,262,'MCP','mcp','acl_a_modules');
INSERT INTO `phpbb_modules` VALUES (77,1,1,'permission_roles','acp',19,181,182,'ACP_ADMIN_ROLES','admin_roles','acl_a_roles && acl_a_aauth');
INSERT INTO `phpbb_modules` VALUES (78,1,1,'permission_roles','acp',19,183,184,'ACP_USER_ROLES','user_roles','acl_a_roles && acl_a_uauth');
INSERT INTO `phpbb_modules` VALUES (79,1,1,'permission_roles','acp',19,185,186,'ACP_MOD_ROLES','mod_roles','acl_a_roles && acl_a_mauth');
INSERT INTO `phpbb_modules` VALUES (80,1,1,'permission_roles','acp',19,187,188,'ACP_FORUM_ROLES','forum_roles','acl_a_roles && acl_a_fauth');
INSERT INTO `phpbb_modules` VALUES (81,1,1,'permissions','acp',16,158,159,'ACP_PERMISSIONS','intro','acl_a_authusers || acl_a_authgroups || acl_a_viewauth');
INSERT INTO `phpbb_modules` VALUES (82,1,0,'permissions','acp',20,191,192,'ACP_PERMISSION_TRACE','trace','acl_a_viewauth');
INSERT INTO `phpbb_modules` VALUES (83,1,1,'permissions','acp',18,171,172,'ACP_FORUM_PERMISSIONS','setting_forum_local','acl_a_fauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO `phpbb_modules` VALUES (84,1,1,'permissions','acp',18,173,174,'ACP_FORUM_MODERATORS','setting_mod_local','acl_a_mauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO `phpbb_modules` VALUES (85,1,1,'permissions','acp',17,161,162,'ACP_USERS_PERMISSIONS','setting_user_global','acl_a_authusers && (acl_a_aauth || acl_a_mauth || acl_a_uauth)');
INSERT INTO `phpbb_modules` VALUES (86,1,1,'permissions','acp',13,109,110,'ACP_USERS_PERMISSIONS','setting_user_global','acl_a_authusers && (acl_a_aauth || acl_a_mauth || acl_a_uauth)');
INSERT INTO `phpbb_modules` VALUES (87,1,1,'permissions','acp',18,175,176,'ACP_USERS_FORUM_PERMISSIONS','setting_user_local','acl_a_authusers && (acl_a_mauth || acl_a_fauth)');
INSERT INTO `phpbb_modules` VALUES (88,1,1,'permissions','acp',13,111,112,'ACP_USERS_FORUM_PERMISSIONS','setting_user_local','acl_a_authusers && (acl_a_mauth || acl_a_fauth)');
INSERT INTO `phpbb_modules` VALUES (89,1,1,'permissions','acp',17,163,164,'ACP_GROUPS_PERMISSIONS','setting_group_global','acl_a_authgroups && (acl_a_aauth || acl_a_mauth || acl_a_uauth)');
INSERT INTO `phpbb_modules` VALUES (90,1,1,'permissions','acp',14,139,140,'ACP_GROUPS_PERMISSIONS','setting_group_global','acl_a_authgroups && (acl_a_aauth || acl_a_mauth || acl_a_uauth)');
INSERT INTO `phpbb_modules` VALUES (91,1,1,'permissions','acp',18,177,178,'ACP_GROUPS_FORUM_PERMISSIONS','setting_group_local','acl_a_authgroups && (acl_a_mauth || acl_a_fauth)');
INSERT INTO `phpbb_modules` VALUES (92,1,1,'permissions','acp',14,141,142,'ACP_GROUPS_FORUM_PERMISSIONS','setting_group_local','acl_a_authgroups && (acl_a_mauth || acl_a_fauth)');
INSERT INTO `phpbb_modules` VALUES (93,1,1,'permissions','acp',17,165,166,'ACP_ADMINISTRATORS','setting_admin_global','acl_a_aauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO `phpbb_modules` VALUES (94,1,1,'permissions','acp',17,167,168,'ACP_GLOBAL_MODERATORS','setting_mod_global','acl_a_mauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO `phpbb_modules` VALUES (95,1,1,'permissions','acp',20,193,194,'ACP_VIEW_ADMIN_PERMISSIONS','view_admin_global','acl_a_viewauth');
INSERT INTO `phpbb_modules` VALUES (96,1,1,'permissions','acp',20,195,196,'ACP_VIEW_USER_PERMISSIONS','view_user_global','acl_a_viewauth');
INSERT INTO `phpbb_modules` VALUES (97,1,1,'permissions','acp',20,197,198,'ACP_VIEW_GLOBAL_MOD_PERMISSIONS','view_mod_global','acl_a_viewauth');
INSERT INTO `phpbb_modules` VALUES (98,1,1,'permissions','acp',20,199,200,'ACP_VIEW_FORUM_MOD_PERMISSIONS','view_mod_local','acl_a_viewauth');
INSERT INTO `phpbb_modules` VALUES (99,1,1,'permissions','acp',20,201,202,'ACP_VIEW_FORUM_PERMISSIONS','view_forum_local','acl_a_viewauth');
INSERT INTO `phpbb_modules` VALUES (100,1,1,'php_info','acp',29,251,252,'ACP_PHP_INFO','info','acl_a_phpinfo');
INSERT INTO `phpbb_modules` VALUES (101,1,1,'profile','acp',13,113,114,'ACP_CUSTOM_PROFILE_FIELDS','profile','acl_a_profile');
INSERT INTO `phpbb_modules` VALUES (102,1,1,'prune','acp',7,65,66,'ACP_PRUNE_FORUMS','forums','acl_a_prune');
INSERT INTO `phpbb_modules` VALUES (103,1,1,'prune','acp',15,153,154,'ACP_PRUNE_USERS','users','acl_a_userdel');
INSERT INTO `phpbb_modules` VALUES (104,1,1,'ranks','acp',13,115,116,'ACP_MANAGE_RANKS','ranks','acl_a_ranks');
INSERT INTO `phpbb_modules` VALUES (105,1,1,'reasons','acp',29,253,254,'ACP_MANAGE_REASONS','main','acl_a_reasons');
INSERT INTO `phpbb_modules` VALUES (106,1,1,'search','acp',5,57,58,'ACP_SEARCH_SETTINGS','settings','acl_a_search');
INSERT INTO `phpbb_modules` VALUES (107,1,1,'search','acp',26,235,236,'ACP_SEARCH_INDEX','index','acl_a_search');
INSERT INTO `phpbb_modules` VALUES (108,1,1,'styles','acp',22,207,208,'ACP_STYLES','style','acl_a_styles');
INSERT INTO `phpbb_modules` VALUES (109,1,1,'styles','acp',23,211,212,'ACP_TEMPLATES','template','acl_a_styles');
INSERT INTO `phpbb_modules` VALUES (110,1,1,'styles','acp',23,213,214,'ACP_THEMES','theme','acl_a_styles');
INSERT INTO `phpbb_modules` VALUES (111,1,1,'styles','acp',23,215,216,'ACP_IMAGESETS','imageset','acl_a_styles');
INSERT INTO `phpbb_modules` VALUES (112,1,1,'update','acp',28,241,242,'ACP_VERSION_CHECK','version_check','acl_a_board');
INSERT INTO `phpbb_modules` VALUES (113,1,1,'users','acp',13,105,106,'ACP_MANAGE_USERS','overview','acl_a_user');
INSERT INTO `phpbb_modules` VALUES (114,1,0,'users','acp',13,117,118,'ACP_USER_FEEDBACK','feedback','acl_a_user');
INSERT INTO `phpbb_modules` VALUES (115,1,0,'users','acp',13,119,120,'ACP_USER_PROFILE','profile','acl_a_user');
INSERT INTO `phpbb_modules` VALUES (116,1,0,'users','acp',13,121,122,'ACP_USER_PREFS','prefs','acl_a_user');
INSERT INTO `phpbb_modules` VALUES (117,1,0,'users','acp',13,123,124,'ACP_USER_AVATAR','avatar','acl_a_user');
INSERT INTO `phpbb_modules` VALUES (118,1,0,'users','acp',13,125,126,'ACP_USER_RANK','rank','acl_a_user');
INSERT INTO `phpbb_modules` VALUES (119,1,0,'users','acp',13,127,128,'ACP_USER_SIG','sig','acl_a_user');
INSERT INTO `phpbb_modules` VALUES (120,1,0,'users','acp',13,129,130,'ACP_USER_GROUPS','groups','acl_a_user && acl_a_group');
INSERT INTO `phpbb_modules` VALUES (121,1,0,'users','acp',13,131,132,'ACP_USER_PERM','perm','acl_a_user && acl_a_viewauth');
INSERT INTO `phpbb_modules` VALUES (122,1,0,'users','acp',13,133,134,'ACP_USER_ATTACH','attach','acl_a_user');
INSERT INTO `phpbb_modules` VALUES (123,1,1,'words','acp',10,89,90,'ACP_WORDS','words','acl_a_words');
INSERT INTO `phpbb_modules` VALUES (124,1,1,'users','acp',2,5,6,'ACP_MANAGE_USERS','overview','acl_a_user');
INSERT INTO `phpbb_modules` VALUES (125,1,1,'groups','acp',2,7,8,'ACP_GROUPS_MANAGE','manage','acl_a_group');
INSERT INTO `phpbb_modules` VALUES (126,1,1,'forums','acp',2,9,10,'ACP_MANAGE_FORUMS','manage','acl_a_forum');
INSERT INTO `phpbb_modules` VALUES (127,1,1,'logs','acp',2,11,12,'ACP_MOD_LOGS','mod','acl_a_viewlogs');
INSERT INTO `phpbb_modules` VALUES (128,1,1,'bots','acp',2,13,14,'ACP_BOTS','bots','acl_a_bots');
INSERT INTO `phpbb_modules` VALUES (129,1,1,'php_info','acp',2,15,16,'ACP_PHP_INFO','info','acl_a_phpinfo');
INSERT INTO `phpbb_modules` VALUES (130,1,1,'permissions','acp',8,69,70,'ACP_FORUM_PERMISSIONS','setting_forum_local','acl_a_fauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO `phpbb_modules` VALUES (131,1,1,'permissions','acp',8,71,72,'ACP_FORUM_MODERATORS','setting_mod_local','acl_a_mauth && (acl_a_authusers || acl_a_authgroups)');
INSERT INTO `phpbb_modules` VALUES (132,1,1,'permissions','acp',8,73,74,'ACP_USERS_FORUM_PERMISSIONS','setting_user_local','acl_a_authusers && (acl_a_mauth || acl_a_fauth)');
INSERT INTO `phpbb_modules` VALUES (133,1,1,'permissions','acp',8,75,76,'ACP_GROUPS_FORUM_PERMISSIONS','setting_group_local','acl_a_authgroups && (acl_a_mauth || acl_a_fauth)');
INSERT INTO `phpbb_modules` VALUES (134,1,1,'','mcp',0,1,10,'MCP_MAIN','','');
INSERT INTO `phpbb_modules` VALUES (135,1,1,'','mcp',0,11,18,'MCP_QUEUE','','');
INSERT INTO `phpbb_modules` VALUES (136,1,1,'','mcp',0,19,26,'MCP_REPORTS','','');
INSERT INTO `phpbb_modules` VALUES (137,1,1,'','mcp',0,27,32,'MCP_NOTES','','');
INSERT INTO `phpbb_modules` VALUES (138,1,1,'','mcp',0,33,42,'MCP_WARN','','');
INSERT INTO `phpbb_modules` VALUES (139,1,1,'','mcp',0,43,50,'MCP_LOGS','','');
INSERT INTO `phpbb_modules` VALUES (140,1,1,'','mcp',0,51,58,'MCP_BAN','','');
INSERT INTO `phpbb_modules` VALUES (141,1,1,'ban','mcp',140,52,53,'MCP_BAN_USERNAMES','user','acl_m_ban');
INSERT INTO `phpbb_modules` VALUES (142,1,1,'ban','mcp',140,54,55,'MCP_BAN_IPS','ip','acl_m_ban');
INSERT INTO `phpbb_modules` VALUES (143,1,1,'ban','mcp',140,56,57,'MCP_BAN_EMAILS','email','acl_m_ban');
INSERT INTO `phpbb_modules` VALUES (144,1,1,'logs','mcp',139,44,45,'MCP_LOGS_FRONT','front','acl_m_ || aclf_m_');
INSERT INTO `phpbb_modules` VALUES (145,1,1,'logs','mcp',139,46,47,'MCP_LOGS_FORUM_VIEW','forum_logs','acl_m_,$id');
INSERT INTO `phpbb_modules` VALUES (146,1,1,'logs','mcp',139,48,49,'MCP_LOGS_TOPIC_VIEW','topic_logs','acl_m_,$id');
INSERT INTO `phpbb_modules` VALUES (147,1,1,'main','mcp',134,2,3,'MCP_MAIN_FRONT','front','');
INSERT INTO `phpbb_modules` VALUES (148,1,1,'main','mcp',134,4,5,'MCP_MAIN_FORUM_VIEW','forum_view','acl_m_,$id');
INSERT INTO `phpbb_modules` VALUES (149,1,1,'main','mcp',134,6,7,'MCP_MAIN_TOPIC_VIEW','topic_view','acl_m_,$id');
INSERT INTO `phpbb_modules` VALUES (150,1,1,'main','mcp',134,8,9,'MCP_MAIN_POST_DETAILS','post_details','acl_m_,$id || (!$id && aclf_m_)');
INSERT INTO `phpbb_modules` VALUES (151,1,1,'notes','mcp',137,28,29,'MCP_NOTES_FRONT','front','');
INSERT INTO `phpbb_modules` VALUES (152,1,1,'notes','mcp',137,30,31,'MCP_NOTES_USER','user_notes','');
INSERT INTO `phpbb_modules` VALUES (153,1,1,'queue','mcp',135,12,13,'MCP_QUEUE_UNAPPROVED_TOPICS','unapproved_topics','aclf_m_approve');
INSERT INTO `phpbb_modules` VALUES (154,1,1,'queue','mcp',135,14,15,'MCP_QUEUE_UNAPPROVED_POSTS','unapproved_posts','aclf_m_approve');
INSERT INTO `phpbb_modules` VALUES (155,1,1,'queue','mcp',135,16,17,'MCP_QUEUE_APPROVE_DETAILS','approve_details','acl_m_approve,$id || (!$id && aclf_m_approve)');
INSERT INTO `phpbb_modules` VALUES (156,1,1,'reports','mcp',136,20,21,'MCP_REPORTS_OPEN','reports','aclf_m_report');
INSERT INTO `phpbb_modules` VALUES (157,1,1,'reports','mcp',136,22,23,'MCP_REPORTS_CLOSED','reports_closed','aclf_m_report');
INSERT INTO `phpbb_modules` VALUES (158,1,1,'reports','mcp',136,24,25,'MCP_REPORT_DETAILS','report_details','acl_m_report,$id || (!$id && aclf_m_report)');
INSERT INTO `phpbb_modules` VALUES (159,1,1,'warn','mcp',138,34,35,'MCP_WARN_FRONT','front','aclf_m_warn');
INSERT INTO `phpbb_modules` VALUES (160,1,1,'warn','mcp',138,36,37,'MCP_WARN_LIST','list','aclf_m_warn');
INSERT INTO `phpbb_modules` VALUES (161,1,1,'warn','mcp',138,38,39,'MCP_WARN_USER','warn_user','aclf_m_warn');
INSERT INTO `phpbb_modules` VALUES (162,1,1,'warn','mcp',138,40,41,'MCP_WARN_POST','warn_post','acl_m_warn && acl_f_read,$id');
INSERT INTO `phpbb_modules` VALUES (163,1,1,'','ucp',0,1,12,'UCP_MAIN','','');
INSERT INTO `phpbb_modules` VALUES (164,1,1,'','ucp',0,13,22,'UCP_PROFILE','','');
INSERT INTO `phpbb_modules` VALUES (165,1,1,'','ucp',0,23,30,'UCP_PREFS','','');
INSERT INTO `phpbb_modules` VALUES (166,1,1,'','ucp',0,31,42,'UCP_PM','','');
INSERT INTO `phpbb_modules` VALUES (167,1,1,'','ucp',0,43,48,'UCP_USERGROUPS','','');
INSERT INTO `phpbb_modules` VALUES (168,1,1,'','ucp',0,49,54,'UCP_ZEBRA','','');
INSERT INTO `phpbb_modules` VALUES (169,1,1,'attachments','ucp',163,10,11,'UCP_MAIN_ATTACHMENTS','attachments','acl_u_attach');
INSERT INTO `phpbb_modules` VALUES (170,1,1,'groups','ucp',167,44,45,'UCP_USERGROUPS_MEMBER','membership','');
INSERT INTO `phpbb_modules` VALUES (171,1,1,'groups','ucp',167,46,47,'UCP_USERGROUPS_MANAGE','manage','');
INSERT INTO `phpbb_modules` VALUES (172,1,1,'main','ucp',163,2,3,'UCP_MAIN_FRONT','front','');
INSERT INTO `phpbb_modules` VALUES (173,1,1,'main','ucp',163,4,5,'UCP_MAIN_SUBSCRIBED','subscribed','');
INSERT INTO `phpbb_modules` VALUES (174,1,1,'main','ucp',163,6,7,'UCP_MAIN_BOOKMARKS','bookmarks','cfg_allow_bookmarks');
INSERT INTO `phpbb_modules` VALUES (175,1,1,'main','ucp',163,8,9,'UCP_MAIN_DRAFTS','drafts','');
INSERT INTO `phpbb_modules` VALUES (176,1,0,'pm','ucp',166,32,33,'UCP_PM_VIEW','view','cfg_allow_privmsg');
INSERT INTO `phpbb_modules` VALUES (177,1,1,'pm','ucp',166,34,35,'UCP_PM_COMPOSE','compose','cfg_allow_privmsg');
INSERT INTO `phpbb_modules` VALUES (178,1,1,'pm','ucp',166,36,37,'UCP_PM_DRAFTS','drafts','cfg_allow_privmsg');
INSERT INTO `phpbb_modules` VALUES (179,1,1,'pm','ucp',166,38,39,'UCP_PM_OPTIONS','options','cfg_allow_privmsg');
INSERT INTO `phpbb_modules` VALUES (180,1,0,'pm','ucp',166,40,41,'UCP_PM_POPUP_TITLE','popup','cfg_allow_privmsg');
INSERT INTO `phpbb_modules` VALUES (181,1,1,'prefs','ucp',165,24,25,'UCP_PREFS_PERSONAL','personal','');
INSERT INTO `phpbb_modules` VALUES (182,1,1,'prefs','ucp',165,26,27,'UCP_PREFS_POST','post','');
INSERT INTO `phpbb_modules` VALUES (183,1,1,'prefs','ucp',165,28,29,'UCP_PREFS_VIEW','view','');
INSERT INTO `phpbb_modules` VALUES (184,1,1,'profile','ucp',164,14,15,'UCP_PROFILE_PROFILE_INFO','profile_info','');
INSERT INTO `phpbb_modules` VALUES (185,1,1,'profile','ucp',164,16,17,'UCP_PROFILE_SIGNATURE','signature','');
INSERT INTO `phpbb_modules` VALUES (186,1,1,'profile','ucp',164,18,19,'UCP_PROFILE_AVATAR','avatar','');
INSERT INTO `phpbb_modules` VALUES (187,1,1,'profile','ucp',164,20,21,'UCP_PROFILE_REG_DETAILS','reg_details','');
INSERT INTO `phpbb_modules` VALUES (188,1,1,'zebra','ucp',168,50,51,'UCP_ZEBRA_FRIENDS','friends','');
INSERT INTO `phpbb_modules` VALUES (189,1,1,'zebra','ucp',168,52,53,'UCP_ZEBRA_FOES','foes','');

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_poll_options
#

DROP TABLE IF EXISTS `phpbb_poll_options`;
CREATE TABLE `phpbb_poll_options` (
  `poll_option_id` tinyint(4) NOT NULL default '0',
  `topic_id` mediumint(8) unsigned NOT NULL default '0',
  `poll_option_text` text collate utf8_bin NOT NULL,
  `poll_option_total` mediumint(8) unsigned NOT NULL default '0',
  KEY `poll_opt_id` (`poll_option_id`),
  KEY `topic_id` (`topic_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_poll_options
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_poll_votes
#

DROP TABLE IF EXISTS `phpbb_poll_votes`;
CREATE TABLE `phpbb_poll_votes` (
  `topic_id` mediumint(8) unsigned NOT NULL default '0',
  `poll_option_id` tinyint(4) NOT NULL default '0',
  `vote_user_id` mediumint(8) unsigned NOT NULL default '0',
  `vote_user_ip` varchar(40) collate utf8_bin NOT NULL default '',
  KEY `topic_id` (`topic_id`),
  KEY `vote_user_id` (`vote_user_id`),
  KEY `vote_user_ip` (`vote_user_ip`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_poll_votes
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_posts
#

DROP TABLE IF EXISTS `phpbb_posts`;
CREATE TABLE `phpbb_posts` (
  `post_id` mediumint(8) unsigned NOT NULL auto_increment,
  `topic_id` mediumint(8) unsigned NOT NULL default '0',
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `poster_id` mediumint(8) unsigned NOT NULL default '0',
  `icon_id` mediumint(8) unsigned NOT NULL default '0',
  `poster_ip` varchar(40) collate utf8_bin NOT NULL default '',
  `post_time` int(11) unsigned NOT NULL default '0',
  `post_approved` tinyint(1) unsigned NOT NULL default '1',
  `post_reported` tinyint(1) unsigned NOT NULL default '0',
  `enable_bbcode` tinyint(1) unsigned NOT NULL default '1',
  `enable_smilies` tinyint(1) unsigned NOT NULL default '1',
  `enable_magic_url` tinyint(1) unsigned NOT NULL default '1',
  `enable_sig` tinyint(1) unsigned NOT NULL default '1',
  `post_username` varchar(255) collate utf8_bin NOT NULL default '',
  `post_subject` varchar(100) character set utf8 collate utf8_unicode_ci NOT NULL default '',
  `post_text` mediumtext collate utf8_bin NOT NULL,
  `post_checksum` varchar(32) collate utf8_bin NOT NULL default '',
  `post_attachment` tinyint(1) unsigned NOT NULL default '0',
  `bbcode_bitfield` varchar(255) collate utf8_bin NOT NULL default '',
  `bbcode_uid` varchar(8) collate utf8_bin NOT NULL default '',
  `post_postcount` tinyint(1) unsigned NOT NULL default '1',
  `post_edit_time` int(11) unsigned NOT NULL default '0',
  `post_edit_reason` varchar(255) collate utf8_bin NOT NULL default '',
  `post_edit_user` mediumint(8) unsigned NOT NULL default '0',
  `post_edit_count` smallint(4) unsigned NOT NULL default '0',
  `post_edit_locked` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`post_id`),
  KEY `forum_id` (`forum_id`),
  KEY `topic_id` (`topic_id`),
  KEY `poster_ip` (`poster_ip`),
  KEY `poster_id` (`poster_id`),
  KEY `post_approved` (`post_approved`),
  KEY `tid_post_time` (`topic_id`,`post_time`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_posts
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_privmsgs
#

DROP TABLE IF EXISTS `phpbb_privmsgs`;
CREATE TABLE `phpbb_privmsgs` (
  `msg_id` mediumint(8) unsigned NOT NULL auto_increment,
  `root_level` mediumint(8) unsigned NOT NULL default '0',
  `author_id` mediumint(8) unsigned NOT NULL default '0',
  `icon_id` mediumint(8) unsigned NOT NULL default '0',
  `author_ip` varchar(40) collate utf8_bin NOT NULL default '',
  `message_time` int(11) unsigned NOT NULL default '0',
  `enable_bbcode` tinyint(1) unsigned NOT NULL default '1',
  `enable_smilies` tinyint(1) unsigned NOT NULL default '1',
  `enable_magic_url` tinyint(1) unsigned NOT NULL default '1',
  `enable_sig` tinyint(1) unsigned NOT NULL default '1',
  `message_subject` varchar(100) collate utf8_bin NOT NULL default '',
  `message_text` mediumtext collate utf8_bin NOT NULL,
  `message_edit_reason` varchar(255) collate utf8_bin NOT NULL default '',
  `message_edit_user` mediumint(8) unsigned NOT NULL default '0',
  `message_attachment` tinyint(1) unsigned NOT NULL default '0',
  `bbcode_bitfield` varchar(255) collate utf8_bin NOT NULL default '',
  `bbcode_uid` varchar(8) collate utf8_bin NOT NULL default '',
  `message_edit_time` int(11) unsigned NOT NULL default '0',
  `message_edit_count` smallint(4) unsigned NOT NULL default '0',
  `to_address` text collate utf8_bin NOT NULL,
  `bcc_address` text collate utf8_bin NOT NULL,
  PRIMARY KEY  (`msg_id`),
  KEY `author_ip` (`author_ip`),
  KEY `message_time` (`message_time`),
  KEY `author_id` (`author_id`),
  KEY `root_level` (`root_level`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_privmsgs
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_privmsgs_folder
#

DROP TABLE IF EXISTS `phpbb_privmsgs_folder`;
CREATE TABLE `phpbb_privmsgs_folder` (
  `folder_id` mediumint(8) unsigned NOT NULL auto_increment,
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `folder_name` varchar(255) collate utf8_bin NOT NULL default '',
  `pm_count` mediumint(8) unsigned NOT NULL default '0',
  PRIMARY KEY  (`folder_id`),
  KEY `user_id` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_privmsgs_folder
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_privmsgs_rules
#

DROP TABLE IF EXISTS `phpbb_privmsgs_rules`;
CREATE TABLE `phpbb_privmsgs_rules` (
  `rule_id` mediumint(8) unsigned NOT NULL auto_increment,
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `rule_check` mediumint(8) unsigned NOT NULL default '0',
  `rule_connection` mediumint(8) unsigned NOT NULL default '0',
  `rule_string` varchar(255) collate utf8_bin NOT NULL default '',
  `rule_user_id` mediumint(8) unsigned NOT NULL default '0',
  `rule_group_id` mediumint(8) unsigned NOT NULL default '0',
  `rule_action` mediumint(8) unsigned NOT NULL default '0',
  `rule_folder_id` int(11) NOT NULL default '0',
  PRIMARY KEY  (`rule_id`),
  KEY `user_id` (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_privmsgs_rules
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_privmsgs_to
#

DROP TABLE IF EXISTS `phpbb_privmsgs_to`;
CREATE TABLE `phpbb_privmsgs_to` (
  `msg_id` mediumint(8) unsigned NOT NULL default '0',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `author_id` mediumint(8) unsigned NOT NULL default '0',
  `pm_deleted` tinyint(1) unsigned NOT NULL default '0',
  `pm_new` tinyint(1) unsigned NOT NULL default '1',
  `pm_unread` tinyint(1) unsigned NOT NULL default '1',
  `pm_replied` tinyint(1) unsigned NOT NULL default '0',
  `pm_marked` tinyint(1) unsigned NOT NULL default '0',
  `pm_forwarded` tinyint(1) unsigned NOT NULL default '0',
  `folder_id` int(11) NOT NULL default '0',
  KEY `msg_id` (`msg_id`),
  KEY `author_id` (`author_id`),
  KEY `usr_flder_id` (`user_id`,`folder_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_privmsgs_to
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_profile_fields
#

DROP TABLE IF EXISTS `phpbb_profile_fields`;
CREATE TABLE `phpbb_profile_fields` (
  `field_id` mediumint(8) unsigned NOT NULL auto_increment,
  `field_name` varchar(255) collate utf8_bin NOT NULL default '',
  `field_type` tinyint(4) NOT NULL default '0',
  `field_ident` varchar(20) collate utf8_bin NOT NULL default '',
  `field_length` varchar(20) collate utf8_bin NOT NULL default '',
  `field_minlen` varchar(255) collate utf8_bin NOT NULL default '',
  `field_maxlen` varchar(255) collate utf8_bin NOT NULL default '',
  `field_novalue` varchar(255) collate utf8_bin NOT NULL default '',
  `field_default_value` varchar(255) collate utf8_bin NOT NULL default '',
  `field_validation` varchar(20) collate utf8_bin NOT NULL default '',
  `field_required` tinyint(1) unsigned NOT NULL default '0',
  `field_show_on_reg` tinyint(1) unsigned NOT NULL default '0',
  `field_hide` tinyint(1) unsigned NOT NULL default '0',
  `field_no_view` tinyint(1) unsigned NOT NULL default '0',
  `field_active` tinyint(1) unsigned NOT NULL default '0',
  `field_order` mediumint(8) unsigned NOT NULL default '0',
  PRIMARY KEY  (`field_id`),
  KEY `fld_type` (`field_type`),
  KEY `fld_ordr` (`field_order`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_profile_fields
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_profile_fields_data
#

DROP TABLE IF EXISTS `phpbb_profile_fields_data`;
CREATE TABLE `phpbb_profile_fields_data` (
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  PRIMARY KEY  (`user_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_profile_fields_data
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_profile_fields_lang
#

DROP TABLE IF EXISTS `phpbb_profile_fields_lang`;
CREATE TABLE `phpbb_profile_fields_lang` (
  `field_id` mediumint(8) unsigned NOT NULL default '0',
  `lang_id` mediumint(8) unsigned NOT NULL default '0',
  `option_id` mediumint(8) unsigned NOT NULL default '0',
  `field_type` tinyint(4) NOT NULL default '0',
  `lang_value` varchar(255) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`field_id`,`lang_id`,`option_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_profile_fields_lang
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_profile_lang
#

DROP TABLE IF EXISTS `phpbb_profile_lang`;
CREATE TABLE `phpbb_profile_lang` (
  `field_id` mediumint(8) unsigned NOT NULL default '0',
  `lang_id` mediumint(8) unsigned NOT NULL default '0',
  `lang_name` varchar(255) collate utf8_bin NOT NULL default '',
  `lang_explain` text collate utf8_bin NOT NULL,
  `lang_default_value` varchar(255) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`field_id`,`lang_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_profile_lang
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_ranks
#

DROP TABLE IF EXISTS `phpbb_ranks`;
CREATE TABLE `phpbb_ranks` (
  `rank_id` mediumint(8) unsigned NOT NULL auto_increment,
  `rank_title` varchar(255) collate utf8_bin NOT NULL default '',
  `rank_min` mediumint(8) unsigned NOT NULL default '0',
  `rank_special` tinyint(1) unsigned NOT NULL default '0',
  `rank_image` varchar(255) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`rank_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_ranks
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_ranks` VALUES (1,'Site Admin',0,1,'');

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_reports
#

DROP TABLE IF EXISTS `phpbb_reports`;
CREATE TABLE `phpbb_reports` (
  `report_id` mediumint(8) unsigned NOT NULL auto_increment,
  `reason_id` smallint(4) unsigned NOT NULL default '0',
  `post_id` mediumint(8) unsigned NOT NULL default '0',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `user_notify` tinyint(1) unsigned NOT NULL default '0',
  `report_closed` tinyint(1) unsigned NOT NULL default '0',
  `report_time` int(11) unsigned NOT NULL default '0',
  `report_text` mediumtext collate utf8_bin NOT NULL,
  PRIMARY KEY  (`report_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_reports
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_reports_reasons
#

DROP TABLE IF EXISTS `phpbb_reports_reasons`;
CREATE TABLE `phpbb_reports_reasons` (
  `reason_id` smallint(4) unsigned NOT NULL auto_increment,
  `reason_title` varchar(255) collate utf8_bin NOT NULL default '',
  `reason_description` mediumtext collate utf8_bin NOT NULL,
  `reason_order` smallint(4) unsigned NOT NULL default '0',
  PRIMARY KEY  (`reason_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_reports_reasons
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_reports_reasons` VALUES (1,'warez','The post contains links to illegal or pirated software.',1);
INSERT INTO `phpbb_reports_reasons` VALUES (2,'spam','The reported post has the only purpose to advertise for a website or another product.',2);
INSERT INTO `phpbb_reports_reasons` VALUES (3,'off_topic','The reported post is off topic.',3);
INSERT INTO `phpbb_reports_reasons` VALUES (4,'other','The reported post does not fit into any other category, please use the further information field.',4);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_search_results
#

DROP TABLE IF EXISTS `phpbb_search_results`;
CREATE TABLE `phpbb_search_results` (
  `search_key` varchar(32) collate utf8_bin NOT NULL default '',
  `search_time` int(11) unsigned NOT NULL default '0',
  `search_keywords` mediumtext collate utf8_bin NOT NULL,
  `search_authors` mediumtext collate utf8_bin NOT NULL,
  PRIMARY KEY  (`search_key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_search_results
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_search_wordlist
#

DROP TABLE IF EXISTS `phpbb_search_wordlist`;
CREATE TABLE `phpbb_search_wordlist` (
  `word_id` mediumint(8) unsigned NOT NULL auto_increment,
  `word_text` varchar(255) collate utf8_bin NOT NULL default '',
  `word_common` tinyint(1) unsigned NOT NULL default '0',
  `word_count` mediumint(8) unsigned NOT NULL default '0',
  PRIMARY KEY  (`word_id`),
  UNIQUE KEY `wrd_txt` (`word_text`),
  KEY `wrd_cnt` (`word_count`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_search_wordlist
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_search_wordlist` VALUES (1,'this',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (2,'example',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (3,'post',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (4,'your',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (5,'phpbb3',0,2);
INSERT INTO `phpbb_search_wordlist` VALUES (6,'installation',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (7,'everything',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (8,'seems',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (9,'working',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (10,'you',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (11,'may',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (12,'delete',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (13,'like',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (14,'and',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (15,'continue',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (16,'set',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (17,'board',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (18,'during',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (19,'the',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (20,'process',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (21,'first',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (22,'category',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (23,'forum',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (24,'are',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (25,'assigned',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (26,'appropriate',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (27,'permissions',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (28,'for',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (29,'predefined',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (30,'usergroups',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (31,'administrators',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (32,'bots',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (33,'global',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (34,'moderators',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (35,'guests',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (36,'registered',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (37,'users',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (38,'coppa',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (39,'also',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (40,'choose',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (41,'not',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (42,'forget',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (43,'assign',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (44,'all',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (45,'these',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (46,'new',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (47,'categories',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (48,'forums',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (49,'create',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (50,'recommended',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (51,'rename',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (52,'copy',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (53,'from',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (54,'while',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (55,'creating',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (56,'have',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (57,'fun',0,1);
INSERT INTO `phpbb_search_wordlist` VALUES (58,'welcome',0,1);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_search_wordmatch
#

DROP TABLE IF EXISTS `phpbb_search_wordmatch`;
CREATE TABLE `phpbb_search_wordmatch` (
  `post_id` mediumint(8) unsigned NOT NULL default '0',
  `word_id` mediumint(8) unsigned NOT NULL default '0',
  `title_match` tinyint(1) unsigned NOT NULL default '0',
  UNIQUE KEY `unq_mtch` (`word_id`,`post_id`,`title_match`),
  KEY `word_id` (`word_id`),
  KEY `post_id` (`post_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_search_wordmatch
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_search_wordmatch` VALUES (1,1,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,2,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,3,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,4,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,5,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,5,1);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,6,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,7,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,8,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,9,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,10,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,11,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,12,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,13,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,14,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,15,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,16,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,17,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,18,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,19,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,20,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,21,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,22,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,23,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,24,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,25,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,26,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,27,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,28,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,29,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,30,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,31,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,32,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,33,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,34,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,35,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,36,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,37,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,38,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,39,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,40,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,41,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,42,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,43,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,44,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,45,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,46,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,47,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,48,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,49,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,50,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,51,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,52,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,53,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,54,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,55,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,56,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,57,0);
INSERT INTO `phpbb_search_wordmatch` VALUES (1,58,1);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_sessions
#

DROP TABLE IF EXISTS `phpbb_sessions`;
CREATE TABLE `phpbb_sessions` (
  `session_id` char(32) collate utf8_bin NOT NULL default '',
  `session_user_id` mediumint(8) unsigned NOT NULL default '0',
  `session_forum_id` mediumint(8) unsigned NOT NULL default '0',
  `session_last_visit` int(11) unsigned NOT NULL default '0',
  `session_start` int(11) unsigned NOT NULL default '0',
  `session_time` int(11) unsigned NOT NULL default '0',
  `session_ip` varchar(40) collate utf8_bin NOT NULL default '',
  `session_browser` varchar(150) collate utf8_bin NOT NULL default '',
  `session_forwarded_for` varchar(255) collate utf8_bin NOT NULL default '',
  `session_page` varchar(255) collate utf8_bin NOT NULL default '',
  `session_viewonline` tinyint(1) unsigned NOT NULL default '1',
  `session_autologin` tinyint(1) unsigned NOT NULL default '0',
  `session_admin` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`session_id`),
  KEY `session_time` (`session_time`),
  KEY `session_user_id` (`session_user_id`),
  KEY `session_forum_id` (`session_forum_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_sessions
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_sessions` VALUES ('1fb1dbb44d1138381b369e0a53cbd7bc',54,0,1219011128,1219011127,1219011127,'127.0.0.1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2; MAXTHON 2.0)','','../register_forum.php',1,0,0);
INSERT INTO `phpbb_sessions` VALUES ('4b8706f6e688de0f3b455b729f7d3e0b',2,0,1219067436,1219067436,1219067436,'127.0.0.1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)','','ucp.php?mode=login',1,0,0);
INSERT INTO `phpbb_sessions` VALUES ('5cf5d8960ce41075316ef5c2bda46c38',2,0,1213196054,1213196054,1213196089,'84.53.238.18','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; MRA 5.1 (build 02198); SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPat','','adm/index.php',1,0,1);
INSERT INTO `phpbb_sessions` VALUES ('7e7800bbf52695a866f99f5061fa00e3',53,0,1219007062,1219007061,1219007061,'127.0.0.1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2; MAXTHON 2.0)','','../register_forum.php',1,0,0);
INSERT INTO `phpbb_sessions` VALUES ('88f290549899b202af89c44eae926187',2,0,1219066355,1219066354,1219071090,'127.0.0.1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2; MAXTHON 2.0)','','adm/index.php?i=forums&icat=7&mode=manage&parent_id=5',1,0,0);
INSERT INTO `phpbb_sessions` VALUES ('8ba397d67839d6906e8cdc485cf7954c',53,0,1219007725,1219007725,1219015369,'127.0.0.1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2; MAXTHON 2.0)','','forum',1,0,0);
INSERT INTO `phpbb_sessions` VALUES ('af983a69d3373ef5db70f3f3bc94d97e',1,0,1213196054,1213196054,1213196054,'84.53.238.18','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; MRA 5.1 (build 02198); SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPat','','install/index.php?mode=install&sub=final',1,0,0);
INSERT INTO `phpbb_sessions` VALUES ('b9b5266b48fb0528d0eed613e68d2740',55,0,1219070191,1219070191,1219070191,'127.0.0.1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)','','../register_forum.php',1,0,0);
INSERT INTO `phpbb_sessions` VALUES ('da076f2774b05fa088a4bfc9da1d0b3e',1,0,1219067703,1219067703,1219067703,'127.0.0.1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)','','adm/index.php?i=forums&icat=7&mode=manage&parent_id=4',1,0,0);
INSERT INTO `phpbb_sessions` VALUES ('ec0ad220122d81d207117b069bc7f558',53,0,1219054526,1219054526,1219054526,'127.0.0.1','Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; SLCC1; .NET CLR 2.0.50727; Media Center PC 5.0; .NET CLR 3.0.04506; InfoPath.2)','','../authenticate_forum.php',1,0,0);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_sessions_keys
#

DROP TABLE IF EXISTS `phpbb_sessions_keys`;
CREATE TABLE `phpbb_sessions_keys` (
  `key_id` char(32) collate utf8_bin NOT NULL default '',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `last_ip` varchar(40) collate utf8_bin NOT NULL default '',
  `last_login` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`key_id`,`user_id`),
  KEY `last_login` (`last_login`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_sessions_keys
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_sitelist
#

DROP TABLE IF EXISTS `phpbb_sitelist`;
CREATE TABLE `phpbb_sitelist` (
  `site_id` mediumint(8) unsigned NOT NULL auto_increment,
  `site_ip` varchar(40) collate utf8_bin NOT NULL default '',
  `site_hostname` varchar(255) collate utf8_bin NOT NULL default '',
  `ip_exclude` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`site_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_sitelist
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_smilies
#

DROP TABLE IF EXISTS `phpbb_smilies`;
CREATE TABLE `phpbb_smilies` (
  `smiley_id` mediumint(8) unsigned NOT NULL auto_increment,
  `code` varchar(50) collate utf8_bin NOT NULL default '',
  `emotion` varchar(50) collate utf8_bin NOT NULL default '',
  `smiley_url` varchar(50) collate utf8_bin NOT NULL default '',
  `smiley_width` smallint(4) unsigned NOT NULL default '0',
  `smiley_height` smallint(4) unsigned NOT NULL default '0',
  `smiley_order` mediumint(8) unsigned NOT NULL default '0',
  `display_on_posting` tinyint(1) unsigned NOT NULL default '1',
  PRIMARY KEY  (`smiley_id`),
  KEY `display_on_post` (`display_on_posting`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_smilies
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_smilies` VALUES (1,':D','Very Happy','icon_e_biggrin.gif',15,17,1,1);
INSERT INTO `phpbb_smilies` VALUES (2,':-D','Very Happy','icon_e_biggrin.gif',15,17,2,1);
INSERT INTO `phpbb_smilies` VALUES (3,':grin:','Very Happy','icon_e_biggrin.gif',15,17,3,1);
INSERT INTO `phpbb_smilies` VALUES (4,':)','Smile','icon_e_smile.gif',15,17,4,1);
INSERT INTO `phpbb_smilies` VALUES (5,':-)','Smile','icon_e_smile.gif',15,17,5,1);
INSERT INTO `phpbb_smilies` VALUES (6,':smile:','Smile','icon_e_smile.gif',15,17,6,1);
INSERT INTO `phpbb_smilies` VALUES (7,';)','Wink','icon_e_wink.gif',15,17,7,1);
INSERT INTO `phpbb_smilies` VALUES (8,';-)','Wink','icon_e_wink.gif',15,17,8,1);
INSERT INTO `phpbb_smilies` VALUES (9,':wink:','Wink','icon_e_wink.gif',15,17,9,1);
INSERT INTO `phpbb_smilies` VALUES (10,':(','Sad','icon_e_sad.gif',15,17,10,1);
INSERT INTO `phpbb_smilies` VALUES (11,':-(','Sad','icon_e_sad.gif',15,17,11,1);
INSERT INTO `phpbb_smilies` VALUES (12,':sad:','Sad','icon_e_sad.gif',15,17,12,1);
INSERT INTO `phpbb_smilies` VALUES (13,':o','Surprised','icon_e_surprised.gif',15,17,13,1);
INSERT INTO `phpbb_smilies` VALUES (14,':-o','Surprised','icon_e_surprised.gif',15,17,14,1);
INSERT INTO `phpbb_smilies` VALUES (15,':eek:','Surprised','icon_e_surprised.gif',15,17,15,1);
INSERT INTO `phpbb_smilies` VALUES (16,':shock:','Shocked','icon_eek.gif',15,17,16,1);
INSERT INTO `phpbb_smilies` VALUES (17,':?','Confused','icon_e_confused.gif',15,17,17,1);
INSERT INTO `phpbb_smilies` VALUES (18,':-?','Confused','icon_e_confused.gif',15,17,18,1);
INSERT INTO `phpbb_smilies` VALUES (19,':???:','Confused','icon_e_confused.gif',15,17,19,1);
INSERT INTO `phpbb_smilies` VALUES (20,'8-)','Cool','icon_cool.gif',15,17,20,1);
INSERT INTO `phpbb_smilies` VALUES (21,':cool:','Cool','icon_cool.gif',15,17,21,1);
INSERT INTO `phpbb_smilies` VALUES (22,':lol:','Laughing','icon_lol.gif',15,17,22,1);
INSERT INTO `phpbb_smilies` VALUES (23,':x','Mad','icon_mad.gif',15,17,23,1);
INSERT INTO `phpbb_smilies` VALUES (24,':-x','Mad','icon_mad.gif',15,17,24,1);
INSERT INTO `phpbb_smilies` VALUES (25,':mad:','Mad','icon_mad.gif',15,17,25,1);
INSERT INTO `phpbb_smilies` VALUES (26,':P','Razz','icon_razz.gif',15,17,26,1);
INSERT INTO `phpbb_smilies` VALUES (27,':-P','Razz','icon_razz.gif',15,17,27,1);
INSERT INTO `phpbb_smilies` VALUES (28,':razz:','Razz','icon_razz.gif',15,17,28,1);
INSERT INTO `phpbb_smilies` VALUES (29,':oops:','Embarrassed','icon_redface.gif',15,17,29,1);
INSERT INTO `phpbb_smilies` VALUES (30,':cry:','Crying or Very Sad','icon_cry.gif',15,17,30,1);
INSERT INTO `phpbb_smilies` VALUES (31,':evil:','Evil or Very Mad','icon_evil.gif',15,17,31,1);
INSERT INTO `phpbb_smilies` VALUES (32,':twisted:','Twisted Evil','icon_twisted.gif',15,17,32,1);
INSERT INTO `phpbb_smilies` VALUES (33,':roll:','Rolling Eyes','icon_rolleyes.gif',15,17,33,1);
INSERT INTO `phpbb_smilies` VALUES (34,':!:','Exclamation','icon_exclaim.gif',15,17,34,1);
INSERT INTO `phpbb_smilies` VALUES (35,':?:','Question','icon_question.gif',15,17,35,1);
INSERT INTO `phpbb_smilies` VALUES (36,':idea:','Idea','icon_idea.gif',15,17,36,1);
INSERT INTO `phpbb_smilies` VALUES (37,':arrow:','Arrow','icon_arrow.gif',15,17,37,1);
INSERT INTO `phpbb_smilies` VALUES (38,':|','Neutral','icon_neutral.gif',15,17,38,1);
INSERT INTO `phpbb_smilies` VALUES (39,':-|','Neutral','icon_neutral.gif',15,17,39,1);
INSERT INTO `phpbb_smilies` VALUES (40,':mrgreen:','Mr. Green','icon_mrgreen.gif',15,17,40,1);
INSERT INTO `phpbb_smilies` VALUES (41,':geek:','Geek','icon_e_geek.gif',17,17,41,1);
INSERT INTO `phpbb_smilies` VALUES (42,':ugeek:','Uber Geek','icon_e_ugeek.gif',17,18,42,1);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_styles
#

DROP TABLE IF EXISTS `phpbb_styles`;
CREATE TABLE `phpbb_styles` (
  `style_id` smallint(4) unsigned NOT NULL auto_increment,
  `style_name` varchar(255) collate utf8_bin NOT NULL default '',
  `style_copyright` varchar(255) collate utf8_bin NOT NULL default '',
  `style_active` tinyint(1) unsigned NOT NULL default '1',
  `template_id` smallint(4) unsigned NOT NULL default '0',
  `theme_id` smallint(4) unsigned NOT NULL default '0',
  `imageset_id` smallint(4) unsigned NOT NULL default '0',
  PRIMARY KEY  (`style_id`),
  UNIQUE KEY `style_name` (`style_name`),
  KEY `template_id` (`template_id`),
  KEY `theme_id` (`theme_id`),
  KEY `imageset_id` (`imageset_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_styles
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_styles` VALUES (1,'prosilver','&copy; phpBB Group',1,1,1,1);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_styles_imageset
#

DROP TABLE IF EXISTS `phpbb_styles_imageset`;
CREATE TABLE `phpbb_styles_imageset` (
  `imageset_id` smallint(4) unsigned NOT NULL auto_increment,
  `imageset_name` varchar(255) collate utf8_bin NOT NULL default '',
  `imageset_copyright` varchar(255) collate utf8_bin NOT NULL default '',
  `imageset_path` varchar(100) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`imageset_id`),
  UNIQUE KEY `imgset_nm` (`imageset_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_styles_imageset
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_styles_imageset` VALUES (1,'prosilver','&copy; phpBB Group','prosilver');

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_styles_imageset_data
#

DROP TABLE IF EXISTS `phpbb_styles_imageset_data`;
CREATE TABLE `phpbb_styles_imageset_data` (
  `image_id` smallint(4) unsigned NOT NULL auto_increment,
  `image_name` varchar(200) collate utf8_bin NOT NULL default '',
  `image_filename` varchar(200) collate utf8_bin NOT NULL default '',
  `image_lang` varchar(30) collate utf8_bin NOT NULL default '',
  `image_height` smallint(4) unsigned NOT NULL default '0',
  `image_width` smallint(4) unsigned NOT NULL default '0',
  `imageset_id` smallint(4) unsigned NOT NULL default '0',
  PRIMARY KEY  (`image_id`),
  KEY `i_d` (`imageset_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_styles_imageset_data
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_styles_imageset_data` VALUES (1,'site_logo','site_logo.gif','',52,139,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (2,'forum_link','forum_link.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (3,'forum_read','forum_read.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (4,'forum_read_locked','forum_read_locked.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (5,'forum_read_subforum','forum_read_subforum.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (6,'forum_unread','forum_unread.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (7,'forum_unread_locked','forum_unread_locked.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (8,'forum_unread_subforum','forum_unread_subforum.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (9,'topic_moved','topic_moved.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (10,'topic_read','topic_read.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (11,'topic_read_mine','topic_read_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (12,'topic_read_hot','topic_read_hot.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (13,'topic_read_hot_mine','topic_read_hot_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (14,'topic_read_locked','topic_read_locked.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (15,'topic_read_locked_mine','topic_read_locked_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (16,'topic_unread','topic_unread.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (17,'topic_unread_mine','topic_unread_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (18,'topic_unread_hot','topic_unread_hot.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (19,'topic_unread_hot_mine','topic_unread_hot_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (20,'topic_unread_locked','topic_unread_locked.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (21,'topic_unread_locked_mine','topic_unread_locked_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (22,'sticky_read','sticky_read.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (23,'sticky_read_mine','sticky_read_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (24,'sticky_read_locked','sticky_read_locked.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (25,'sticky_read_locked_mine','sticky_read_locked_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (26,'sticky_unread','sticky_unread.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (27,'sticky_unread_mine','sticky_unread_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (28,'sticky_unread_locked','sticky_unread_locked.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (29,'sticky_unread_locked_mine','sticky_unread_locked_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (30,'announce_read','announce_read.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (31,'announce_read_mine','announce_read_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (32,'announce_read_locked','announce_read_locked.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (33,'announce_read_locked_mine','announce_read_locked_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (34,'announce_unread','announce_unread.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (35,'announce_unread_mine','announce_unread_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (36,'announce_unread_locked','announce_unread_locked.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (37,'announce_unread_locked_mine','announce_unread_locked_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (38,'global_read','announce_read.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (39,'global_read_mine','announce_read_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (40,'global_read_locked','announce_read_locked.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (41,'global_read_locked_mine','announce_read_locked_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (42,'global_unread','announce_unread.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (43,'global_unread_mine','announce_unread_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (44,'global_unread_locked','announce_unread_locked.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (45,'global_unread_locked_mine','announce_unread_locked_mine.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (46,'pm_read','topic_read.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (47,'pm_unread','topic_unread.gif','',27,27,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (48,'icon_back_top','icon_back_top.gif','',11,11,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (49,'icon_contact_aim','icon_contact_aim.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (50,'icon_contact_email','icon_contact_email.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (51,'icon_contact_icq','icon_contact_icq.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (52,'icon_contact_jabber','icon_contact_jabber.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (53,'icon_contact_msnm','icon_contact_msnm.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (54,'icon_contact_www','icon_contact_www.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (55,'icon_contact_yahoo','icon_contact_yahoo.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (56,'icon_post_delete','icon_post_delete.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (57,'icon_post_info','icon_post_info.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (58,'icon_post_report','icon_post_report.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (59,'icon_post_target','icon_post_target.gif','',9,11,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (60,'icon_post_target_unread','icon_post_target_unread.gif','',9,11,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (61,'icon_topic_attach','icon_topic_attach.gif','',10,7,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (62,'icon_topic_latest','icon_topic_latest.gif','',9,11,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (63,'icon_topic_newest','icon_topic_newest.gif','',9,11,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (64,'icon_topic_reported','icon_topic_reported.gif','',14,16,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (65,'icon_topic_unapproved','icon_topic_unapproved.gif','',14,16,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (66,'icon_user_warn','icon_user_warn.gif','',20,20,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (67,'subforum_read','subforum_read.gif','',9,11,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (68,'subforum_unread','subforum_unread.gif','',9,11,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (69,'icon_contact_pm','icon_contact_pm.gif','en',20,28,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (70,'icon_post_edit','icon_post_edit.gif','en',20,42,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (71,'icon_post_quote','icon_post_quote.gif','en',20,54,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (72,'icon_user_online','icon_user_online.gif','en',58,58,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (73,'button_pm_forward','button_pm_forward.gif','en',25,96,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (74,'button_pm_new','button_pm_new.gif','en',25,84,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (75,'button_pm_reply','button_pm_reply.gif','en',25,96,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (76,'button_topic_locked','button_topic_locked.gif','en',25,88,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (77,'button_topic_new','button_topic_new.gif','en',25,96,1);
INSERT INTO `phpbb_styles_imageset_data` VALUES (78,'button_topic_reply','button_topic_reply.gif','en',25,96,1);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_styles_template
#

DROP TABLE IF EXISTS `phpbb_styles_template`;
CREATE TABLE `phpbb_styles_template` (
  `template_id` smallint(4) unsigned NOT NULL auto_increment,
  `template_name` varchar(255) collate utf8_bin NOT NULL default '',
  `template_copyright` varchar(255) collate utf8_bin NOT NULL default '',
  `template_path` varchar(100) collate utf8_bin NOT NULL default '',
  `bbcode_bitfield` varchar(255) collate utf8_bin NOT NULL default 'kNg=',
  `template_storedb` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`template_id`),
  UNIQUE KEY `tmplte_nm` (`template_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_styles_template
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_styles_template` VALUES (1,'prosilver','&copy; phpBB Group','prosilver','lNg=',0);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_styles_template_data
#

DROP TABLE IF EXISTS `phpbb_styles_template_data`;
CREATE TABLE `phpbb_styles_template_data` (
  `template_id` smallint(4) unsigned NOT NULL default '0',
  `template_filename` varchar(100) collate utf8_bin NOT NULL default '',
  `template_included` text collate utf8_bin NOT NULL,
  `template_mtime` int(11) unsigned NOT NULL default '0',
  `template_data` mediumtext collate utf8_bin NOT NULL,
  KEY `tid` (`template_id`),
  KEY `tfn` (`template_filename`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_styles_template_data
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_styles_theme
#

DROP TABLE IF EXISTS `phpbb_styles_theme`;
CREATE TABLE `phpbb_styles_theme` (
  `theme_id` smallint(4) unsigned NOT NULL auto_increment,
  `theme_name` varchar(255) collate utf8_bin NOT NULL default '',
  `theme_copyright` varchar(255) collate utf8_bin NOT NULL default '',
  `theme_path` varchar(100) collate utf8_bin NOT NULL default '',
  `theme_storedb` tinyint(1) unsigned NOT NULL default '0',
  `theme_mtime` int(11) unsigned NOT NULL default '0',
  `theme_data` mediumtext collate utf8_bin NOT NULL,
  PRIMARY KEY  (`theme_id`),
  UNIQUE KEY `theme_name` (`theme_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_styles_theme
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_styles_theme` VALUES (1,'prosilver','&copy; phpBB Group','prosilver',1,1219015370,'/*  phpBB 3.0 Style Sheet\n    --------------------------------------------------------------\n	Style name:		proSilver\n	Based on style:	proSilver (this is the default phpBB 3 style)\n	Original author:	subBlue ( http://www.subBlue.com/ )\n	Modified by:		\n	\n	Copyright 2006 phpBB Group ( http://www.phpbb.com/ )\n    --------------------------------------------------------------\n*/\n\n/* General proSilver Markup Styles\n---------------------------------------- */\n\n* {\n	/* Reset browsers default margin, padding and font sizes */\n	margin: 0;\n	padding: 0;\n}\n\nhtml {\n	font-size: 100%;\n	/* Always show a scrollbar for short pages - stops the jump when the scrollbar appears. non-IE browsers */\n	height: 100%;\n	margin-bottom: 1px;\n}\n\nbody {\n	/* Text-Sizing with ems: http://www.clagnut.com/blog/348/ */\n	font-family: Verdana, Helvetica, Arial, sans-serif;\n	color: #828282;\n	background-color: #FFFFFF;\n	/*font-size: 62.5%;			 This sets the default font size to be equivalent to 10px */\n	font-size: 10px;\n	margin: 0;\n	padding: 12px 0;\n}\n\nh1 {\n	/* Forum name */\n	font-family: \"Trebuchet MS\", Arial, Helvetica, sans-serif;\n	margin-right: 200px;\n	color: #FFFFFF;\n	margin-top: 15px;\n	font-weight: bold;\n	font-size: 2em;\n}\n\nh2 {\n	/* Forum header titles */\n	font-family: \"Trebuchet MS\", Arial, Helvetica, sans-serif;\n	font-weight: normal;\n	color: #3f3f3f;\n	font-size: 2em;\n	margin: 0.8em 0 0.2em 0;\n}\n\nh2.solo {\n	margin-bottom: 1em;\n}\n\nh3 {\n	/* Sub-headers (also used as post headers, but defined later) */\n	font-family: Arial, Helvetica, sans-serif;\n	font-weight: bold;\n	text-transform: uppercase;\n	border-bottom: 1px solid #CCCCCC;\n	margin-bottom: 3px;\n	padding-bottom: 2px;\n	font-size: 1.05em;\n	color: #989898;\n	margin-top: 20px;\n}\n\nh4 {\n	/* Forum and topic list titles */\n	font-family: \"Trebuchet MS\", Verdana, Helvetica, Arial, Sans-serif;\n	font-size: 1.3em;\n}\n\np {\n	line-height: 1.3em;\n	font-size: 1.1em;\n	margin-bottom: 1.5em;\n}\n\nimg {\n	border-width: 0;\n}\n\nhr {\n	/* Also see tweaks.css */\n	border: 0 none #FFFFFF;\n	border-top: 1px solid #CCCCCC;\n	height: 1px;\n	margin: 5px 0;\n	display: block;\n	clear: both;\n}\n\nhr.dashed {\n	border-top: 1px dashed #CCCCCC;\n	margin: 10px 0;\n}\n\nhr.divider {\n	display: none;\n}\n\np.right {\n	text-align: right;\n}\n\n/* Main blocks\n---------------------------------------- */\n#wrap {\n	padding: 0 20px;\n	min-width: 650px;\n}\n\n#simple-wrap {\n	padding: 6px 10px;\n}\n\n#page-body {\n	margin: 4px 0;\n	clear: both;\n}\n\n#page-footer {\n	clear: both;\n}\n\n#page-footer h3 {\n	margin-top: 20px;\n}\n\n#logo {\n	float: left;\n	width: auto;\n	padding: 10px 13px 0 10px;\n}\n\na#logo:hover {\n	text-decoration: none;\n}\n\n/* Search box\n--------------------------------------------- */\n#search-box {\n	color: #FFFFFF;\n	position: relative;\n	margin-top: 30px;\n	margin-right: 5px;\n	display: block;\n	float: right;\n	text-align: right;\n	white-space: nowrap; /* For Opera */\n}\n\n#search-box #keywords {\n	width: 95px;\n	background-color: #FFF;\n}\n\n#search-box input {\n	border: 1px solid #b0b0b0;\n}\n\n/* .button1 style defined later, just a few tweaks for the search button version */\n#search-box input.button1 {\n	padding: 1px 5px;\n}\n\n#search-box li {\n	text-align: right;\n	margin-top: 4px;\n}\n\n#search-box img {\n	vertical-align: middle;\n	margin-right: 3px;\n}\n\n/* Site description and logo */\n#site-description {\n	float: left;\n	width: 70%;\n}\n\n#site-description h1 {\n	margin-right: 0;\n}\n\n/* Round cornered boxes and backgrounds\n---------------------------------------- */\n.headerbar {\n	background: #ebebeb none repeat-x 0 0;\n	color: #FFFFFF;\n	margin-bottom: 4px;\n	padding: 0 5px;\n}\n\n.navbar {\n	background-color: #ebebeb;\n	padding: 0 10px;\n}\n\n.forabg {\n	background: #b1b1b1 none repeat-x 0 0;\n	margin-bottom: 4px;\n	padding: 0 5px;\n	clear: both;\n}\n\n.forumbg {\n	background: #ebebeb none repeat-x 0 0;\n	margin-bottom: 4px;\n	padding: 0 5px;\n	clear: both;\n}\n\n.panel {\n	margin-bottom: 4px;\n	padding: 0 10px;\n	background-color: #f3f3f3;\n	color: #3f3f3f;\n}\n\n.post {\n	padding: 0 10px;\n	margin-bottom: 4px;\n	background-repeat: no-repeat;\n	background-position: 100% 0;\n}\n\n.post:target .content {\n	color: #000000;\n}\n\n.post:target h3 a {\n	color: #000000;\n}\n\n.bg1	{ background-color: #f7f7f7;}\n.bg2	{ background-color: #f2f2f2; }\n.bg3	{ background-color: #ebebeb; }\n\n.rowbg {\n	margin: 5px 5px 2px 5px;\n}\n\n.ucprowbg {\n	background-color: #e2e2e2;\n}\n\n.fieldsbg {\n	/*border: 1px #DBDEE2 solid;*/\n	background-color: #eaeaea;\n}\n\nspan.corners-top, span.corners-bottom, span.corners-top span, span.corners-bottom span {\n	font-size: 1px;\n	line-height: 1px;\n	display: block;\n	height: 5px;\n	background-repeat: no-repeat;\n}\n\nspan.corners-top {\n	background-image: none;\n	background-position: 0 0;\n	margin: 0 -5px;\n}\n\nspan.corners-top span {\n	background-image: none;\n	background-position: 100% 0;\n}\n\nspan.corners-bottom {\n	background-image: none;\n	background-position: 0 100%;\n	margin: 0 -5px;\n	clear: both;\n}\n\nspan.corners-bottom span {\n	background-image: none;\n	background-position: 100% 100%;\n}\n\n.headbg span.corners-bottom {\n	margin-bottom: -1px;\n}\n\n.post span.corners-top, .post span.corners-bottom, .panel span.corners-top, .panel span.corners-bottom, .navbar span.corners-top, .navbar span.corners-bottom {\n	margin: 0 -10px;\n}\n\n.rules span.corners-top {\n	margin: 0 -10px 5px -10px;\n}\n\n.rules span.corners-bottom {\n	margin: 5px -10px 0 -10px;\n}\n\n/* Horizontal lists\n----------------------------------------*/\nul.linklist {\n	display: block;\n	margin: 0;\n}\n\nul.linklist li {\n	display: block;\n	list-style-type: none;\n	float: left;\n	width: auto;\n	margin-right: 5px;\n	font-size: 1.1em;\n	line-height: 2.2em;\n}\n\nul.linklist li.rightside, p.rightside {\n	float: right;\n	margin-right: 0;\n	margin-left: 5px;\n	text-align: right;\n}\n\nul.navlinks {\n	padding-bottom: 1px;\n	margin-bottom: 1px;\n	border-bottom: 1px solid #FFFFFF;\n	font-weight: bold;\n}\n\nul.leftside {\n	float: left;\n	margin-left: 0;\n	margin-right: 5px;\n	text-align: left;\n}\n\nul.rightside {\n	float: right;\n	margin-left: 5px;\n	margin-right: -5px;\n	text-align: right;\n}\n\n/* Table styles\n----------------------------------------*/\ntable.table1 {\n	/* See tweaks.css */\n}\n\n#ucp-main table.table1 {\n	padding: 2px;\n}\n\ntable.table1 thead th {\n	font-weight: normal;\n	text-transform: uppercase;\n	color: #FFFFFF;\n	line-height: 1.3em;\n	font-size: 1em;\n	padding: 0 0 4px 3px;\n}\n\ntable.table1 thead th span {\n	padding-left: 7px;\n}\n\ntable.table1 tbody tr {\n	border: 1px solid #cfcfcf;\n}\n\ntable.table1 tbody tr:hover, table.table1 tbody tr.hover {\n	background-color: #f6f6f6;\n	color: #000;\n}\n\ntable.table1 td {\n	color: #6a6a6a;\n	font-size: 1.1em;\n}\n\ntable.table1 tbody td {\n	padding: 5px;\n	border-top: 1px solid #FAFAFA;\n}\n\ntable.table1 tbody th {\n	padding: 5px;\n	border-bottom: 1px solid #000000;\n	text-align: left;\n	color: #333333;\n	background-color: #FFFFFF;\n}\n\n/* Specific column styles */\ntable.table1 .name		{ text-align: left; }\ntable.table1 .posts		{ text-align: center !important; width: 7%; }\ntable.table1 .joined	{ text-align: left; width: 15%; }\ntable.table1 .active	{ text-align: left; width: 15%; }\ntable.table1 .mark		{ text-align: center; width: 7%; }\ntable.table1 .info		{ text-align: left; width: 30%; }\ntable.table1 .info div	{ width: 100%; white-space: nowrap; overflow: hidden; }\ntable.table1 .autocol	{ line-height: 2em; white-space: nowrap; }\ntable.table1 thead .autocol { padding-left: 1em; }\n\ntable.table1 span.rank-img {\n	float: right;\n	width: auto;\n}\n\ntable.info td {\n	padding: 3px;\n}\n\ntable.info tbody th {\n	padding: 3px;\n	text-align: right;\n	vertical-align: top;\n	color: #000000;\n	font-weight: normal;\n}\n\n.forumbg table.table1 {\n	margin: 0 -2px -1px -1px;\n}\n\n/* Misc layout styles\n---------------------------------------- */\n/* column[1-2] styles are containers for two column layouts \n   Also see tweaks.css */\n.column1 {\n	float: left;\n	clear: left;\n	width: 49%;\n}\n\n.column2 {\n	float: right;\n	clear: right;\n	width: 49%;\n}\n\n/* General classes for placing floating blocks */\n.left-box {\n	float: left;\n	width: auto;\n	text-align: left;\n}\n\n.right-box {\n	float: right;\n	width: auto;\n	text-align: right;\n}\n\ndl.details {\n	/*font-family: \"Lucida Grande\", Verdana, Helvetica, Arial, sans-serif;*/\n	font-size: 1.1em;\n}\n\ndl.details dt {\n	float: left;\n	clear: left;\n	width: 30%;\n	text-align: right;\n	color: #000000;\n	display: block;\n}\n\ndl.details dd {\n	margin-left: 0;\n	padding-left: 5px;\n	margin-bottom: 5px;\n	color: #828282;\n	float: left;\n	width: 65%;\n}\n\n/* Pagination\n---------------------------------------- */\n.pagination {\n	height: 1%; /* IE tweak (holly hack) */\n	width: auto;\n	text-align: right;\n	margin-top: 5px;\n	float: right;\n}\n\n.pagination span.page-sep {\n	display: none;\n}\n\nli.pagination {\n	margin-top: 0;\n}\n\n.pagination strong, .pagination b {\n	font-weight: normal;\n}\n\n.pagination span strong {\n	padding: 0 2px;\n	margin: 0 2px;\n	font-weight: normal;\n	color: #FFFFFF;\n	background-color: #bfbfbf;\n	border: 1px solid #bfbfbf;\n	font-size: 0.9em;\n}\n\n.pagination span a, .pagination span a:link, .pagination span a:visited, .pagination span a:active {\n	font-weight: normal;\n	text-decoration: none;\n	color: #747474;\n	margin: 0 2px;\n	padding: 0 2px;\n	background-color: #eeeeee;\n	border: 1px solid #bababa;\n	font-size: 0.9em;\n	line-height: 1.5em;\n}\n\n.pagination span a:hover {\n	border-color: #d2d2d2;\n	background-color: #d2d2d2;\n	color: #FFF;\n	text-decoration: none;\n}\n\n.pagination img {\n	vertical-align: middle;\n}\n\n/* Pagination in viewforum for multipage topics */\n.row .pagination {\n	display: block;\n	float: right;\n	width: auto;\n	margin-top: 0;\n	padding: 1px 0 1px 15px;\n	font-size: 0.9em;\n	background: none 0 50% no-repeat;\n}\n\n.row .pagination span a, li.pagination span a {\n	background-color: #FFFFFF;\n}\n\n.row .pagination span a:hover, li.pagination span a:hover {\n	background-color: #d2d2d2;\n}\n\n/* Miscellaneous styles\n---------------------------------------- */\n#forum-permissions {\n	float: right;\n	width: auto;\n	padding-left: 5px;\n	margin-left: 5px;\n	margin-top: 10px;\n	text-align: right;\n}\n\n.copyright {\n	padding: 5px;\n	text-align: center;\n	color: #555555;\n}\n\n.small {\n	font-size: 0.9em !important;\n}\n\n.titlespace {\n	margin-bottom: 15px;\n}\n\n.headerspace {\n	margin-top: 20px;\n}\n\n.error {\n	color: #bcbcbc;\n	font-weight: bold;\n	font-size: 1em;\n}\n\n.reported {\n	background-color: #f7f7f7;\n}\n\nli.reported:hover {\n	background-color: #ececec;\n}\n\ndiv.rules {\n	background-color: #ececec;\n	color: #bcbcbc;\n	padding: 0 10px;\n	margin: 10px 0;\n	font-size: 1.1em;\n}\n\ndiv.rules ul {\n	margin-left: 20px;\n}\n\np.rules {\n	background-color: #ececec;\n	background-image: none;\n	padding: 5px;\n}\n\np.rules img {\n	vertical-align: middle;\n}\n\np.rules a {\n	vertical-align: middle;\n	clear: both;\n}\n\n#top {\n	position: absolute;\n	top: -20px;\n}\n\n.clear {\n	display: block;\n	clear: both;\n	font-size: 1px;\n	line-height: 1px;\n	background: transparent;\n}\n/* proSilver Link Styles\n---------------------------------------- */\n\na:link	{ color: #898989; text-decoration: none; }\na:visited	{ color: #898989; text-decoration: none; }\na:hover	{ color: #d3d3d3; text-decoration: underline; }\na:active	{ color: #d2d2d2; text-decoration: none; }\n\n/* Coloured usernames */\n.username-coloured {\n	font-weight: bold;\n	display: inline !important;\n}\n\n/* Links on gradient backgrounds */\n#search-box a:link, .navbg a:link, .forumbg .header a:link, .forabg .header a:link, th a:link {\n	color: #FFFFFF;\n	text-decoration: none;\n}\n\n#search-box a:visited, .navbg a:visited, .forumbg .header a:visited, .forabg .header a:visited, th a:visited {\n	color: #FFFFFF;\n	text-decoration: none;\n}\n\n#search-box a:hover, .navbg a:hover, .forumbg .header a:hover, .forabg .header a:hover, th a:hover {\n	color: #ffffff;\n	text-decoration: underline;\n}\n\n#search-box a:active, .navbg a:active, .forumbg .header a:active, .forabg .header a:active, th a:active {\n	color: #ffffff;\n	text-decoration: none;\n}\n\n/* Links for forum/topic lists */\na.forumtitle {\n	font-family: \"Trebuchet MS\", Helvetica, Arial, Sans-serif;\n	font-size: 1.2em;\n	font-weight: bold;\n	color: #898989;\n	text-decoration: none;\n}\n\n/* a.forumtitle:visited { color: #898989; } */\n\na.forumtitle:hover {\n	color: #bcbcbc;\n	text-decoration: underline;\n}\n\na.forumtitle:active {\n	color: #898989;\n}\n\na.topictitle {\n	font-family: \"Trebuchet MS\", Helvetica, Arial, Sans-serif;\n	font-size: 1.2em;\n	font-weight: bold;\n	color: #898989;\n	text-decoration: none;\n}\n\n/* a.topictitle:visited { color: #d2d2d2; } */\n\na.topictitle:hover {\n	color: #bcbcbc;\n	text-decoration: underline;\n}\n\na.topictitle:active {\n	color: #898989;\n}\n\n/* Post body links */\n.postlink {\n	text-decoration: none;\n	color: #d2d2d2;\n	border-bottom: 1px solid #d2d2d2;\n	padding-bottom: 0;\n}\n\n.postlink:visited {\n	color: #bdbdbd;\n	border-bottom-style: dotted;\n	border-bottom-color: #666666;\n}\n\n.postlink:active {\n	color: #d2d2d2;\n}\n\n.postlink:hover {\n	background-color: #f6f6f6;\n	text-decoration: none;\n	color: #404040;\n}\n\n.signature a, .signature a:visited, .signature a:active, .signature a:hover {\n	border: none;\n	text-decoration: underline;\n	background-color: transparent;\n}\n\n/* Profile links */\n.postprofile a:link, .postprofile a:active, .postprofile a:visited, .postprofile dt.author a {\n	font-weight: bold;\n	color: #898989;\n	text-decoration: none;\n}\n\n.postprofile a:hover, .postprofile dt.author a:hover {\n	text-decoration: underline;\n	color: #d3d3d3;\n}\n\n\n/* Profile searchresults */	\n.search .postprofile a {\n	color: #898989;\n	text-decoration: none; \n	font-weight: normal;\n}\n\n.search .postprofile a:hover {\n	color: #d3d3d3;\n	text-decoration: underline; \n}\n\n/* Back to top of page */\n.back2top {\n	clear: both;\n	height: 11px;\n	text-align: right;\n}\n\na.top {\n	background: none no-repeat top left;\n	text-decoration: none;\n	width: {IMG_ICON_BACK_TOP_WIDTH}px;\n	height: {IMG_ICON_BACK_TOP_HEIGHT}px;\n	display: block;\n	float: right;\n	overflow: hidden;\n	letter-spacing: 1000px;\n	text-indent: 11px;\n}\n\na.top2 {\n	background: none no-repeat 0 50%;\n	text-decoration: none;\n	padding-left: 15px;\n}\n\n/* Arrow links  */\na.up		{ background: none no-repeat left center; }\na.down		{ background: none no-repeat right center; }\na.left		{ background: none no-repeat 3px 60%; }\na.right		{ background: none no-repeat 95% 60%; }\n\na.up, a.up:link, a.up:active, a.up:visited {\n	padding-left: 10px;\n	text-decoration: none;\n	border-bottom-width: 0;\n}\n\na.up:hover {\n	background-position: left top;\n	background-color: transparent;\n}\n\na.down, a.down:link, a.down:active, a.down:visited {\n	padding-right: 10px;\n}\n\na.down:hover {\n	background-position: right bottom;\n	text-decoration: none;\n}\n\na.left, a.left:active, a.left:visited {\n	padding-left: 12px;\n}\n\na.left:hover {\n	color: #d2d2d2;\n	text-decoration: none;\n	background-position: 0 60%;\n}\n\na.right, a.right:active, a.right:visited {\n	padding-right: 12px;\n}\n\na.right:hover {\n	color: #d2d2d2;\n	text-decoration: none;\n	background-position: 100% 60%;\n}\n/* proSilver Content Styles\n---------------------------------------- */\n\nul.topiclist {\n	display: block;\n	list-style-type: none;\n	margin: 0;\n}\n\nul.forums {\n	background: #f9f9f9 none repeat-x 0 0;\n}\n\nul.topiclist li {\n	display: block;\n	list-style-type: none;\n	color: #777777;\n	margin: 0;\n}\n\nul.topiclist dl {\n	position: relative;\n}\n\nul.topiclist li.row dl {\n	padding: 2px 0;\n}\n\nul.topiclist dt {\n	display: block;\n	float: left;\n	width: 50%;\n	font-size: 1.1em;\n	padding-left: 5px;\n	padding-right: 5px;\n}\n\nul.topiclist dd {\n	display: block;\n	float: left;\n	border-left: 1px solid #FFFFFF;\n	padding: 4px 0;\n}\n\nul.topiclist dfn {\n	/* Labels for post/view counts */\n	display: none;\n}\n\nul.topiclist li.row dt a.subforum {\n	background-image: none;\n	background-position: 0 50%;\n	background-repeat: no-repeat;\n	position: relative;\n	white-space: nowrap;\n	padding: 0 0 0 12px;\n}\n\n.forum-image {\n	float: left;\n	padding-top: 5px;\n	margin-right: 5px;\n}\n\nli.row {\n	border-top: 1px solid #FFFFFF;\n	border-bottom: 1px solid #8f8f8f;\n}\n\nli.row strong {\n	font-weight: normal;\n	color: #000000;\n}\n\nli.row:hover {\n	background-color: #f6f6f6;\n}\n\nli.row:hover dd {\n	border-left-color: #CCCCCC;\n}\n\nli.header dt, li.header dd {\n	line-height: 1em;\n	border-left-width: 0;\n	margin: 2px 0 4px 0;\n	color: #FFFFFF;\n	padding-top: 2px;\n	padding-bottom: 2px;\n	font-size: 1em;\n	font-family: Arial, Helvetica, sans-serif;\n	text-transform: uppercase;\n}\n\nli.header dt {\n	font-weight: bold;\n}\n\nli.header dd {\n	margin-left: 1px;\n}\n\nli.header dl.icon {\n	min-height: 0;\n}\n\nli.header dl.icon dt {\n	/* Tweak for headers alignment when folder icon used */\n	padding-left: 0;\n	padding-right: 50px;\n}\n\n/* Forum list column styles */\ndl.icon {\n	min-height: 35px;\n	background-position: 10px 50%;		/* Position of folder icon */\n	background-repeat: no-repeat;\n}\n\ndl.icon dt {\n	padding-left: 45px;					/* Space for folder icon */\n	background-repeat: no-repeat;\n	background-position: 5px 95%;		/* Position of topic icon */\n}\n\ndd.posts, dd.topics, dd.views {\n	width: 8%;\n	text-align: center;\n	line-height: 2.2em;\n	font-size: 1.2em;\n}\n\ndd.lastpost {\n	width: 25%;\n	font-size: 1.1em;\n}\n\ndd.redirect {\n	font-size: 1.1em;\n	line-height: 2.5em;\n}\n\ndd.moderation {\n	font-size: 1.1em;\n}\n\ndd.lastpost span, ul.topiclist dd.searchby span, ul.topiclist dd.info span, ul.topiclist dd.time span, dd.redirect span, dd.moderation span {\n	display: block;\n	padding-left: 5px;\n}\n\ndd.time {\n	width: auto;\n	line-height: 200%;\n	font-size: 1.1em;\n}\n\ndd.extra {\n	width: 12%;\n	line-height: 200%;\n	text-align: center;\n	font-size: 1.1em;\n}\n\ndd.mark {\n	float: right !important;\n	width: 9%;\n	text-align: center;\n	line-height: 200%;\n	font-size: 1.2em;\n}\n\ndd.info {\n	width: 30%;\n}\n\ndd.option {\n	width: 15%;\n	line-height: 200%;\n	text-align: center;\n	font-size: 1.1em;\n}\n\ndd.searchby {\n	width: 47%;\n	font-size: 1.1em;\n	line-height: 1em;\n}\n\nul.topiclist dd.searchextra {\n	margin-left: 5px;\n	padding: 0.2em 0;\n	font-size: 1.1em;\n	color: #333333;\n	border-left: none;\n	clear: both;\n	width: 98%;\n	overflow: hidden;\n}\n\n/* Container for post/reply buttons and pagination */\n.topic-actions {\n	margin-bottom: 3px;\n	font-size: 1.1em;\n	height: 28px;\n	min-height: 28px;\n}\ndiv[class].topic-actions {\n	height: auto;\n}\n\n/* Post body styles\n----------------------------------------*/\n.postbody {\n	padding: 0;\n	line-height: 1.48em;\n	color: #333333;\n	width: 76%;\n	float: left;\n	clear: both;\n}\n\n.postbody .ignore {\n	font-size: 1.1em;\n}\n\n.postbody h3.first {\n	/* The first post on the page uses this */\n	font-size: 1.7em;\n}\n\n.postbody h3 {\n	/* Postbody requires a different h3 format - so change it here */\n	font-size: 1.5em;\n	padding: 2px 0 0 0;\n	margin: 0 0 0.3em 0 !important;\n	text-transform: none;\n	border: none;\n	font-family: \"Trebuchet MS\", Verdana, Helvetica, Arial, sans-serif;\n	line-height: 125%;\n}\n\n.postbody h3 img {\n	/* Also see tweaks.css */\n	vertical-align: bottom;\n}\n\n.postbody .content {\n	font-size: 1.3em;\n}\n\n.search .postbody {\n	width: 68%\n}\n\n/* Topic review panel\n----------------------------------------*/\n#review {\n	margin-top: 2em;\n}\n\n#topicreview {\n	padding-right: 5px;\n	overflow: auto;\n	height: 300px;\n}\n\n#topicreview .postbody {\n	width: auto;\n	float: none;\n	margin: 0;\n	height: auto;\n}\n\n#topicreview .post {\n	height: auto;\n}\n\n#topicreview h2 {\n	border-bottom-width: 0;\n}\n\n/* Content container styles\n----------------------------------------*/\n.content {\n	min-height: 3em;\n	overflow: hidden;\n	line-height: 1.4em;\n	font-family: \"Lucida Grande\", \"Trebuchet MS\", Verdana, Helvetica, Arial, sans-serif;\n	font-size: 1em;\n	color: #333333;\n}\n\n.content h2, .panel h2 {\n	font-weight: normal;\n	color: #989898;\n	border-bottom: 1px solid #CCCCCC;\n	font-size: 1.6em;\n	margin-top: 0.5em;\n	margin-bottom: 0.5em;\n	padding-bottom: 0.5em;\n}\n\n.panel h3 {\n	margin: 0.5em 0;\n}\n\n.panel p {\n	font-size: 1.2em;\n	margin-bottom: 1em;\n	line-height: 1.4em;\n}\n\n.content p {\n	font-family: \"Lucida Grande\", \"Trebuchet MS\", Verdana, Helvetica, Arial, sans-serif;\n	font-size: 1.2em;\n	margin-bottom: 1em;\n	line-height: 1.4em;\n}\n\ndl.faq {\n	font-family: \"Lucida Grande\", Verdana, Helvetica, Arial, sans-serif;\n	font-size: 1.1em;\n	margin-top: 1em;\n	margin-bottom: 2em;\n	line-height: 1.4em;\n}\n\ndl.faq dt {\n	font-weight: bold;\n	color: #333333;\n}\n\n.content dl.faq {\n	font-size: 1.2em;\n	margin-bottom: 0.5em;\n}\n\n.content li {\n	list-style-type: inherit;\n}\n\n.content ul, .content ol {\n	margin-bottom: 1em;\n	margin-left: 3em;\n}\n\n.posthilit {\n	background-color: #f3f3f3;\n	color: #BCBCBC;\n	padding: 0 2px 1px 2px;\n}\n\n.announce, .unreadpost {\n	/* Highlight the announcements & unread posts box */\n	border-left-color: #BCBCBC;\n	border-right-color: #BCBCBC;\n}\n\n/* Post author */\np.author {\n	margin: 0 15em 0.6em 0;\n	padding: 0 0 5px 0;\n	font-family: Verdana, Helvetica, Arial, sans-serif;\n	font-size: 1em;\n	line-height: 1.2em;\n}\n\n/* Post signature */\n.signature {\n	margin-top: 1.5em;\n	padding-top: 0.2em;\n	font-size: 1.1em;\n	border-top: 1px solid #CCCCCC;\n	clear: left;\n	line-height: 140%;\n	overflow: hidden;\n	width: 100%;\n}\n\ndd .signature {\n	margin: 0;\n	padding: 0;\n	clear: none;\n	border: none;\n}\n\n/* Post noticies */\n.notice {\n	font-family: \"Lucida Grande\", Verdana, Helvetica, Arial, sans-serif;\n	width: auto;\n	margin-top: 1.5em;\n	padding-top: 0.2em;\n	font-size: 1em;\n	border-top: 1px dashed #CCCCCC;\n	clear: left;\n	line-height: 130%;\n}\n\n/* Jump to post link for now */\nul.searchresults {\n	list-style: none;\n	text-align: right;\n	clear: both;\n}\n\n/* BB Code styles\n----------------------------------------*/\n/* Quote block */\nblockquote {\n	background: #ebebeb none 6px 8px no-repeat;\n	border: 1px solid #dbdbdb;\n	font-size: 0.95em;\n	margin: 0.5em 1px 0 25px;\n	overflow: hidden;\n	padding: 5px;\n}\n\nblockquote blockquote {\n	/* Nested quotes */\n	background-color: #bababa;\n	font-size: 1em;\n	margin: 0.5em 1px 0 15px;	\n}\n\nblockquote blockquote blockquote {\n	/* Nested quotes */\n	background-color: #e4e4e4;\n}\n\nblockquote cite {\n	/* Username/source of quoter */\n	font-style: normal;\n	font-weight: bold;\n	margin-left: 20px;\n	display: block;\n	font-size: 0.9em;\n}\n\nblockquote cite cite {\n	font-size: 1em;\n}\n\nblockquote.uncited {\n	padding-top: 25px;\n}\n\n/* Code block */\ndl.codebox {\n	padding: 3px;\n	background-color: #FFFFFF;\n	border: 1px solid #d8d8d8;\n	font-size: 1em;\n}\n\ndl.codebox dt {\n	text-transform: uppercase;\n	border-bottom: 1px solid #CCCCCC;\n	margin-bottom: 3px;\n	font-size: 0.8em;\n	font-weight: bold;\n	display: block;\n}\n\nblockquote dl.codebox {\n	margin-left: 0;\n}\n\ndl.codebox code {\n	/* Also see tweaks.css */\n	overflow: auto;\n	display: block;\n	height: auto;\n	max-height: 200px;\n	white-space: normal;\n	padding-top: 5px;\n	font: 0.9em Monaco, \"Andale Mono\",\"Courier New\", Courier, mono;\n	line-height: 1.3em;\n	color: #8b8b8b;\n	margin: 2px 0;\n}\n\n.syntaxbg		{ color: #FFFFFF; }\n.syntaxcomment	{ color: #000000; }\n.syntaxdefault	{ color: #bcbcbc; }\n.syntaxhtml		{ color: #000000; }\n.syntaxkeyword	{ color: #585858; }\n.syntaxstring	{ color: #a7a7a7; }\n\n/* Attachments\n----------------------------------------*/\n.attachbox {\n	float: left;\n	width: auto; \n	margin: 5px 5px 5px 0;\n	padding: 6px;\n	background-color: #FFFFFF;\n	border: 1px dashed #d8d8d8;\n	clear: left;\n}\n\n.pm-message .attachbox {\n	background-color: #f3f3f3;\n}\n\n.attachbox dt {\n	font-family: Arial, Helvetica, sans-serif;\n	text-transform: uppercase;\n}\n\n.attachbox dd {\n	margin-top: 4px;\n	padding-top: 4px;\n	clear: left;\n	border-top: 1px solid #d8d8d8;\n}\n\n.attachbox dd dd {\n	border: none;\n}\n\n.attachbox p {\n	line-height: 110%;\n	color: #666666;\n	font-weight: normal;\n	clear: left;\n}\n\n.attachbox p.stats\n{\n	line-height: 110%;\n	color: #666666;\n	font-weight: normal;\n	clear: left;\n}\n\n.attach-image {\n	margin: 3px 0;\n	width: 100%;\n	max-height: 350px;\n	overflow: auto;\n}\n\n.attach-image img {\n	border: 1px solid #999999;\n/*	cursor: move; */\n	cursor: default;\n}\n\n/* Inline image thumbnails */\ndiv.inline-attachment dl.thumbnail, div.inline-attachment dl.file {\n	display: block;\n	margin-bottom: 4px;\n}\n\ndiv.inline-attachment p {\n	font-size: 100%;\n}\n\ndl.file {\n	font-family: Verdana, Arial, Helvetica, sans-serif;\n	display: block;\n}\n\ndl.file dt {\n	text-transform: none;\n	margin: 0;\n	padding: 0;\n	font-weight: bold;\n	font-family: Verdana, Arial, Helvetica, sans-serif;\n}\n\ndl.file dd {\n	color: #666666;\n	margin: 0;\n	padding: 0;	\n}\n\ndl.thumbnail img {\n	padding: 3px;\n	border: 1px solid #666666;\n	background-color: #FFF;\n}\n\ndl.thumbnail dd {\n	color: #666666;\n	font-style: italic;\n	font-family: Verdana, Arial, Helvetica, sans-serif;\n}\n\n.attachbox dl.thumbnail dd {\n	font-size: 100%;\n}\n\ndl.thumbnail dt a:hover {\n	background-color: #EEEEEE;\n}\n\ndl.thumbnail dt a:hover img {\n	border: 1px solid #d2d2d2;\n}\n\n/* Post poll styles\n----------------------------------------*/\nfieldset.polls {\n	font-family: \"Trebuchet MS\", Verdana, Helvetica, Arial, sans-serif;\n}\n\nfieldset.polls dl {\n	margin-top: 5px;\n	border-top: 1px solid #e2e2e2;\n	padding: 5px 0 0 0;\n	line-height: 120%;\n	color: #666666;\n}\n\nfieldset.polls dl.voted {\n	font-weight: bold;\n	color: #000000;\n}\n\nfieldset.polls dt {\n	text-align: left;\n	float: left;\n	display: block;\n	width: 30%;\n	border-right: none;\n	padding: 0;\n	margin: 0;\n	font-size: 1.1em;\n}\n\nfieldset.polls dd {\n	float: left;\n	width: 10%;\n	border-left: none;\n	padding: 0 5px;\n	margin-left: 0;\n	font-size: 1.1em;\n}\n\nfieldset.polls dd.resultbar {\n	width: 50%;\n}\n\nfieldset.polls dd input {\n	margin: 2px 0;\n}\n\nfieldset.polls dd div {\n	text-align: right;\n	font-family: Arial, Helvetica, sans-serif;\n	color: #FFFFFF;\n	font-weight: bold;\n	padding: 0 2px;\n	overflow: visible;\n	min-width: 2%;\n}\n\n.pollbar1 {\n	background-color: #aaaaaa;\n	border-bottom: 1px solid #747474;\n	border-right: 1px solid #747474;\n}\n\n.pollbar2 {\n	background-color: #bebebe;\n	border-bottom: 1px solid #8c8c8c;\n	border-right: 1px solid #8c8c8c;\n}\n\n.pollbar3 {\n	background-color: #D1D1D1;\n	border-bottom: 1px solid #aaaaaa;\n	border-right: 1px solid #aaaaaa;\n}\n\n.pollbar4 {\n	background-color: #e4e4e4;\n	border-bottom: 1px solid #bebebe;\n	border-right: 1px solid #bebebe;\n}\n\n.pollbar5 {\n	background-color: #f8f8f8;\n	border-bottom: 1px solid #D1D1D1;\n	border-right: 1px solid #D1D1D1;\n}\n\n/* Poster profile block\n----------------------------------------*/\n.postprofile {\n	/* Also see tweaks.css */\n	margin: 5px 0 10px 0;\n	min-height: 80px;\n	color: #666666;\n	border-left: 1px solid #FFFFFF;\n	width: 22%;\n	float: right;\n	display: inline;\n}\n.pm .postprofile {\n	border-left: 1px solid #DDDDDD;\n}\n\n.postprofile dd, .postprofile dt {\n	line-height: 1.2em;\n	margin-left: 8px;\n}\n\n.postprofile strong {\n	font-weight: normal;\n	color: #000000;\n}\n\n.avatar {\n	border: none;\n	margin-bottom: 3px;\n}\n\n.online {\n	background-image: none;\n	background-position: 100% 0;\n	background-repeat: no-repeat;\n}\n\n/* Poster profile used by search*/\n.search .postprofile {\n	width: 30%;\n}\n\n/* pm list in compose message if mass pm is enabled */\ndl.pmlist dt {\n	width: 60% !important;\n}\n\ndl.pmlist dt textarea {\n	width: 95%;\n}\n\ndl.pmlist dd {\n	margin-left: 61% !important;\n	margin-bottom: 2px;\n}\n/* proSilver Button Styles\n---------------------------------------- */\n\n/* Rollover buttons\n   Based on: http://wellstyled.com/css-nopreload-rollovers.html\n----------------------------------------*/\n.buttons {\n	float: left;\n	width: auto;\n	height: auto;\n}\n\n/* Rollover state */\n.buttons div {\n	float: left;\n	margin: 0 5px 0 0;\n	background-position: 0 100%;\n}\n\n/* Rolloff state */\n.buttons div a {\n	display: block;\n	width: 100%;\n	height: 100%;\n	background-position: 0 0;\n	position: relative;\n	overflow: hidden;\n}\n\n/* Hide <a> text and hide off-state image when rolling over (prevents flicker in IE) */\n/*.buttons div span		{ display: none; }*/\n/*.buttons div a:hover	{ background-image: none; }*/\n.buttons div span			{ position: absolute; width: 100%; height: 100%; cursor: pointer;}\n.buttons div a:hover span	{ background-position: 0 100%; }\n\n/* Big button images */\n.reply-icon span	{ background: transparent none 0 0 no-repeat; }\n.post-icon span		{ background: transparent none 0 0 no-repeat; }\n.locked-icon span	{ background: transparent none 0 0 no-repeat; }\n.pmreply-icon span	{ background: none 0 0 no-repeat; }\n.newpm-icon span 	{ background: none 0 0 no-repeat; }\n.forwardpm-icon span 	{ background: none 0 0 no-repeat; }\n\n/* Set big button dimensions */\n.buttons div.reply-icon		{ width: {IMG_BUTTON_TOPIC_REPLY_WIDTH}px; height: {IMG_BUTTON_TOPIC_REPLY_HEIGHT}px; }\n.buttons div.post-icon		{ width: {IMG_BUTTON_TOPIC_NEW_WIDTH}px; height: {IMG_BUTTON_TOPIC_NEW_HEIGHT}px; }\n.buttons div.locked-icon	{ width: {IMG_BUTTON_TOPIC_LOCKED_WIDTH}px; height: {IMG_BUTTON_TOPIC_LOCKED_HEIGHT}px; }\n.buttons div.pmreply-icon	{ width: {IMG_BUTTON_PM_REPLY_WIDTH}px; height: {IMG_BUTTON_PM_REPLY_HEIGHT}px; }\n.buttons div.newpm-icon		{ width: {IMG_BUTTON_PM_NEW_WIDTH}px; height: {IMG_BUTTON_PM_NEW_HEIGHT}px; }\n.buttons div.forwardpm-icon	{ width: {IMG_BUTTON_PM_FORWARD_WIDTH}px; height: {IMG_BUTTON_PM_FORWARD_HEIGHT}px; }\n\n/* Sub-header (navigation bar)\n--------------------------------------------- */\na.print, a.sendemail, a.fontsize {\n	display: block;\n	overflow: hidden;\n	height: 18px;\n	text-indent: -5000px;\n	text-align: left;\n	background-repeat: no-repeat;\n}\n\na.print {\n	background-image: none;\n	width: 22px;\n}\n\na.sendemail {\n	background-image: none;\n	width: 22px;\n}\n\na.fontsize {\n	background-image: none;\n	background-position: 0 -1px;\n	width: 29px;\n}\n\na.fontsize:hover {\n	background-position: 0 -20px;\n	text-decoration: none;\n}\n\n/* Icon images\n---------------------------------------- */\n.sitehome, .icon-faq, .icon-members, .icon-home, .icon-ucp, .icon-register, .icon-logout,\n.icon-bookmark, .icon-bump, .icon-subscribe, .icon-unsubscribe, .icon-pages, .icon-search {\n	background-position: 0 50%;\n	background-repeat: no-repeat;\n	background-image: none;\n	padding: 1px 0 0 17px;\n}\n\n/* Poster profile icons\n----------------------------------------*/\nul.profile-icons {\n	padding-top: 10px;\n	list-style: none;\n}\n\n/* Rollover state */\nul.profile-icons li {\n	float: left;\n	margin: 0 6px 3px 0;\n	background-position: 0 100%;\n}\n\n/* Rolloff state */\nul.profile-icons li a {\n	display: block;\n	width: 100%;\n	height: 100%;\n	background-position: 0 0;\n}\n\n/* Hide <a> text and hide off-state image when rolling over (prevents flicker in IE) */\nul.profile-icons li span { display:none; }\nul.profile-icons li a:hover { background: none; }\n\n/* Positioning of moderator icons */\n.postbody ul.profile-icons {\n	float: right;\n	width: auto;\n	padding: 0;\n}\n\n.postbody ul.profile-icons li {\n	margin: 0 3px;\n}\n\n/* Profile & navigation icons */\n.email-icon, .email-icon a		{ background: none top left no-repeat; }\n.aim-icon, .aim-icon a			{ background: none top left no-repeat; }\n.yahoo-icon, .yahoo-icon a		{ background: none top left no-repeat; }\n.web-icon, .web-icon a			{ background: none top left no-repeat; }\n.msnm-icon, .msnm-icon a			{ background: none top left no-repeat; }\n.icq-icon, .icq-icon a			{ background: none top left no-repeat; }\n.jabber-icon, .jabber-icon a		{ background: none top left no-repeat; }\n.pm-icon, .pm-icon a				{ background: none top left no-repeat; }\n.quote-icon, .quote-icon a		{ background: none top left no-repeat; }\n\n/* Moderator icons */\n.report-icon, .report-icon a		{ background: none top left no-repeat; }\n.warn-icon, .warn-icon a			{ background: none top left no-repeat; }\n.edit-icon, .edit-icon a			{ background: none top left no-repeat; }\n.delete-icon, .delete-icon a		{ background: none top left no-repeat; }\n.info-icon, .info-icon a			{ background: none top left no-repeat; }\n\n/* Set profile icon dimensions */\nul.profile-icons li.email-icon		{ width: {IMG_ICON_CONTACT_EMAIL_WIDTH}px; height: {IMG_ICON_CONTACT_EMAIL_HEIGHT}px; }\nul.profile-icons li.aim-icon	{ width: {IMG_ICON_CONTACT_AIM_WIDTH}px; height: {IMG_ICON_CONTACT_AIM_HEIGHT}px; }\nul.profile-icons li.yahoo-icon	{ width: {IMG_ICON_CONTACT_YAHOO_WIDTH}px; height: {IMG_ICON_CONTACT_YAHOO_HEIGHT}px; }\nul.profile-icons li.web-icon	{ width: {IMG_ICON_CONTACT_WWW_WIDTH}px; height: {IMG_ICON_CONTACT_WWW_HEIGHT}px; }\nul.profile-icons li.msnm-icon	{ width: {IMG_ICON_CONTACT_MSNM_WIDTH}px; height: {IMG_ICON_CONTACT_MSNM_HEIGHT}px; }\nul.profile-icons li.icq-icon	{ width: {IMG_ICON_CONTACT_ICQ_WIDTH}px; height: {IMG_ICON_CONTACT_ICQ_HEIGHT}px; }\nul.profile-icons li.jabber-icon	{ width: {IMG_ICON_CONTACT_JABBER_WIDTH}px; height: {IMG_ICON_CONTACT_JABBER_HEIGHT}px; }\nul.profile-icons li.pm-icon		{ width: {IMG_ICON_CONTACT_PM_WIDTH}px; height: {IMG_ICON_CONTACT_PM_HEIGHT}px; }\nul.profile-icons li.quote-icon	{ width: {IMG_ICON_POST_QUOTE_WIDTH}px; height: {IMG_ICON_POST_QUOTE_HEIGHT}px; }\nul.profile-icons li.report-icon	{ width: {IMG_ICON_POST_REPORT_WIDTH}px; height: {IMG_ICON_POST_REPORT_HEIGHT}px; }\nul.profile-icons li.edit-icon	{ width: {IMG_ICON_POST_EDIT_WIDTH}px; height: {IMG_ICON_POST_EDIT_HEIGHT}px; }\nul.profile-icons li.delete-icon	{ width: {IMG_ICON_POST_DELETE_WIDTH}px; height: {IMG_ICON_POST_DELETE_HEIGHT}px; }\nul.profile-icons li.info-icon	{ width: {IMG_ICON_POST_INFO_WIDTH}px; height: {IMG_ICON_POST_INFO_HEIGHT}px; }\nul.profile-icons li.warn-icon	{ width: {IMG_ICON_USER_WARN_WIDTH}px; height: {IMG_ICON_USER_WARN_HEIGHT}px; }\n\n/* Fix profile icon default margins */\nul.profile-icons li.edit-icon	{ margin: 0 0 0 3px; }\nul.profile-icons li.quote-icon	{ margin: 0 0 0 10px; }\nul.profile-icons li.info-icon, ul.profile-icons li.report-icon	{ margin: 0 3px 0 0; }\n/* proSilver Control Panel Styles\n---------------------------------------- */\n\n\n/* Main CP box\n----------------------------------------*/\n#cp-menu {\n	float:left;\n	width: 19%;\n	margin-top: 1em;\n	margin-bottom: 5px;\n}\n\n#cp-main {\n	float: left;\n	width: 81%;\n}\n\n#cp-main .content {\n	padding: 0;\n}\n\n#cp-main h3, #cp-main hr, #cp-menu hr {\n	border-color: #bfbfbf;\n}\n\n#cp-main .panel p {\n	font-size: 1.1em;\n}\n\n#cp-main .panel ol {\n	margin-left: 2em;\n	font-size: 1.1em;\n}\n\n#cp-main .panel li.row {\n	border-bottom: 1px solid #cbcbcb;\n	border-top: 1px solid #F9F9F9;\n}\n\nul.cplist {\n	margin-bottom: 5px;\n	border-top: 1px solid #cbcbcb;\n}\n\n#cp-main .panel li.header dd, #cp-main .panel li.header dt {\n	color: #000000;\n	margin-bottom: 2px;\n}\n\n#cp-main table.table1 {\n	margin-bottom: 1em;\n}\n\n#cp-main table.table1 thead th {\n	color: #333333;\n	font-weight: bold;\n	border-bottom: 1px solid #333333;\n	padding: 5px;\n}\n\n#cp-main table.table1 tbody th {\n	font-style: italic;\n	background-color: transparent !important;\n	border-bottom: none;\n}\n\n#cp-main .pagination {\n	float: right;\n	width: auto;\n	padding-top: 1px;\n}\n\n#cp-main .postbody p {\n	font-size: 1.1em;\n}\n\n#cp-main .pm-message {\n	border: 1px solid #e2e2e2;\n	margin: 10px 0;\n	background-color: #FFFFFF;\n	width: auto;\n	float: none;\n}\n\n.pm-message h2 {\n	padding-bottom: 5px;\n}\n\n#cp-main .postbody h3, #cp-main .box2 h3 {\n	margin-top: 0;\n}\n\n#cp-main .buttons {\n	margin-left: 0;\n}\n\n#cp-main ul.linklist {\n	margin: 0;\n}\n\n/* MCP Specific tweaks */\n.mcp-main .postbody {\n	width: 100%;\n}\n\n/* CP tabbed menu\n----------------------------------------*/\n#tabs {\n	line-height: normal;\n	margin: 20px 0 -1px 7px;\n	min-width: 570px;\n}\n\n#tabs ul {\n	margin:0;\n	padding: 0;\n	list-style: none;\n}\n\n#tabs li {\n	display: inline;\n	margin: 0;\n	padding: 0;\n	font-size: 1em;\n	font-weight: bold;\n}\n\n#tabs a {\n	float: left;\n	background: none no-repeat 0% -35px;\n	margin: 0 1px 0 0;\n	padding: 0 0 0 5px;\n	text-decoration: none;\n	position: relative;\n	cursor: pointer;\n}\n\n#tabs a span {\n	float: left;\n	display: block;\n	background: none no-repeat 100% -35px;\n	padding: 6px 10px 6px 5px;\n	color: #828282;\n	white-space: nowrap;\n}\n\n#tabs a:hover span {\n	color: #bcbcbc;\n}\n\n#tabs .activetab a {\n	background-position: 0 0;\n	border-bottom: 1px solid #ebebeb;\n}\n\n#tabs .activetab a span {\n	background-position: 100% 0;\n	padding-bottom: 7px;\n	color: #333333;\n}\n\n#tabs a:hover {\n	background-position: 0 -70px;\n}\n\n#tabs a:hover span {\n	background-position:100% -70px;\n}\n\n#tabs .activetab a:hover {\n	background-position: 0 0;\n}\n\n#tabs .activetab a:hover span {\n	color: #000000;\n	background-position: 100% 0;\n}\n\n/* Mini tabbed menu used in MCP\n----------------------------------------*/\n#minitabs {\n	line-height: normal;\n	margin: -20px 7px 0 0;\n}\n\n#minitabs ul {\n	margin:0;\n	padding: 0;\n	list-style: none;\n}\n\n#minitabs li {\n	display: block;\n	float: right;\n	padding: 0 10px 4px 10px;\n	font-size: 1em;\n	font-weight: bold;\n	background-color: #f2f2f2;\n	margin-left: 2px;\n}\n\n#minitabs a {\n}\n\n#minitabs a:hover {\n	text-decoration: none;\n}\n\n#minitabs li.activetab {\n	background-color: #F9F9F9;\n}\n\n#minitabs li.activetab a, #minitabs li.activetab a:hover {\n	color: #333333;\n}\n\n/* UCP navigation menu\n----------------------------------------*/\n/* Container for sub-navigation list */\n#navigation {\n	width: 100%;\n	padding-top: 36px;\n}\n\n#navigation ul {\n	list-style:none;\n}\n\n/* Default list state */\n#navigation li {\n	margin: 1px 0;\n	padding: 0;\n	font-weight: bold;\n	display: inline;\n}\n\n/* Link styles for the sub-section links */\n#navigation a {\n	display: block;\n	padding: 5px;\n	margin: 1px 0;\n	text-decoration: none;\n	font-weight: bold;\n	color: #333;\n	background: #cfcfcf none repeat-y 100% 0;\n}\n\n#navigation a:hover {\n	text-decoration: none;\n	background-color: #c6c6c6;\n	color: #bcbcbc;\n	background-image: none;\n}\n\n#navigation #active-subsection a {\n	display: block;\n	color: #d3d3d3;\n	background-color: #F9F9F9;\n	background-image: none;\n}\n\n#navigation #active-subsection a:hover {\n	color: #d3d3d3;\n}\n\n/* Preferences pane layout\n----------------------------------------*/\n#cp-main h2 {\n	border-bottom: none;\n	padding: 0;\n	margin-left: 10px;\n	color: #333333;\n}\n\n#cp-main .panel {\n	background-color: #F9F9F9;\n}\n\n#cp-main .pm {\n	background-color: #FFFFFF;\n}\n\n#cp-main span.corners-top, #cp-menu span.corners-top {\n	background-image: none;\n}\n\n#cp-main span.corners-top span, #cp-menu span.corners-top span {\n	background-image: none;\n}\n\n#cp-main span.corners-bottom, #cp-menu span.corners-bottom {\n	background-image: none;\n}\n\n#cp-main span.corners-bottom span, #cp-menu span.corners-bottom span {\n	background-image: none;\n}\n\n/* Topicreview */\n#cp-main .panel #topicreview span.corners-top, #cp-menu .panel #topicreview span.corners-top {\n	background-image: none;\n}\n\n#cp-main .panel #topicreview span.corners-top span, #cp-menu .panel #topicreview span.corners-top span {\n	background-image: none;\n}\n\n#cp-main .panel #topicreview span.corners-bottom, #cp-menu .panel #topicreview span.corners-bottom {\n	background-image: none;\n}\n\n#cp-main .panel #topicreview span.corners-bottom span, #cp-menu .panel #topicreview span.corners-bottom span {\n	background-image: none;\n}\n\n/* Friends list */\n.cp-mini {\n	background-color: #f9f9f9;\n	padding: 0 5px;\n	margin: 10px 15px 10px 5px;\n}\n\n.cp-mini span.corners-top, .cp-mini span.corners-bottom {\n	margin: 0 -5px;\n}\n\ndl.mini dt {\n	font-weight: bold;\n	color: #676767;\n}\n\ndl.mini dd {\n	padding-top: 4px;\n}\n\n.friend-online {\n	font-weight: bold;\n}\n\n.friend-offline {\n	font-style: italic;\n}\n\n/* PM Styles\n----------------------------------------*/\n#pm-menu {\n	line-height: 2.5em;\n}\n\n/* PM Message history */\n.current {\n	color: #999999;\n}\n\n/* Defined rules list for PM options */\nol.def-rules {\n	padding-left: 0;\n}\n\nol.def-rules li {\n	line-height: 180%;\n	padding: 1px;\n}\n\n/* PM marking colours */\n.pmlist li.bg1 {\n	border: solid 3px transparent;\n	border-width: 0 3px;\n}\n\n.pmlist li.bg2 {\n	border: solid 3px transparent;\n	border-width: 0 3px;\n}\n\n.pmlist li.pm_message_reported_colour, .pm_message_reported_colour {\n	border-left-color: #bcbcbc;\n	border-right-color: #bcbcbc;\n}\n\n.pmlist li.pm_marked_colour, .pm_marked_colour {\n	border: solid 3px #ffffff;\n	border-width: 0 3px;\n}\n\n.pmlist li.pm_replied_colour, .pm_replied_colour {\n	border: solid 3px #c2c2c2;\n	border-width: 0 3px;	\n}\n\n.pmlist li.pm_friend_colour, .pm_friend_colour {\n	border: solid 3px #bdbdbd;\n	border-width: 0 3px;\n}\n\n.pmlist li.pm_foe_colour, .pm_foe_colour {\n	border: solid 3px #000000;\n	border-width: 0 3px;\n}\n\n.pm-legend {\n	border-left-width: 10px;\n	border-left-style: solid;\n	border-right-width: 0;\n	margin-bottom: 3px;\n	padding-left: 3px;\n}\n\n/* Avatar gallery */\n#gallery label {\n	position: relative;\n	float: left;\n	margin: 10px;\n	padding: 5px;\n	width: auto;\n	background: #FFFFFF;\n	border: 1px solid #CCC;\n	text-align: center;\n}\n\n#gallery label:hover {\n	background-color: #EEE;\n}\n/* proSilver Form Styles\n---------------------------------------- */\n\n/* General form styles\n----------------------------------------*/\nfieldset {\n	border-width: 0;\n	font-family: Verdana, Helvetica, Arial, sans-serif;\n	font-size: 1.1em;\n}\n\ninput {\n	font-weight: normal;\n	cursor: pointer;\n	vertical-align: middle;\n	padding: 0 3px;\n	font-size: 1em;\n	font-family: Verdana, Helvetica, Arial, sans-serif;\n}\n\nselect {\n	font-family: Verdana, Helvetica, Arial, sans-serif;\n	font-weight: normal;\n	cursor: pointer;\n	vertical-align: middle;\n	border: 1px solid #666666;\n	padding: 1px;\n	background-color: #FAFAFA;\n}\n\noption {\n	padding-right: 1em;\n}\n\noption.disabled-option {\n	color: graytext;\n}\n\ntextarea {\n	font-family: \"Lucida Grande\", Verdana, Helvetica, Arial, sans-serif;\n	width: 60%;\n	padding: 2px;\n	font-size: 1em;\n	line-height: 1.4em;\n}\n\nlabel {\n	cursor: default;\n	padding-right: 5px;\n	color: #676767;\n}\n\nlabel input {\n	vertical-align: middle;\n}\n\nlabel img {\n	vertical-align: middle;\n}\n\n/* Definition list layout for forms\n---------------------------------------- */\nfieldset dl {\n	padding: 4px 0;\n}\n\nfieldset dt {\n	float: left;	\n	width: 40%;\n	text-align: left;\n	display: block;\n}\n\nfieldset dd {\n	margin-left: 41%;\n	vertical-align: top;\n	margin-bottom: 3px;\n}\n\n/* Specific layout 1 */\nfieldset.fields1 dt {\n	width: 15em;\n	border-right-width: 0;\n}\n\nfieldset.fields1 dd {\n	margin-left: 15em;\n	border-left-width: 0;\n}\n\nfieldset.fields1 {\n	background-color: transparent;\n}\n\nfieldset.fields1 div {\n	margin-bottom: 3px;\n}\n\n/* Specific layout 2 */\nfieldset.fields2 dt {\n	width: 15em;\n	border-right-width: 0;\n}\n\nfieldset.fields2 dd {\n	margin-left: 16em;\n	border-left-width: 0;\n}\n\n/* Form elements */\ndt label {\n	font-weight: bold;\n	text-align: left;\n}\n\ndd label {\n	white-space: nowrap;\n	color: #333;\n}\n\ndd input, dd textarea {\n	margin-right: 3px;\n}\n\ndd select {\n	width: auto;\n}\n\ndd textarea {\n	width: 85%;\n}\n\n/* Hover effects */\nfieldset dl:hover dt label {\n	color: #000000;\n}\n\nfieldset.fields2 dl:hover dt label {\n	color: inherit;\n}\n\n#timezone {\n	width: 95%;\n}\n\n* html #timezone {\n	width: 50%;\n}\n\n/* Quick-login on index page */\nfieldset.quick-login {\n	margin-top: 5px;\n}\n\nfieldset.quick-login input {\n	width: auto;\n}\n\nfieldset.quick-login input.inputbox {\n	width: 15%;\n	vertical-align: middle;\n	margin-right: 5px;\n	background-color: #f3f3f3;\n}\n\nfieldset.quick-login label {\n	white-space: nowrap;\n	padding-right: 2px;\n}\n\n/* Display options on viewtopic/viewforum pages  */\nfieldset.display-options {\n	text-align: center;\n	margin: 3px 0 5px 0;\n}\n\nfieldset.display-options label {\n	white-space: nowrap;\n	padding-right: 2px;\n}\n\nfieldset.display-options a {\n	margin-top: 3px;\n}\n\n/* Display actions for ucp and mcp pages */\nfieldset.display-actions {\n	text-align: right;\n	line-height: 2em;\n	white-space: nowrap;\n	padding-right: 1em;\n}\n\nfieldset.display-actions label {\n	white-space: nowrap;\n	padding-right: 2px;\n}\n\nfieldset.sort-options {\n	line-height: 2em;\n}\n\n/* MCP forum selection*/\nfieldset.forum-selection {\n	margin: 5px 0 3px 0;\n	float: right;\n}\n\nfieldset.forum-selection2 {\n	margin: 13px 0 3px 0;\n	float: right;\n}\n\n/* Jumpbox */\nfieldset.jumpbox {\n	text-align: right;\n	margin-top: 15px;\n	height: 2.5em;\n}\n\nfieldset.quickmod {\n	width: 50%;\n	float: right;\n	text-align: right;\n	height: 2.5em;\n}\n\n/* Submit button fieldset */\nfieldset.submit-buttons {\n	text-align: center;\n	vertical-align: middle;\n	margin: 5px 0;\n}\n\nfieldset.submit-buttons input {\n	vertical-align: middle;\n	padding-top: 3px;\n	padding-bottom: 3px;\n}\n\n/* Posting page styles\n----------------------------------------*/\n\n/* Buttons used in the editor */\n#format-buttons {\n	margin: 15px 0 2px 0;\n}\n\n#format-buttons input, #format-buttons select {\n	vertical-align: middle;\n}\n\n/* Main message box */\n#message-box {\n	width: 80%;\n}\n\n#message-box textarea {\n	font-family: \"Trebuchet MS\", Verdana, Helvetica, Arial, sans-serif;\n	width: 100%;\n	font-size: 1.2em;\n	color: #333333;\n}\n\n/* Emoticons panel */\n#smiley-box {\n	width: 18%;\n	float: right;\n}\n\n#smiley-box img {\n	margin: 3px;\n}\n\n/* Input field styles\n---------------------------------------- */\n.inputbox {\n	background-color: #FFFFFF;\n	border: 1px solid #c0c0c0;\n	color: #333333;\n	padding: 2px;\n	cursor: text;\n}\n\n.inputbox:hover {\n	border: 1px solid #eaeaea;\n}\n\n.inputbox:focus {\n	border: 1px solid #eaeaea;\n	color: #4b4b4b;\n}\n\ninput.inputbox	{ width: 85%; }\ninput.medium	{ width: 50%; }\ninput.narrow	{ width: 25%; }\ninput.tiny		{ width: 125px; }\n\ntextarea.inputbox {\n	width: 85%;\n}\n\n.autowidth {\n	width: auto !important;\n}\n\n/* Form button styles\n---------------------------------------- */\ninput.button1, input.button2 {\n	font-size: 1em;\n}\n\na.button1, input.button1, input.button3, a.button2, input.button2 {\n	width: auto !important;\n	padding-top: 1px;\n	padding-bottom: 1px;\n	font-family: \"Lucida Grande\", Verdana, Helvetica, Arial, sans-serif;\n	color: #000;\n	background: #FAFAFA none repeat-x top;\n}\n\na.button1, input.button1 {\n	font-weight: bold;\n	border: 1px solid #666666;\n}\n\ninput.button3 {\n	padding: 0;\n	margin: 0;\n	line-height: 5px;\n	height: 12px;\n	background-image: none;\n	font-variant: small-caps;\n}\n\n/* Alternative button */\na.button2, input.button2, input.button3 {\n	border: 1px solid #666666;\n}\n\n/* <a> button in the style of the form buttons */\na.button1, a.button1:link, a.button1:visited, a.button1:active, a.button2, a.button2:link, a.button2:visited, a.button2:active {\n	text-decoration: none;\n	color: #000000;\n	padding: 2px 8px;\n	line-height: 250%;\n	vertical-align: text-bottom;\n	background-position: 0 1px;\n}\n\n/* Hover states */\na.button1:hover, input.button1:hover, a.button2:hover, input.button2:hover, input.button3:hover {\n	border: 1px solid #BCBCBC;\n	background-position: 0 100%;\n	color: #BCBCBC;\n}\n\ninput.disabled {\n	font-weight: normal;\n	color: #666666;\n}\n\n/* Topic and forum Search */\n.search-box {\n	margin-top: 3px;\n	margin-left: 5px;\n	float: left;\n}\n\n.search-box input {\n}\n\ninput.search {\n	background-image: none;\n	background-repeat: no-repeat;\n	background-position: left 1px;\n	padding-left: 17px;\n}\n\n.full { width: 95%; }\n.medium { width: 50%;}\n.narrow { width: 25%;}\n.tiny { width: 10%;}\n/* proSilver Style Sheet Tweaks\n\nThese style definitions are mainly IE specific \ntweaks required due to its poor CSS support.\n-------------------------------------------------*/\n\n* html table, * html select, * html input { font-size: 100%; }\n* html hr { margin: 0; }\n* html span.corners-top, * html span.corners-bottom { background-image: url(\"{T_THEME_PATH}/images/corners_left.gif\"); }\n* html span.corners-top span, * html span.corners-bottom span { background-image: url(\"{T_THEME_PATH}/images/corners_right.gif\"); }\n\ntable.table1 {\n	width: 99%;		/* IE < 6 browsers */\n	/* Tantek hack */\n	voice-family: \"\\\"}\\\"\";\n	voice-family: inherit;\n	width: 100%;\n}\nhtml>body table.table1 { width: 100%; }	/* Reset 100% for opera */\n\n* html ul.topiclist li { position: relative; }\n* html .postbody h3 img { vertical-align: middle; }\n\n/* Form styles */\nhtml>body dd label input { vertical-align: text-bottom; }	/* Align checkboxes/radio buttons nicely */\n\n* html input.button1, * html input.button2 {\n	padding-bottom: 0;\n	margin-bottom: 1px;\n}\n\n/* Misc layout styles */\n* html .column1, * html .column2 { width: 45%; }\n\n/* Nice method for clearing floated blocks without having to insert any extra markup (like spacer above)\n   From http://www.positioniseverything.net/easyclearing.html \n#tabs:after, #minitabs:after, .post:after, .navbar:after, fieldset dl:after, ul.topiclist dl:after, ul.linklist:after, dl.polls:after {\n	content: \".\"; \n	display: block; \n	height: 0; \n	clear: both; \n	visibility: hidden;\n}*/\n\n.clearfix, #tabs, #minitabs, fieldset dl, ul.topiclist dl, dl.polls {\n	height: 1%;\n	overflow: hidden;\n}\n\n/* viewtopic fix */\n* html .post {\n	height: 25%;\n	overflow: hidden;\n}\n\n/* navbar fix */\n* html .clearfix, * html .navbar, ul.linklist {\n	height: 4%;\n	overflow: hidden;\n}\n\n/* Simple fix so forum and topic lists always have a min-height set, even in IE6\n	From http://www.dustindiaz.com/min-height-fast-hack */\ndl.icon {\n	min-height: 35px;\n	height: auto !important;\n	height: 35px;\n}\n\n* html #search-box {\n	width: 25%;\n}\n\n/* Correctly clear floating for details on profile view */\n*:first-child+html dl.details dd {\n	margin-left: 30%;\n	float: none;\n}\n\n* html dl.details dd {\n	margin-left: 30%;\n	float: none;\n}\n/*  	\n--------------------------------------------------------------\nColours and backgrounds for common.css\n-------------------------------------------------------------- */\n\nhtml, body {\n	color: #536482;\n	background-color: #FFFFFF;\n}\n\nh1 {\n	color: #FFFFFF;\n}\n\nh2 {\n	color: #28313F;\n}\n\nh3 {\n	border-bottom-color: #CCCCCC;\n	color: #115098;\n}\n\nhr {\n	border-color: #FFFFFF;\n	border-top-color: #CCCCCC;\n}\n\nhr.dashed {\n	border-top-color: #CCCCCC;\n}\n\n/* Search box\n--------------------------------------------- */\n\n#search-box {\n	color: #FFFFFF;\n}\n\n#search-box #keywords {\n	background-color: #FFF;\n}\n\n#search-box input {\n	border-color: #0075B0;\n}\n\n/* Round cornered boxes and backgrounds\n---------------------------------------- */\n.headerbar {\n	background-color: #12A3EB;\n	background-image: url(\"{T_THEME_PATH}/images/bg_header.gif\");\n	color: #FFFFFF;\n}\n\n.navbar {\n	background-color: #cadceb;\n}\n\n.forabg {\n	background-color: #0076b1;\n	background-image: url(\"{T_THEME_PATH}/images/bg_list.gif\");\n}\n\n.forumbg {\n	background-color: #12A3EB;\n	background-image: url(\"{T_THEME_PATH}/images/bg_header.gif\");\n}\n\n.panel {\n	background-color: #ECF1F3;\n	color: #28313F;\n}\n\n.post:target .content {\n	color: #000000;\n}\n\n.post:target h3 a {\n	color: #000000;\n}\n\n.bg1	{ background-color: #ECF3F7; }\n.bg2	{ background-color: #e1ebf2;  }\n.bg3	{ background-color: #cadceb; }\n\n.ucprowbg {\n	background-color: #DCDEE2;\n}\n\n.fieldsbg {\n	background-color: #E7E8EA;\n}\n\nspan.corners-top {\n	background-image: url(\"{T_THEME_PATH}/images/corners_left.png\");\n}\n\nspan.corners-top span {\n	background-image: url(\"{T_THEME_PATH}/images/corners_right.png\");\n}\n\nspan.corners-bottom {\n	background-image: url(\"{T_THEME_PATH}/images/corners_left.png\");\n}\n\nspan.corners-bottom span {\n	background-image: url(\"{T_THEME_PATH}/images/corners_right.png\");\n}\n\n/* Horizontal lists\n----------------------------------------*/\n\nul.navlinks {\n	border-bottom-color: #FFFFFF;\n}\n\n/* Table styles\n----------------------------------------*/\ntable.table1 thead th {\n	color: #FFFFFF;\n}\n\ntable.table1 tbody tr {\n	border-color: #BFC1CF;\n}\n\ntable.table1 tbody tr:hover, table.table1 tbody tr.hover {\n	background-color: #CFE1F6;\n	color: #000;\n}\n\ntable.table1 td {\n	color: #536482;\n}\n\ntable.table1 tbody td {\n	border-top-color: #FAFAFA;\n}\n\ntable.table1 tbody th {\n	border-bottom-color: #000000;\n	color: #333333;\n	background-color: #FFFFFF;\n}\n\ntable.info tbody th {\n	color: #000000;\n}\n\n/* Misc layout styles\n---------------------------------------- */\ndl.details dt {\n	color: #000000;\n}\n\ndl.details dd {\n	color: #536482;\n}\n\n.sep {\n	color: #1198D9;\n}\n\n/* Pagination\n---------------------------------------- */\n\n.pagination span strong {\n	color: #FFFFFF;\n	background-color: #4692BF;\n	border-color: #4692BF;\n}\n\n.pagination span a, .pagination span a:link, .pagination span a:visited, .pagination span a:active {\n	color: #5C758C;\n	background-color: #ECEDEE;\n	border-color: #B4BAC0;\n}\n\n.pagination span a:hover {\n	border-color: #368AD2;\n	background-color: #368AD2;\n	color: #FFF;\n}\n\n/* Pagination in viewforum for multipage topics */\n.row .pagination {\n	background-image: url(\"{T_THEME_PATH}/images/icon_pages.gif\");\n}\n\n.row .pagination span a, li.pagination span a {\n	background-color: #FFFFFF;\n}\n\n.row .pagination span a:hover, li.pagination span a:hover {\n	background-color: #368AD2;\n}\n\n/* Miscellaneous styles\n---------------------------------------- */\n\n.copyright {\n	color: #555555;\n}\n\n.error {\n	color: #BC2A4D;\n}\n\n.reported {\n	background-color: #F7ECEF;\n}\n\nli.reported:hover {\n	background-color: #ECD5D8 !important;\n}\n.sticky, .announce {\n	/* you can add a background for stickies and announcements*/\n}\n\ndiv.rules {\n	background-color: #ECD5D8;\n	color: #BC2A4D;\n}\n\np.rules {\n	background-color: #ECD5D8;\n	background-image: none;\n}\n\n/*  	\n--------------------------------------------------------------\nColours and backgrounds for links.css\n-------------------------------------------------------------- */\n\na:link	{ color: #105289; }\na:visited	{ color: #105289; }\na:hover	{ color: #D31141; }\na:active	{ color: #368AD2; }\n\n/* Links on gradient backgrounds */\n#search-box a:link, .navbg a:link, .forumbg .header a:link, .forabg .header a:link, th a:link {\n	color: #FFFFFF;\n}\n\n#search-box a:visited, .navbg a:visited, .forumbg .header a:visited, .forabg .header a:visited, th a:visited {\n	color: #FFFFFF;\n}\n\n#search-box a:hover, .navbg a:hover, .forumbg .header a:hover, .forabg .header a:hover, th a:hover {\n	color: #A8D8FF;\n}\n\n#search-box a:active, .navbg a:active, .forumbg .header a:active, .forabg .header a:active, th a:active {\n	color: #C8E6FF;\n}\n\n/* Links for forum/topic lists */\na.forumtitle {\n	color: #105289;\n}\n\n/* a.forumtitle:visited { color: #105289; } */\n\na.forumtitle:hover {\n	color: #BC2A4D;\n}\n\na.forumtitle:active {\n	color: #105289;\n}\n\na.topictitle {\n	color: #105289;\n}\n\n/* a.topictitle:visited { color: #368AD2; } */\n\na.topictitle:hover {\n	color: #BC2A4D;\n}\n\na.topictitle:active {\n	color: #105289;\n}\n\n/* Post body links */\n.postlink {\n	color: #368AD2;\n	border-bottom-color: #368AD2;\n}\n\n.postlink:visited {\n	color: #5D8FBD;\n	border-bottom-color: #666666;\n}\n\n.postlink:active {\n	color: #368AD2;\n}\n\n.postlink:hover {\n	background-color: #D0E4F6;\n	color: #0D4473;\n}\n\n.signature a, .signature a:visited, .signature a:active, .signature a:hover {\n	background-color: transparent;\n}\n\n/* Profile links */\n.postprofile a:link, .postprofile a:active, .postprofile a:visited, .postprofile dt.author a {\n	color: #105289;\n}\n\n.postprofile a:hover, .postprofile dt.author a:hover {\n	color: #D31141;\n}\n\n/* Profile searchresults */	\n.search .postprofile a {\n	color: #105289;\n}\n\n.search .postprofile a:hover {\n	color: #D31141;\n}\n\n/* Back to top of page */\na.top {\n	background-image: url(\"{IMG_ICON_BACK_TOP_SRC}\");\n}\n\na.top2 {\n	background-image: url(\"{IMG_ICON_BACK_TOP_SRC}\");\n}\n\n/* Arrow links  */\na.up		{ background-image: url(\"{T_THEME_PATH}/images/arrow_up.gif\") }\na.down		{ background-image: url(\"{T_THEME_PATH}/images/arrow_down.gif\") }\na.left		{ background-image: url(\"{T_THEME_PATH}/images/arrow_left.gif\") }\na.right		{ background-image: url(\"{T_THEME_PATH}/images/arrow_right.gif\") }\n\na.up:hover {\n	background-color: transparent;\n}\n\na.left:hover {\n	color: #368AD2;\n}\n\na.right:hover {\n	color: #368AD2;\n}\n\n\n/*  	\n--------------------------------------------------------------\nColours and backgrounds for content.css\n-------------------------------------------------------------- */\n\nul.forums {\n	background-color: #eef5f9;\n	background-image: url(\"{T_THEME_PATH}/images/gradient.gif\");\n}\n\nul.topiclist li {\n	color: #4C5D77;\n}\n\nul.topiclist dd {\n	border-left-color: #FFFFFF;\n}\n\n.rtl ul.topiclist dd {\n	border-right-color: #fff;\n	border-left-color: transparent;\n}\n\nul.topiclist li.row dt a.subforum.read {\n	background-image: url(\"{IMG_SUBFORUM_READ_SRC}\");\n}\n\nul.topiclist li.row dt a.subforum.unread {\n	background-image: url(\"{IMG_SUBFORUM_UNREAD_SRC}\");\n}\n\nli.row {\n	border-top-color:  #FFFFFF;\n	border-bottom-color: #00608F;\n}\n\nli.row strong {\n	color: #000000;\n}\n\nli.row:hover {\n	background-color: #F6F4D0;\n}\n\nli.row:hover dd {\n	border-left-color: #CCCCCC;\n}\n\n.rtl li.row:hover dd {\n	border-right-color: #CCCCCC;\n	border-left-color: transparent;\n}\n\nli.header dt, li.header dd {\n	color: #FFFFFF;\n}\n\n/* Forum list column styles */\nul.topiclist dd.searchextra {\n	color: #333333;\n}\n\n/* Post body styles\n----------------------------------------*/\n.postbody {\n	color: #333333;\n}\n\n/* Content container styles\n----------------------------------------*/\n.content {\n	color: #333333;\n}\n\n.content h2, .panel h2 {\n	color: #115098;\n	border-bottom-color:  #CCCCCC;\n}\n\ndl.faq dt {\n	color: #333333;\n}\n\n.posthilit {\n	background-color: #F3BFCC;\n	color: #BC2A4D;\n}\n\n/* Post signature */\n.signature {\n	border-top-color: #CCCCCC;\n}\n\n/* Post noticies */\n.notice {\n	border-top-color:  #CCCCCC;\n}\n\n/* BB Code styles\n----------------------------------------*/\n/* Quote block */\nblockquote {\n	background-color: #EBEADD;\n	background-image: url(\"{T_THEME_PATH}/images/quote.gif\");\n	border-color:#DBDBCE;\n}\n\nblockquote blockquote {\n	/* Nested quotes */\n	background-color:#EFEED9;\n}\n\nblockquote blockquote blockquote {\n	/* Nested quotes */\n	background-color: #EBEADD;\n}\n\n/* Code block */\ndl.codebox {\n	background-color: #FFFFFF;\n	border-color: #C9D2D8;\n}\n\ndl.codebox dt {\n	border-bottom-color:  #CCCCCC;\n}\n\ndl.codebox code {\n	color: #2E8B57;\n}\n\n.syntaxbg		{ color: #FFFFFF; }\n.syntaxcomment	{ color: #FF8000; }\n.syntaxdefault	{ color: #0000BB; }\n.syntaxhtml		{ color: #000000; }\n.syntaxkeyword	{ color: #007700; }\n.syntaxstring	{ color: #DD0000; }\n\n/* Attachments\n----------------------------------------*/\n.attachbox {\n	background-color: #FFFFFF;\n	border-color:  #C9D2D8;\n}\n\n.pm-message .attachbox {\n	background-color: #F2F3F3;\n}\n\n.attachbox dd {\n	border-top-color: #C9D2D8;\n}\n\n.attachbox p {\n	color: #666666;\n}\n\n.attachbox p.stats {\n	color: #666666;\n}\n\n.attach-image img {\n	border-color: #999999;\n}\n\n/* Inline image thumbnails */\n\ndl.file dd {\n	color: #666666;\n}\n\ndl.thumbnail img {\n	border-color: #666666;\n	background-color: #FFFFFF;\n}\n\ndl.thumbnail dd {\n	color: #666666;\n}\n\ndl.thumbnail dt a:hover {\n	background-color: #EEEEEE;\n}\n\ndl.thumbnail dt a:hover img {\n	border-color: #368AD2;\n}\n\n/* Post poll styles\n----------------------------------------*/\n\nfieldset.polls dl {\n	border-top-color: #DCDEE2;\n	color: #666666;\n}\n\nfieldset.polls dl.voted {\n	color: #000000;\n}\n\nfieldset.polls dd div {\n	color: #FFFFFF;\n}\n\n.rtl .pollbar1, .rtl .pollbar2, .rtl .pollbar3, .rtl .pollbar4, .rtl .pollbar5 {\n	border-right-color: transparent;\n}\n\n.pollbar1 {\n	background-color: #AA2346;\n	border-bottom-color: #74162C;\n	border-right-color: #74162C;\n}\n\n.rtl .pollbar1 {\n	border-left-color: #74162C;\n}\n\n.pollbar2 {\n	background-color: #BE1E4A;\n	border-bottom-color: #8C1C38;\n	border-right-color: #8C1C38;\n}\n\n.rtl .pollbar2 {\n	border-left-color: #8C1C38;\n}\n\n.pollbar3 {\n	background-color: #D11A4E;\n	border-bottom-color: #AA2346;\n	border-right-color: #AA2346;\n}\n\n.rtl .pollbar3 {\n	border-left-color: #AA2346;\n}\n\n.pollbar4 {\n	background-color: #E41653;\n	border-bottom-color: #BE1E4A;\n	border-right-color: #BE1E4A;\n}\n\n.rtl .pollbar4 {\n	border-left-color: #BE1E4A;\n}\n\n.pollbar5 {\n	background-color: #F81157;\n	border-bottom-color: #D11A4E;\n	border-right-color: #D11A4E;\n}\n\n.rtl .pollbar5 {\n	border-left-color: #D11A4E;\n}\n\n/* Poster profile block\n----------------------------------------*/\n.postprofile {\n	color: #666666;\n	border-left-color: #FFFFFF;\n}\n\n.rtl .postprofile {\n	border-right-color: #FFFFFF;\n	border-left-color: transparent;\n}\n\n.pm .postprofile {\n	border-left-color: #DDDDDD;\n}\n\n.rtl .pm .postprofile {\n	border-right-color: #DDDDDD;\n	border-left-color: transparent;\n}\n\n.postprofile strong {\n	color: #000000;\n}\n\n.online {\n	background-image: url(\"{T_IMAGESET_LANG_PATH}/icon_user_online.gif\");\n}\n\n/*  	\n--------------------------------------------------------------\nColours and backgrounds for buttons.css\n-------------------------------------------------------------- */\n\n/* Big button images */\n.reply-icon span	{ background-image: url(\"{IMG_BUTTON_TOPIC_REPLY_SRC}\"); }\n.post-icon span		{ background-image: url(\"{IMG_BUTTON_TOPIC_NEW_SRC}\"); }\n.locked-icon span	{ background-image: url(\"{IMG_BUTTON_TOPIC_LOCKED_SRC}\"); }\n.pmreply-icon span	{ background-image: url(\"{IMG_BUTTON_PM_REPLY_SRC}\") ;}\n.newpm-icon span 	{ background-image: url(\"{IMG_BUTTON_PM_NEW_SRC}\") ;}\n.forwardpm-icon span	{ background-image: url(\"{IMG_BUTTON_PM_FORWARD_SRC}\") ;}\n\na.print {\n	background-image: url(\"{T_THEME_PATH}/images/icon_print.gif\");\n}\n\na.sendemail {\n	background-image: url(\"{T_THEME_PATH}/images/icon_sendemail.gif\");\n}\n\na.fontsize {\n	background-image: url(\"{T_THEME_PATH}/images/icon_fontsize.gif\");\n}\n\n/* Icon images\n---------------------------------------- */\n.sitehome						{ background-image: url(\"{T_THEME_PATH}/images/icon_home.gif\"); }\n.icon-faq						{ background-image: url(\"{T_THEME_PATH}/images/icon_faq.gif\"); }\n.icon-members					{ background-image: url(\"{T_THEME_PATH}/images/icon_members.gif\"); }\n.icon-home						{ background-image: url(\"{T_THEME_PATH}/images/icon_home.gif\"); }\n.icon-ucp						{ background-image: url(\"{T_THEME_PATH}/images/icon_ucp.gif\"); }\n.icon-register					{ background-image: url(\"{T_THEME_PATH}/images/icon_register.gif\"); }\n.icon-logout					{ background-image: url(\"{T_THEME_PATH}/images/icon_logout.gif\"); }\n.icon-bookmark					{ background-image: url(\"{T_THEME_PATH}/images/icon_bookmark.gif\"); }\n.icon-bump						{ background-image: url(\"{T_THEME_PATH}/images/icon_bump.gif\"); }\n.icon-subscribe					{ background-image: url(\"{T_THEME_PATH}/images/icon_subscribe.gif\"); }\n.icon-unsubscribe				{ background-image: url(\"{T_THEME_PATH}/images/icon_unsubscribe.gif\"); }\n.icon-pages						{ background-image: url(\"{T_THEME_PATH}/images/icon_pages.gif\"); }\n.icon-search					{ background-image: url(\"{T_THEME_PATH}/images/icon_search.gif\"); }\n\n/* Profile & navigation icons */\n.email-icon, .email-icon a		{ background-image: url(\"{IMG_ICON_CONTACT_EMAIL_SRC}\"); }\n.aim-icon, .aim-icon a			{ background-image: url(\"{IMG_ICON_CONTACT_AIM_SRC}\"); }\n.yahoo-icon, .yahoo-icon a		{ background-image: url(\"{IMG_ICON_CONTACT_YAHOO_SRC}\"); }\n.web-icon, .web-icon a			{ background-image: url(\"{IMG_ICON_CONTACT_WWW_SRC}\"); }\n.msnm-icon, .msnm-icon a			{ background-image: url(\"{IMG_ICON_CONTACT_MSNM_SRC}\"); }\n.icq-icon, .icq-icon a			{ background-image: url(\"{IMG_ICON_CONTACT_ICQ_SRC}\"); }\n.jabber-icon, .jabber-icon a		{ background-image: url(\"{IMG_ICON_CONTACT_JABBER_SRC}\"); }\n.pm-icon, .pm-icon a				{ background-image: url(\"{IMG_ICON_CONTACT_PM_SRC}\"); }\n.quote-icon, .quote-icon a		{ background-image: url(\"{IMG_ICON_POST_QUOTE_SRC}\"); }\n\n/* Moderator icons */\n.report-icon, .report-icon a		{ background-image: url(\"{IMG_ICON_POST_REPORT_SRC}\"); }\n.edit-icon, .edit-icon a			{ background-image: url(\"{IMG_ICON_POST_EDIT_SRC}\"); }\n.delete-icon, .delete-icon a		{ background-image: url(\"{IMG_ICON_POST_DELETE_SRC}\"); }\n.info-icon, .info-icon a			{ background-image: url(\"{IMG_ICON_POST_INFO_SRC}\"); }\n.warn-icon, .warn-icon a			{ background-image: url(\"{IMG_ICON_USER_WARN_SRC}\"); } /* Need updated warn icon */\n\n/*  	\n--------------------------------------------------------------\nColours and backgrounds for cp.css\n-------------------------------------------------------------- */\n\n/* Main CP box\n----------------------------------------*/\n\n#cp-main h3, #cp-main hr, #cp-menu hr {\n	border-color: #A4B3BF;\n}\n\n#cp-main .panel li.row {\n	border-bottom-color: #B5C1CB;\n	border-top-color: #F9F9F9;\n}\n\nul.cplist {\n	border-top-color: #B5C1CB;\n}\n\n#cp-main .panel li.header dd, #cp-main .panel li.header dt {\n	color: #000000;\n}\n\n#cp-main table.table1 thead th {\n	color: #333333;\n	border-bottom-color: #333333;\n}\n\n#cp-main .pm-message {\n	border-color: #DBDEE2;\n	background-color: #FFFFFF;\n}\n\n/* CP tabbed menu\n----------------------------------------*/\n#tabs a {\n	background-image: url(\"{T_THEME_PATH}/images/bg_tabs1.gif\");\n}\n\n#tabs a span {\n	background-image: url(\"{T_THEME_PATH}/images/bg_tabs2.gif\");\n	color: #536482;\n}\n\n#tabs a:hover span {\n	color: #BC2A4D;\n}\n\n#tabs .activetab a {\n	border-bottom-color: #CADCEB;\n}\n\n#tabs .activetab a span {\n	color: #333333;\n}\n\n#tabs .activetab a:hover span {\n	color: #000000;\n}\n\n/* Mini tabbed menu used in MCP\n----------------------------------------*/\n#minitabs li {\n	background-color: #E1EBF2;\n}\n\n#minitabs li.activetab {\n	background-color: #F9F9F9;\n}\n\n#minitabs li.activetab a, #minitabs li.activetab a:hover {\n	color: #333333;\n}\n\n/* UCP navigation menu\n----------------------------------------*/\n\n/* Link styles for the sub-section links */\n#navigation a {\n	color: #333;\n	background-color: #B2C2CF;\n	background-image: url(\"{T_THEME_PATH}/images/bg_menu.gif\");\n}\n\n#navigation a:hover {\n	background-color: #aabac6;\n	color: #BC2A4D;\n}\n\n#navigation #active-subsection a {\n	color: #D31141;\n	background-color: #F9F9F9;\n	background-image: none;\n}\n\n#navigation #active-subsection a:hover {\n	color: #D31141;\n}\n\n/* Preferences pane layout\n----------------------------------------*/\n#cp-main h2 {\n	color: #333333;\n}\n\n#cp-main .panel {\n	background-color: #F9F9F9;\n}\n\n#cp-main .pm {\n	background-color: #FFFFFF;\n}\n\n#cp-main span.corners-top, #cp-menu span.corners-top {\n	background-image: url(\"{T_THEME_PATH}/images/corners_left2.gif\");\n}\n\n#cp-main span.corners-top span, #cp-menu span.corners-top span {\n	background-image: url(\"{T_THEME_PATH}/images/corners_right2.gif\");\n}\n\n#cp-main span.corners-bottom, #cp-menu span.corners-bottom {\n	background-image: url(\"{T_THEME_PATH}/images/corners_left2.gif\");\n}\n\n#cp-main span.corners-bottom span, #cp-menu span.corners-bottom span {\n	background-image: url(\"{T_THEME_PATH}/images/corners_right2.gif\");\n}\n\n/* Topicreview */\n#cp-main .panel #topicreview span.corners-top, #cp-menu .panel #topicreview span.corners-top {\n	background-image: url(\"{T_THEME_PATH}/images/corners_left.gif\");\n}\n\n#cp-main .panel #topicreview span.corners-top span, #cp-menu .panel #topicreview span.corners-top span {\n	background-image: url(\"{T_THEME_PATH}/images/corners_right.gif\");\n}\n\n#cp-main .panel #topicreview span.corners-bottom, #cp-menu .panel #topicreview span.corners-bottom {\n	background-image: url(\"{T_THEME_PATH}/images/corners_left.gif\");\n}\n\n#cp-main .panel #topicreview span.corners-bottom span, #cp-menu .panel #topicreview span.corners-bottom span {\n	background-image: url(\"{T_THEME_PATH}/images/corners_right.gif\");\n}\n\n/* Friends list */\n.cp-mini {\n	background-color: #eef5f9;\n}\n\ndl.mini dt {\n	color: #425067;\n}\n\n/* PM Styles\n----------------------------------------*/\n/* PM Message history */\n.current {\n	color: #999999 !important;\n}\n\n/* PM marking colours */\n.pmlist li.pm_message_reported_colour, .pm_message_reported_colour {\n	border-left-color: #BC2A4D;\n	border-right-color: #BC2A4D;\n}\n\n.pmlist li.pm_marked_colour, .pm_marked_colour {\n	border-color: #FF6600;\n}\n\n.pmlist li.pm_replied_colour, .pm_replied_colour {\n	border-color: #A9B8C2;\n}\n\n.pmlist li.pm_friend_colour, .pm_friend_colour {\n	border-color: #5D8FBD;\n}\n\npmlist li.pm_foe_colour, .pm_foe_colour {\n	border-color: #000000;\n}\n\n/* Avatar gallery */\n#gallery label {\n	background-color: #FFFFFF;\n	border-color: #CCC;\n}\n\n#gallery label:hover {\n	background-color: #EEE;\n}\n\n/*  	\n--------------------------------------------------------------\nColours and backgrounds for forms.css\n-------------------------------------------------------------- */\n\n/* General form styles\n----------------------------------------*/\nselect {\n	border-color: #666666;\n	background-color: #FAFAFA;\n}\n\nlabel {\n	color: #425067;\n}\n\noption.disabled-option {\n	color: graytext;\n}\n\n/* Definition list layout for forms\n---------------------------------------- */\ndd label {\n	color: #333;\n}\n\n/* Hover effects */\nfieldset dl:hover dt label {\n	color: #000000;\n}\n\nfieldset.fields2 dl:hover dt label {\n	color: inherit;\n}\n\n/* Quick-login on index page */\nfieldset.quick-login input.inputbox {\n	background-color: #F2F3F3;\n}\n\n/* Posting page styles\n----------------------------------------*/\n\n#message-box textarea {\n	color: #333333;\n}\n\n/* Input field styles\n---------------------------------------- */\n.inputbox {\n	background-color: #FFFFFF; \n	border-color: #B4BAC0;\n	color: #333333;\n}\n\n.inputbox:hover {\n	border-color: #11A3EA;\n}\n\n.inputbox:focus {\n	border-color: #11A3EA;\n	color: #0F4987;\n}\n\n/* Form button styles\n---------------------------------------- */\n\na.button1, input.button1, input.button3, a.button2, input.button2 {\n	color: #000;\n	background-color: #FAFAFA;\n	background-image: url(\"{T_THEME_PATH}/images/bg_button.gif\");\n}\n\na.button1, input.button1 {\n	border-color: #666666;\n}\n\ninput.button3 {\n	background-image: none;\n}\n\n/* Alternative button */\na.button2, input.button2, input.button3 {\n	border-color: #666666;\n}\n\n/* <a> button in the style of the form buttons */\na.button1, a.button1:link, a.button1:visited, a.button1:active, a.button2, a.button2:link, a.button2:visited, a.button2:active {\n	color: #000000;\n}\n\n/* Hover states */\na.button1:hover, input.button1:hover, a.button2:hover, input.button2:hover, input.button3:hover {\n	border-color: #BC2A4D;\n	color: #BC2A4D;\n}\n\ninput.search {\n	background-image: url(\"{T_THEME_PATH}/images/icon_textbox_search.gif\");\n}\n\ninput.disabled {\n	color: #666666;\n}\n');

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_topics
#

DROP TABLE IF EXISTS `phpbb_topics`;
CREATE TABLE `phpbb_topics` (
  `topic_id` mediumint(8) unsigned NOT NULL auto_increment,
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `icon_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_attachment` tinyint(1) unsigned NOT NULL default '0',
  `topic_approved` tinyint(1) unsigned NOT NULL default '1',
  `topic_reported` tinyint(1) unsigned NOT NULL default '0',
  `topic_title` varchar(100) character set utf8 collate utf8_unicode_ci NOT NULL default '',
  `topic_poster` mediumint(8) unsigned NOT NULL default '0',
  `topic_time` int(11) unsigned NOT NULL default '0',
  `topic_time_limit` int(11) unsigned NOT NULL default '0',
  `topic_views` mediumint(8) unsigned NOT NULL default '0',
  `topic_replies` mediumint(8) unsigned NOT NULL default '0',
  `topic_replies_real` mediumint(8) unsigned NOT NULL default '0',
  `topic_status` tinyint(3) NOT NULL default '0',
  `topic_type` tinyint(3) NOT NULL default '0',
  `topic_first_post_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_first_poster_name` varchar(255) collate utf8_bin NOT NULL default '',
  `topic_first_poster_colour` varchar(6) collate utf8_bin NOT NULL default '',
  `topic_last_post_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_last_poster_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_last_poster_name` varchar(255) collate utf8_bin NOT NULL default '',
  `topic_last_poster_colour` varchar(6) collate utf8_bin NOT NULL default '',
  `topic_last_post_subject` varchar(100) collate utf8_bin NOT NULL default '',
  `topic_last_post_time` int(11) unsigned NOT NULL default '0',
  `topic_last_view_time` int(11) unsigned NOT NULL default '0',
  `topic_moved_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_bumped` tinyint(1) unsigned NOT NULL default '0',
  `topic_bumper` mediumint(8) unsigned NOT NULL default '0',
  `poll_title` varchar(255) collate utf8_bin NOT NULL default '',
  `poll_start` int(11) unsigned NOT NULL default '0',
  `poll_length` int(11) unsigned NOT NULL default '0',
  `poll_max_options` tinyint(4) NOT NULL default '1',
  `poll_last_vote` int(11) unsigned NOT NULL default '0',
  `poll_vote_change` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`topic_id`),
  KEY `forum_id` (`forum_id`),
  KEY `forum_id_type` (`forum_id`,`topic_type`),
  KEY `last_post_time` (`topic_last_post_time`),
  KEY `topic_approved` (`topic_approved`),
  KEY `forum_appr_last` (`forum_id`,`topic_approved`,`topic_last_post_id`),
  KEY `fid_time_moved` (`forum_id`,`topic_last_post_time`,`topic_moved_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_topics
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_topics_posted
#

DROP TABLE IF EXISTS `phpbb_topics_posted`;
CREATE TABLE `phpbb_topics_posted` (
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_posted` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`user_id`,`topic_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_topics_posted
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_topics_posted` VALUES (2,1,1);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_topics_track
#

DROP TABLE IF EXISTS `phpbb_topics_track`;
CREATE TABLE `phpbb_topics_track` (
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `topic_id` mediumint(8) unsigned NOT NULL default '0',
  `forum_id` mediumint(8) unsigned NOT NULL default '0',
  `mark_time` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`user_id`,`topic_id`),
  KEY `forum_id` (`forum_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_topics_track
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_topics_watch
#

DROP TABLE IF EXISTS `phpbb_topics_watch`;
CREATE TABLE `phpbb_topics_watch` (
  `topic_id` mediumint(8) unsigned NOT NULL default '0',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `notify_status` tinyint(1) unsigned NOT NULL default '0',
  KEY `topic_id` (`topic_id`),
  KEY `user_id` (`user_id`),
  KEY `notify_stat` (`notify_status`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_topics_watch
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_user_group
#

DROP TABLE IF EXISTS `phpbb_user_group`;
CREATE TABLE `phpbb_user_group` (
  `group_id` mediumint(8) unsigned NOT NULL default '0',
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `group_leader` tinyint(1) unsigned NOT NULL default '0',
  `user_pending` tinyint(1) unsigned NOT NULL default '1',
  KEY `group_id` (`group_id`),
  KEY `user_id` (`user_id`),
  KEY `group_leader` (`group_leader`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_user_group
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_user_group` VALUES (1,1,0,0);
INSERT INTO `phpbb_user_group` VALUES (2,2,0,0);
INSERT INTO `phpbb_user_group` VALUES (4,2,0,0);
INSERT INTO `phpbb_user_group` VALUES (5,2,1,0);
INSERT INTO `phpbb_user_group` VALUES (6,3,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,4,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,5,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,6,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,7,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,8,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,9,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,10,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,11,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,12,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,13,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,14,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,15,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,16,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,17,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,18,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,19,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,20,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,21,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,22,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,23,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,24,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,25,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,26,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,27,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,28,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,29,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,30,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,31,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,32,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,33,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,34,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,35,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,36,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,37,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,38,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,39,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,40,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,41,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,42,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,43,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,44,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,45,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,46,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,47,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,48,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,49,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,50,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,51,0,0);
INSERT INTO `phpbb_user_group` VALUES (6,52,0,0);

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_users
#

DROP TABLE IF EXISTS `phpbb_users`;
CREATE TABLE `phpbb_users` (
  `user_id` mediumint(8) unsigned NOT NULL auto_increment,
  `user_type` tinyint(2) NOT NULL default '0',
  `group_id` mediumint(8) unsigned NOT NULL default '3',
  `user_permissions` mediumtext collate utf8_bin NOT NULL,
  `user_perm_from` mediumint(8) unsigned NOT NULL default '0',
  `user_ip` varchar(40) collate utf8_bin NOT NULL default '',
  `user_regdate` int(11) unsigned NOT NULL default '0',
  `username` varchar(255) collate utf8_bin NOT NULL default '',
  `username_clean` varchar(255) collate utf8_bin NOT NULL default '',
  `user_password` varchar(40) collate utf8_bin NOT NULL default '',
  `user_passchg` int(11) unsigned NOT NULL default '0',
  `user_pass_convert` tinyint(1) unsigned NOT NULL default '0',
  `user_email` varchar(100) collate utf8_bin NOT NULL default '',
  `user_email_hash` bigint(20) NOT NULL default '0',
  `user_birthday` varchar(10) collate utf8_bin NOT NULL default '',
  `user_lastvisit` int(11) unsigned NOT NULL default '0',
  `user_lastmark` int(11) unsigned NOT NULL default '0',
  `user_lastpost_time` int(11) unsigned NOT NULL default '0',
  `user_lastpage` varchar(200) collate utf8_bin NOT NULL default '',
  `user_last_confirm_key` varchar(10) collate utf8_bin NOT NULL default '',
  `user_last_search` int(11) unsigned NOT NULL default '0',
  `user_warnings` tinyint(4) NOT NULL default '0',
  `user_last_warning` int(11) unsigned NOT NULL default '0',
  `user_login_attempts` tinyint(4) NOT NULL default '0',
  `user_inactive_reason` tinyint(2) NOT NULL default '0',
  `user_inactive_time` int(11) unsigned NOT NULL default '0',
  `user_posts` mediumint(8) unsigned NOT NULL default '0',
  `user_lang` varchar(30) collate utf8_bin NOT NULL default '',
  `user_timezone` decimal(5,2) NOT NULL default '0.00',
  `user_dst` tinyint(1) unsigned NOT NULL default '0',
  `user_dateformat` varchar(30) collate utf8_bin NOT NULL default 'd M Y H:i',
  `user_style` smallint(4) unsigned NOT NULL default '0',
  `user_rank` mediumint(8) unsigned NOT NULL default '0',
  `user_colour` varchar(6) collate utf8_bin NOT NULL default '',
  `user_new_privmsg` int(4) NOT NULL default '0',
  `user_unread_privmsg` int(4) NOT NULL default '0',
  `user_last_privmsg` int(11) unsigned NOT NULL default '0',
  `user_message_rules` tinyint(1) unsigned NOT NULL default '0',
  `user_full_folder` int(11) NOT NULL default '-3',
  `user_emailtime` int(11) unsigned NOT NULL default '0',
  `user_topic_show_days` smallint(4) unsigned NOT NULL default '0',
  `user_topic_sortby_type` varchar(1) collate utf8_bin NOT NULL default 't',
  `user_topic_sortby_dir` varchar(1) collate utf8_bin NOT NULL default 'd',
  `user_post_show_days` smallint(4) unsigned NOT NULL default '0',
  `user_post_sortby_type` varchar(1) collate utf8_bin NOT NULL default 't',
  `user_post_sortby_dir` varchar(1) collate utf8_bin NOT NULL default 'a',
  `user_notify` tinyint(1) unsigned NOT NULL default '0',
  `user_notify_pm` tinyint(1) unsigned NOT NULL default '1',
  `user_notify_type` tinyint(4) NOT NULL default '0',
  `user_allow_pm` tinyint(1) unsigned NOT NULL default '1',
  `user_allow_viewonline` tinyint(1) unsigned NOT NULL default '1',
  `user_allow_viewemail` tinyint(1) unsigned NOT NULL default '1',
  `user_allow_massemail` tinyint(1) unsigned NOT NULL default '1',
  `user_options` int(11) unsigned NOT NULL default '895',
  `user_avatar` varchar(255) collate utf8_bin NOT NULL default '',
  `user_avatar_type` tinyint(2) NOT NULL default '0',
  `user_avatar_width` smallint(4) unsigned NOT NULL default '0',
  `user_avatar_height` smallint(4) unsigned NOT NULL default '0',
  `user_sig` mediumtext collate utf8_bin NOT NULL,
  `user_sig_bbcode_uid` varchar(8) collate utf8_bin NOT NULL default '',
  `user_sig_bbcode_bitfield` varchar(255) collate utf8_bin NOT NULL default '',
  `user_from` varchar(100) collate utf8_bin NOT NULL default '',
  `user_icq` varchar(15) collate utf8_bin NOT NULL default '',
  `user_aim` varchar(255) collate utf8_bin NOT NULL default '',
  `user_yim` varchar(255) collate utf8_bin NOT NULL default '',
  `user_msnm` varchar(255) collate utf8_bin NOT NULL default '',
  `user_jabber` varchar(255) collate utf8_bin NOT NULL default '',
  `user_website` varchar(200) collate utf8_bin NOT NULL default '',
  `user_occ` text collate utf8_bin NOT NULL,
  `user_interests` text collate utf8_bin NOT NULL,
  `user_actkey` varchar(32) collate utf8_bin NOT NULL default '',
  `user_newpasswd` varchar(40) collate utf8_bin NOT NULL default '',
  `user_form_salt` varchar(32) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`user_id`),
  UNIQUE KEY `username_clean` (`username_clean`),
  KEY `user_birthday` (`user_birthday`),
  KEY `user_email_hash` (`user_email_hash`),
  KEY `user_type` (`user_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_users
#

/*!40101 SET NAMES utf8 */;

INSERT INTO `phpbb_users` VALUES (1,2,1,'',0,'',1213196049,'Anonymous','anonymous','',0,0,'',0,'',0,0,0,'','',0,0,0,0,0,0,0,'en',0,0,'d M Y H:i',1,0,'',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','d85e4240f22608e6');
INSERT INTO `phpbb_users` VALUES (2,3,5,'zik0zjzik0zjzik0w0\n\n\nziimf2000000\nziimf2000000\nziimf2000000\nziimf2000000\nziimf2000000\nziimf2000000',0,'84.53.238.18',1213196049,'admin','admin','$H$9k4lnKdk9/0YwjJffY4n7REPZrpZN2.',0,0,'mikes@solovatsoft.com',145124878121,'',0,0,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,1,'AA0000',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,1,895,'',0,0,0,'','','','','','','','','','','','','','','4dda0eda5a5597ce');
INSERT INTO `phpbb_users` VALUES (3,2,6,'',0,'',1213196054,'AdsBot [Google]','adsbot [google]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','0d33efd8f6258650');
INSERT INTO `phpbb_users` VALUES (4,2,6,'',0,'',1213196054,'Alexa [Bot]','alexa [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','5109a00f44426172');
INSERT INTO `phpbb_users` VALUES (5,2,6,'',0,'',1213196054,'Alta Vista [Bot]','alta vista [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','b19f06e9465f2926');
INSERT INTO `phpbb_users` VALUES (6,2,6,'',0,'',1213196054,'Ask Jeeves [Bot]','ask jeeves [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','1abaac35363c0057');
INSERT INTO `phpbb_users` VALUES (7,2,6,'',0,'',1213196054,'Baidu [Spider]','baidu [spider]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','379c65a4fd470eef');
INSERT INTO `phpbb_users` VALUES (8,2,6,'',0,'',1213196054,'Exabot [Bot]','exabot [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','394fe9a96c091567');
INSERT INTO `phpbb_users` VALUES (9,2,6,'',0,'',1213196054,'FAST Enterprise [Crawler]','fast enterprise [crawler]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','6418ae3b559567d6');
INSERT INTO `phpbb_users` VALUES (10,2,6,'',0,'',1213196054,'FAST WebCrawler [Crawler]','fast webcrawler [crawler]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','5b8ac11b11c7f9c9');
INSERT INTO `phpbb_users` VALUES (11,2,6,'',0,'',1213196054,'Francis [Bot]','francis [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','8ca6f17c0b049fed');
INSERT INTO `phpbb_users` VALUES (12,2,6,'',0,'',1213196054,'Gigabot [Bot]','gigabot [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','443f9cb0bedd5fc1');
INSERT INTO `phpbb_users` VALUES (13,2,6,'',0,'',1213196054,'Google Adsense [Bot]','google adsense [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','0bce27f9c5279309');
INSERT INTO `phpbb_users` VALUES (14,2,6,'',0,'',1213196054,'Google Desktop','google desktop','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','2e8a1ab4c9b4c3c6');
INSERT INTO `phpbb_users` VALUES (15,2,6,'',0,'',1213196054,'Google Feedfetcher','google feedfetcher','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','cbc1661125c64625');
INSERT INTO `phpbb_users` VALUES (16,2,6,'',0,'',1213196054,'Google [Bot]','google [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','3e9888b43a0f35fd');
INSERT INTO `phpbb_users` VALUES (17,2,6,'',0,'',1213196054,'Heise IT-Markt [Crawler]','heise it-markt [crawler]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','d27fb43c336e60d5');
INSERT INTO `phpbb_users` VALUES (18,2,6,'',0,'',1213196054,'Heritrix [Crawler]','heritrix [crawler]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','306aca0d75832cb9');
INSERT INTO `phpbb_users` VALUES (19,2,6,'',0,'',1213196054,'IBM Research [Bot]','ibm research [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','b7588a23e19c4b75');
INSERT INTO `phpbb_users` VALUES (20,2,6,'',0,'',1213196054,'ICCrawler - ICjobs','iccrawler - icjobs','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','d8f616569a77870d');
INSERT INTO `phpbb_users` VALUES (21,2,6,'',0,'',1213196054,'ichiro [Crawler]','ichiro [crawler]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','e5e65647bcb2d6cb');
INSERT INTO `phpbb_users` VALUES (22,2,6,'',0,'',1213196054,'Majestic-12 [Bot]','majestic-12 [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','6e54d97f38a7466a');
INSERT INTO `phpbb_users` VALUES (23,2,6,'',0,'',1213196054,'Metager [Bot]','metager [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','0a3958f81340c138');
INSERT INTO `phpbb_users` VALUES (24,2,6,'',0,'',1213196054,'MSN NewsBlogs','msn newsblogs','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','5f9210989231ee39');
INSERT INTO `phpbb_users` VALUES (25,2,6,'',0,'',1213196054,'MSN [Bot]','msn [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','01eb5dea40452bb2');
INSERT INTO `phpbb_users` VALUES (26,2,6,'',0,'',1213196054,'MSNbot Media','msnbot media','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','860dcdc283679471');
INSERT INTO `phpbb_users` VALUES (27,2,6,'',0,'',1213196054,'NG-Search [Bot]','ng-search [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','3ce3b99ad861bc9c');
INSERT INTO `phpbb_users` VALUES (28,2,6,'',0,'',1213196054,'Nutch [Bot]','nutch [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','86fd79ef9b58b1f9');
INSERT INTO `phpbb_users` VALUES (29,2,6,'',0,'',1213196054,'Nutch/CVS [Bot]','nutch/cvs [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','3bbd5fa76bbf0d0b');
INSERT INTO `phpbb_users` VALUES (30,2,6,'',0,'',1213196054,'OmniExplorer [Bot]','omniexplorer [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','8481f0e2e9be3a51');
INSERT INTO `phpbb_users` VALUES (31,2,6,'',0,'',1213196054,'Online link [Validator]','online link [validator]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','425a56fafc6b0d15');
INSERT INTO `phpbb_users` VALUES (32,2,6,'',0,'',1213196054,'psbot [Picsearch]','psbot [picsearch]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','df23abc02d28ff86');
INSERT INTO `phpbb_users` VALUES (33,2,6,'',0,'',1213196054,'Seekport [Bot]','seekport [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','6e0bdcc4f07202f0');
INSERT INTO `phpbb_users` VALUES (34,2,6,'',0,'',1213196054,'Sensis [Crawler]','sensis [crawler]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','fffb6dc14cd2ef16');
INSERT INTO `phpbb_users` VALUES (35,2,6,'',0,'',1213196054,'SEO Crawler','seo crawler','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','7281ef5f53471e47');
INSERT INTO `phpbb_users` VALUES (36,2,6,'',0,'',1213196054,'Seoma [Crawler]','seoma [crawler]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','ae2a583250e22053');
INSERT INTO `phpbb_users` VALUES (37,2,6,'',0,'',1213196054,'SEOSearch [Crawler]','seosearch [crawler]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','3d85cb5dfd7c5e78');
INSERT INTO `phpbb_users` VALUES (38,2,6,'',0,'',1213196054,'Snappy [Bot]','snappy [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','db4567c9bf198198');
INSERT INTO `phpbb_users` VALUES (39,2,6,'',0,'',1213196054,'Steeler [Crawler]','steeler [crawler]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','c0239bee99789216');
INSERT INTO `phpbb_users` VALUES (40,2,6,'',0,'',1213196054,'Synoo [Bot]','synoo [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','dfbaa58a6cd6012b');
INSERT INTO `phpbb_users` VALUES (41,2,6,'',0,'',1213196054,'Telekom [Bot]','telekom [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','2bc56c9f9a981005');
INSERT INTO `phpbb_users` VALUES (42,2,6,'',0,'',1213196054,'TurnitinBot [Bot]','turnitinbot [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','682affc6c79f4a99');
INSERT INTO `phpbb_users` VALUES (43,2,6,'',0,'',1213196054,'Voyager [Bot]','voyager [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','9661f2071ef4524e');
INSERT INTO `phpbb_users` VALUES (44,2,6,'',0,'',1213196054,'W3 [Sitesearch]','w3 [sitesearch]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','3d17b45f1ed63280');
INSERT INTO `phpbb_users` VALUES (45,2,6,'',0,'',1213196054,'W3C [Linkcheck]','w3c [linkcheck]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','bb462472c1c730ed');
INSERT INTO `phpbb_users` VALUES (46,2,6,'',0,'',1213196054,'W3C [Validator]','w3c [validator]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','ef0f97a571078513');
INSERT INTO `phpbb_users` VALUES (47,2,6,'',0,'',1213196054,'WiseNut [Bot]','wisenut [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','7740b915d33d1020');
INSERT INTO `phpbb_users` VALUES (48,2,6,'',0,'',1213196054,'YaCy [Bot]','yacy [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','39cd9802d19b17ec');
INSERT INTO `phpbb_users` VALUES (49,2,6,'',0,'',1213196054,'Yahoo MMCrawler [Bot]','yahoo mmcrawler [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','0583fbd15db6a9fb');
INSERT INTO `phpbb_users` VALUES (50,2,6,'',0,'',1213196054,'Yahoo Slurp [Bot]','yahoo slurp [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','bccc046376176fc1');
INSERT INTO `phpbb_users` VALUES (51,2,6,'',0,'',1213196054,'Yahoo [Bot]','yahoo [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','b20dec55a910e5b5');
INSERT INTO `phpbb_users` VALUES (52,2,6,'',0,'',1213196054,'YahooSeeker [Bot]','yahooseeker [bot]','',1213196054,0,'',0,'',0,1213196054,0,'','',0,0,0,0,0,0,0,'en',0,0,'D M d, Y g:i a',1,0,'9E8DA7',0,0,0,0,-3,0,0,'t','d',0,'t','a',0,1,0,1,1,1,0,895,'',0,0,0,'','','','','','','','','','','','','','','cbe313fa6a862cb6');

/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_warnings
#

DROP TABLE IF EXISTS `phpbb_warnings`;
CREATE TABLE `phpbb_warnings` (
  `warning_id` mediumint(8) unsigned NOT NULL auto_increment,
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `post_id` mediumint(8) unsigned NOT NULL default '0',
  `log_id` mediumint(8) unsigned NOT NULL default '0',
  `warning_time` int(11) unsigned NOT NULL default '0',
  PRIMARY KEY  (`warning_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_warnings
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_words
#

DROP TABLE IF EXISTS `phpbb_words`;
CREATE TABLE `phpbb_words` (
  `word_id` mediumint(8) unsigned NOT NULL auto_increment,
  `word` varchar(255) collate utf8_bin NOT NULL default '',
  `replacement` varchar(255) collate utf8_bin NOT NULL default '',
  PRIMARY KEY  (`word_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_words
#

/*!40101 SET NAMES utf8 */;


/*!40101 SET NAMES utf8 */;


#
# Table structure for table phpbb_zebra
#

DROP TABLE IF EXISTS `phpbb_zebra`;
CREATE TABLE `phpbb_zebra` (
  `user_id` mediumint(8) unsigned NOT NULL default '0',
  `zebra_id` mediumint(8) unsigned NOT NULL default '0',
  `friend` tinyint(1) unsigned NOT NULL default '0',
  `foe` tinyint(1) unsigned NOT NULL default '0',
  PRIMARY KEY  (`user_id`,`zebra_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_bin;

#
# Dumping data for table phpbb_zebra
#
/*!40101 SET NAMES utf8 */;


#
# Table structure for table userblock
#

DROP TABLE IF EXISTS `userblock`;
CREATE TABLE `userblock` (
  `UserBlockID` int(11) NOT NULL auto_increment,
  `UserBlockType` int(11) NOT NULL default '0',
  `UserBlockPattern` varchar(255) default NULL,
  `UserBlockResources` int(11) NOT NULL default '0',
  PRIMARY KEY  (`UserBlockID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

#
# Table structure for table videoalbum
#

DROP TABLE IF EXISTS `videoalbum`;
CREATE TABLE `videoalbum` (
  `VideoAlbumID` int(11) NOT NULL auto_increment,
  `GroupID` int(11) default NULL,
  `UserID` int(11) default NULL,
  `OrganizationID` int(11) default NULL,
  `CommunityID` int(11) default NULL,
  `VideoAlbumName` varchar(128) NOT NULL,
  `VideoAlbumDescription` varchar(255) default NULL,
  `VideoAlbumPrivacy` int(11) default NULL,
  PRIMARY KEY  (`VideoAlbumID`),
  KEY `FK_VideoAlbumToGroup` (`GroupID`),
  KEY `FK_VideoAlbumToOrganization` (`OrganizationID`),
  KEY `FK_ComminutyToVideoAlbum` (`CommunityID`),
  KEY `FK_UserToVideoAlbum` (`UserID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

#
# Dumping data for table videoalbum
#

INSERT INTO `additionalstorage` VALUES (1,1,'2',10,2);
INSERT INTO `additionalstorage` VALUES (2,2,'3',20,2);
INSERT INTO `additionalstorage` VALUES (3,3,'4',30,2);
INSERT INTO `additionalstorage` VALUES (4,4,'5',40,2);
INSERT INTO `additionalstorage` VALUES (5,5,'Unlimited',70,2);


insert into country set CountryID = 1, CountryCode = 'AF', CountryName = 'Afghanistan';
insert into country set CountryID = 2, CountryCode = 'AL', CountryName = 'Albania';
insert into country set CountryID = 3, CountryCode = 'DZ', CountryName = 'Algeria';
insert into country set CountryID = 4, CountryCode = 'AS', CountryName = 'American Samoa';
insert into country set CountryID = 5, CountryCode = 'AD', CountryName = 'Andorra';
insert into country set CountryID = 6, CountryCode = 'AO', CountryName = 'Angola';
insert into country set CountryID = 7, CountryCode = 'AI', CountryName = 'Anguilla';
insert into country set CountryID = 8, CountryCode = 'AQ', CountryName = 'Antarctica';
insert into country set CountryID = 9, CountryCode = 'AG', CountryName = 'Antigua and Barbuda';
insert into country set CountryID = 10, CountryCode = 'AR', CountryName = 'Argentina';
insert into country set CountryID = 11, CountryCode = 'AM', CountryName = 'Armenia';
insert into country set CountryID = 12, CountryCode = 'AW', CountryName = 'Aruba';
insert into country set CountryID = 13, CountryCode = 'AU', CountryName = 'Australia';
insert into country set CountryID = 14, CountryCode = 'AT', CountryName = 'Austria';
insert into country set CountryID = 15, CountryCode = 'AZ', CountryName = 'Azerbaijan';
insert into country set CountryID = 16, CountryCode = 'BS', CountryName = 'Bahamas';
insert into country set CountryID = 17, CountryCode = 'BH', CountryName = 'Bahrain';
insert into country set CountryID = 18, CountryCode = 'BD', CountryName = 'Bangladesh';
insert into country set CountryID = 19, CountryCode = 'BB', CountryName = 'Barbados';
insert into country set CountryID = 20, CountryCode = 'BY', CountryName = 'Belarus';
insert into country set CountryID = 21, CountryCode = 'BE', CountryName = 'Belgium';
insert into country set CountryID = 22, CountryCode = 'BZ', CountryName = 'Belize';
insert into country set CountryID = 23, CountryCode = 'BJ', CountryName = 'Benin';
insert into country set CountryID = 24, CountryCode = 'BM', CountryName = 'Bermuda';
insert into country set CountryID = 25, CountryCode = 'BT', CountryName = 'Bhutan';
insert into country set CountryID = 26, CountryCode = 'BO', CountryName = 'Bolivia';
insert into country set CountryID = 27, CountryCode = 'BA', CountryName = 'Bosnia and Herzegovina';
insert into country set CountryID = 28, CountryCode = 'BW', CountryName = 'Botswana';
insert into country set CountryID = 29, CountryCode = 'BV', CountryName = 'Bouvet Island';
insert into country set CountryID = 30, CountryCode = 'BR', CountryName = 'Brazil';
insert into country set CountryID = 31, CountryCode = 'IO', CountryName = 'British Indian Ocean Territory';
insert into country set CountryID = 32, CountryCode = 'BN', CountryName = 'Brunei Darussalam';
insert into country set CountryID = 33, CountryCode = 'BG', CountryName = 'Bulgaria';
insert into country set CountryID = 34, CountryCode = 'BF', CountryName = 'Burkina Faso';
insert into country set CountryID = 35, CountryCode = 'BU', CountryName = 'Burma';
insert into country set CountryID = 36, CountryCode = 'BI', CountryName = 'Burundi';
insert into country set CountryID = 37, CountryCode = 'KH', CountryName = 'Cambodia';
insert into country set CountryID = 38, CountryCode = 'CM', CountryName = 'Cameroon';
insert into country set CountryID = 39, CountryCode = 'CA', CountryName = 'Canada';
insert into country set CountryID = 40, CountryCode = 'CV', CountryName = 'Cape Verde';
insert into country set CountryID = 41, CountryCode = 'KY', CountryName = 'Cayman Islands';
insert into country set CountryID = 42, CountryCode = 'CF', CountryName = 'Central African Republic';
insert into country set CountryID = 43, CountryCode = 'TD', CountryName = 'Chad';
insert into country set CountryID = 44, CountryCode = 'CL', CountryName = 'Chile';
insert into country set CountryID = 45, CountryCode = 'CN', CountryName = 'China';
insert into country set CountryID = 46, CountryCode = 'CX', CountryName = 'Christmas Island';
insert into country set CountryID = 47, CountryCode = 'CC', CountryName = 'Cocos (Keeling Islands)';
insert into country set CountryID = 48, CountryCode = 'CO', CountryName = 'Colombia';
insert into country set CountryID = 49, CountryCode = 'KM', CountryName = 'Comoros';
insert into country set CountryID = 50, CountryCode = 'CG', CountryName = 'Congo';
insert into country set CountryID = 51, CountryCode = 'CK', CountryName = 'Cook Islands';
insert into country set CountryID = 52, CountryCode = 'CR', CountryName = 'Costa Rica';
insert into country set CountryID = 53, CountryCode = 'CI', CountryName = 'Cote D\'Ivoire (Ivory Coast)';
insert into country set CountryID = 54, CountryCode = 'HR', CountryName = 'Croatia (Hrvatska)';
insert into country set CountryID = 55, CountryCode = 'CU', CountryName = 'Cuba';
insert into country set CountryID = 56, CountryCode = 'CY', CountryName = 'Cyprus';
insert into country set CountryID = 57, CountryCode = 'CZ', CountryName = 'Czech Republic';
insert into country set CountryID = 58, CountryCode = 'ZR', CountryName = 'Democratic Republic of Congo';
insert into country set CountryID = 59, CountryCode = 'DK', CountryName = 'Denmark';
insert into country set CountryID = 60, CountryCode = 'DJ', CountryName = 'Djibouti';
insert into country set CountryID = 61, CountryCode = 'DM', CountryName = 'Dominica';
insert into country set CountryID = 62, CountryCode = 'DO', CountryName = 'Dominican Republic';
insert into country set CountryID = 63, CountryCode = 'TP', CountryName = 'East Timor';
insert into country set CountryID = 64, CountryCode = 'EC', CountryName = 'Ecuador';
insert into country set CountryID = 65, CountryCode = 'EG', CountryName = 'Egypt';
insert into country set CountryID = 66, CountryCode = 'SV', CountryName = 'El Salvador';
insert into country set CountryID = 67, CountryCode = 'GQ', CountryName = 'Equatorial Guinea';
insert into country set CountryID = 68, CountryCode = 'ER', CountryName = 'Eritrea';
insert into country set CountryID = 69, CountryCode = 'EE', CountryName = 'Estonia';
insert into country set CountryID = 70, CountryCode = 'ET', CountryName = 'Ethiopia';
insert into country set CountryID = 71, CountryCode = 'FK', CountryName = 'Falkland Islands (Malvinas)';
insert into country set CountryID = 72, CountryCode = 'FO', CountryName = 'Faroe Islands';
insert into country set CountryID = 73, CountryCode = 'FJ', CountryName = 'Fiji';
insert into country set CountryID = 74, CountryCode = 'FI', CountryName = 'Finland';
insert into country set CountryID = 75, CountryCode = 'FR', CountryName = 'France';
insert into country set CountryID = 76, CountryCode = 'GF', CountryName = 'French Guiana';
insert into country set CountryID = 77, CountryCode = 'PF', CountryName = 'French Polynesia';
insert into country set CountryID = 78, CountryCode = 'TF', CountryName = 'French Southern Territories';
insert into country set CountryID = 79, CountryCode = 'GA', CountryName = 'Gabon';
insert into country set CountryID = 80, CountryCode = 'GM', CountryName = 'Gambia';
insert into country set CountryID = 81, CountryCode = 'GE', CountryName = 'Georgia';
insert into country set CountryID = 82, CountryCode = 'DE', CountryName = 'Germany';
insert into country set CountryID = 83, CountryCode = 'GH', CountryName = 'Ghana';
insert into country set CountryID = 84, CountryCode = 'GI', CountryName = 'Gibraltar';
insert into country set CountryID = 85, CountryCode = 'GR', CountryName = 'Greece';
insert into country set CountryID = 86, CountryCode = 'GL', CountryName = 'Greenland';
insert into country set CountryID = 87, CountryCode = 'GD', CountryName = 'Grenada';
insert into country set CountryID = 88, CountryCode = 'GP', CountryName = 'Guadeloupe';
insert into country set CountryID = 89, CountryCode = 'GU', CountryName = 'Guam';
insert into country set CountryID = 90, CountryCode = 'GT', CountryName = 'Guatemala';
insert into country set CountryID = 91, CountryCode = 'GN', CountryName = 'Guinea';
insert into country set CountryID = 92, CountryCode = 'GW', CountryName = 'Guinea-Bissau';
insert into country set CountryID = 93, CountryCode = 'GY', CountryName = 'Guyana';
insert into country set CountryID = 94, CountryCode = 'HT', CountryName = 'Haiti';
insert into country set CountryID = 95, CountryCode = 'HM', CountryName = 'Heard and McDonald Islands';
insert into country set CountryID = 96, CountryCode = 'HN', CountryName = 'Honduras';
insert into country set CountryID = 97, CountryCode = 'HK', CountryName = 'Hong Kong';
insert into country set CountryID = 98, CountryCode = 'HU', CountryName = 'Hungary';
insert into country set CountryID = 99, CountryCode = 'IS', CountryName = 'Iceland';
insert into country set CountryID = 100, CountryCode = 'IN', CountryName = 'India';
insert into country set CountryID = 101, CountryCode = 'ID', CountryName = 'Indonesia';
insert into country set CountryID = 102, CountryCode = 'IR', CountryName = 'Iran';
insert into country set CountryID = 103, CountryCode = 'IQ', CountryName = 'Iraq';
insert into country set CountryID = 104, CountryCode = 'IE', CountryName = 'Ireland';
insert into country set CountryID = 105, CountryCode = 'IL', CountryName = 'Israel';
insert into country set CountryID = 106, CountryCode = 'IT', CountryName = 'Italy';
insert into country set CountryID = 107, CountryCode = 'JM', CountryName = 'Jamaica';
insert into country set CountryID = 108, CountryCode = 'JP', CountryName = 'Japan';
insert into country set CountryID = 109, CountryCode = 'JO', CountryName = 'Jordan';
insert into country set CountryID = 110, CountryCode = 'KZ', CountryName = 'Kazakhstan';
insert into country set CountryID = 111, CountryCode = 'KE', CountryName = 'Kenya';
insert into country set CountryID = 112, CountryCode = 'KI', CountryName = 'Kiribati';
insert into country set CountryID = 113, CountryCode = 'KP', CountryName = 'Korea (North)';
insert into country set CountryID = 114, CountryCode = 'KR', CountryName = 'Korea (South)';
insert into country set CountryID = 115, CountryCode = 'KW', CountryName = 'Kuwait';
insert into country set CountryID = 116, CountryCode = 'KG', CountryName = 'Kyrgyzstan';
insert into country set CountryID = 117, CountryCode = 'LA', CountryName = 'Laos';
insert into country set CountryID = 118, CountryCode = 'LV', CountryName = 'Latvia';
insert into country set CountryID = 119, CountryCode = 'LB', CountryName = 'Lebanon';
insert into country set CountryID = 120, CountryCode = 'LS', CountryName = 'Lesotho';
insert into country set CountryID = 121, CountryCode = 'LR', CountryName = 'Liberia';
insert into country set CountryID = 122, CountryCode = 'LY', CountryName = 'Libya';
insert into country set CountryID = 123, CountryCode = 'LI', CountryName = 'Liechtenstein';
insert into country set CountryID = 124, CountryCode = 'LT', CountryName = 'Lithuania';
insert into country set CountryID = 125, CountryCode = 'LU', CountryName = 'Luxembourg';
insert into country set CountryID = 126, CountryCode = 'MO', CountryName = 'Macau';
insert into country set CountryID = 127, CountryCode = 'MK', CountryName = 'Macedonia';
insert into country set CountryID = 128, CountryCode = 'MG', CountryName = 'Madagascar';
insert into country set CountryID = 129, CountryCode = 'MW', CountryName = 'Malawi';
insert into country set CountryID = 130, CountryCode = 'MY', CountryName = 'Malaysia';
insert into country set CountryID = 131, CountryCode = 'MV', CountryName = 'Maldives';
insert into country set CountryID = 132, CountryCode = 'ML', CountryName = 'Mali';
insert into country set CountryID = 133, CountryCode = 'MT', CountryName = 'Malta';
insert into country set CountryID = 134, CountryCode = 'MH', CountryName = 'Marshall Islands';
insert into country set CountryID = 135, CountryCode = 'MQ', CountryName = 'Martinique';
insert into country set CountryID = 136, CountryCode = 'MR', CountryName = 'Mauritania';
insert into country set CountryID = 137, CountryCode = 'MU', CountryName = 'Mauritius';
insert into country set CountryID = 138, CountryCode = 'YT', CountryName = 'Mayotte';
insert into country set CountryID = 139, CountryCode = 'MX', CountryName = 'Mexico';
insert into country set CountryID = 140, CountryCode = 'FM', CountryName = 'Micronesia';
insert into country set CountryID = 141, CountryCode = 'MD', CountryName = 'Moldova';
insert into country set CountryID = 142, CountryCode = 'MC', CountryName = 'Monaco';
insert into country set CountryID = 143, CountryCode = 'MN', CountryName = 'Mongolia';
insert into country set CountryID = 144, CountryCode = 'MS', CountryName = 'Montserrat';
insert into country set CountryID = 145, CountryCode = 'MA', CountryName = 'Morocco';
insert into country set CountryID = 146, CountryCode = 'MZ', CountryName = 'Mozambique';
insert into country set CountryID = 147, CountryCode = 'MM', CountryName = 'Myanmar';
insert into country set CountryID = 148, CountryCode = 'NA', CountryName = 'Namibia';
insert into country set CountryID = 149, CountryCode = 'NR', CountryName = 'Nauru';
insert into country set CountryID = 150, CountryCode = 'NP', CountryName = 'Nepal';
insert into country set CountryID = 151, CountryCode = 'NL', CountryName = 'Netherlands';
insert into country set CountryID = 152, CountryCode = 'AN', CountryName = 'Netherlands Antilles';
insert into country set CountryID = 153, CountryCode = 'NT', CountryName = 'Neutral Zone';
insert into country set CountryID = 154, CountryCode = 'NC', CountryName = 'New Caledonia';
insert into country set CountryID = 155, CountryCode = 'NZ', CountryName = 'New Zealand (Aotearoa)';
insert into country set CountryID = 156, CountryCode = 'NI', CountryName = 'Nicaragua';
insert into country set CountryID = 157, CountryCode = 'NE', CountryName = 'Niger';
insert into country set CountryID = 158, CountryCode = 'NG', CountryName = 'Nigeria';
insert into country set CountryID = 159, CountryCode = 'NU', CountryName = 'Niue';
insert into country set CountryID = 160, CountryCode = 'NF', CountryName = 'Norfolk Island';
insert into country set CountryID = 161, CountryCode = 'MP', CountryName = 'Northern Mariana Islands';
insert into country set CountryID = 162, CountryCode = 'NO', CountryName = 'Norway';
insert into country set CountryID = 163, CountryCode = 'OM', CountryName = 'Oman';
insert into country set CountryID = 164, CountryCode = 'PK', CountryName = 'Pakistan';
insert into country set CountryID = 165, CountryCode = 'PW', CountryName = 'Palau';
insert into country set CountryID = 166, CountryCode = 'PA', CountryName = 'Panama';
insert into country set CountryID = 167, CountryCode = 'PG', CountryName = 'Papua New Guinea';
insert into country set CountryID = 168, CountryCode = 'PY', CountryName = 'Paraguay';
insert into country set CountryID = 169, CountryCode = 'PE', CountryName = 'Peru';
insert into country set CountryID = 170, CountryCode = 'PH', CountryName = 'Philippines';
insert into country set CountryID = 171, CountryCode = 'PN', CountryName = 'Pitcairn';
insert into country set CountryID = 172, CountryCode = 'PL', CountryName = 'Poland';
insert into country set CountryID = 173, CountryCode = 'PT', CountryName = 'Portugal';
insert into country set CountryID = 174, CountryCode = 'PR', CountryName = 'Puerto Rico';
insert into country set CountryID = 175, CountryCode = 'QA', CountryName = 'Qatar';
insert into country set CountryID = 176, CountryCode = 'RE', CountryName = 'Reunion';
insert into country set CountryID = 177, CountryCode = 'RO', CountryName = 'Romania';
insert into country set CountryID = 178, CountryCode = 'RU', CountryName = 'Russian Federation';
insert into country set CountryID = 179, CountryCode = 'RW', CountryName = 'Rwanda';
insert into country set CountryID = 180, CountryCode = 'GS', CountryName = 'S. Georgia and S. Sandwich Isls.';
insert into country set CountryID = 181, CountryCode = 'KN', CountryName = 'Saint Kitts and Nevis';
insert into country set CountryID = 182, CountryCode = 'LC', CountryName = 'Saint Lucia';
insert into country set CountryID = 183, CountryCode = 'VC', CountryName = 'Saint Vincent and the Grenadines';
insert into country set CountryID = 184, CountryCode = 'WS', CountryName = 'Samoa';
insert into country set CountryID = 185, CountryCode = 'SM', CountryName = 'San Marino';
insert into country set CountryID = 186, CountryCode = 'ST', CountryName = 'Sao Tome and Principe';
insert into country set CountryID = 187, CountryCode = 'SA', CountryName = 'Saudi Arabia';
insert into country set CountryID = 188, CountryCode = 'SN', CountryName = 'Senegal';
insert into country set CountryID = 189, CountryCode = 'CS', CountryName = 'Serbia & Montenegro';
insert into country set CountryID = 190, CountryCode = 'SC', CountryName = 'Seychelles';
insert into country set CountryID = 191, CountryCode = 'SL', CountryName = 'Sierra Leone';
insert into country set CountryID = 192, CountryCode = 'SG', CountryName = 'Singapore';
insert into country set CountryID = 193, CountryCode = 'SK', CountryName = 'Slovak Republic';
insert into country set CountryID = 194, CountryCode = 'SI', CountryName = 'Slovenia';
insert into country set CountryID = 195, CountryCode = 'Sb', CountryName = 'Solomon Islands';
insert into country set CountryID = 196, CountryCode = 'SO', CountryName = 'Somalia';
insert into country set CountryID = 197, CountryCode = 'ZA', CountryName = 'South Africa';
insert into country set CountryID = 198, CountryCode = 'ES', CountryName = 'Spain';
insert into country set CountryID = 199, CountryCode = 'LK', CountryName = 'Sri Lanka';
insert into country set CountryID = 200, CountryCode = 'SH', CountryName = 'St. Helena';
insert into country set CountryID = 201, CountryCode = 'PM', CountryName = 'St. Pierre and Miquelon';
insert into country set CountryID = 202, CountryCode = 'SD', CountryName = 'Sudan';
insert into country set CountryID = 203, CountryCode = 'SR', CountryName = 'Suriname';
insert into country set CountryID = 204, CountryCode = 'SJ', CountryName = 'Svalbard and Jan Mayen Islands';
insert into country set CountryID = 205, CountryCode = 'SZ', CountryName = 'Swaziland';
insert into country set CountryID = 206, CountryCode = 'SE', CountryName = 'Sweden';
insert into country set CountryID = 207, CountryCode = 'CH', CountryName = 'Switzerland';
insert into country set CountryID = 208, CountryCode = 'SY', CountryName = 'Syria';
insert into country set CountryID = 209, CountryCode = 'TW', CountryName = 'Taiwan';
insert into country set CountryID = 210, CountryCode = 'TJ', CountryName = 'Tajikistan';
insert into country set CountryID = 211, CountryCode = 'TZ', CountryName = 'Tanzania';
insert into country set CountryID = 212, CountryCode = 'TH', CountryName = 'Thailand';
insert into country set CountryID = 213, CountryCode = 'TG', CountryName = 'Togo';
insert into country set CountryID = 214, CountryCode = 'TK', CountryName = 'Tokelau';
insert into country set CountryID = 215, CountryCode = 'TO', CountryName = 'Tonga';
insert into country set CountryID = 216, CountryCode = 'TT', CountryName = 'Trinidad and Tobago';
insert into country set CountryID = 217, CountryCode = 'TN', CountryName = 'Tunisia';
insert into country set CountryID = 218, CountryCode = 'TR', CountryName = 'Turkey';
insert into country set CountryID = 219, CountryCode = 'TM', CountryName = 'Turkmenistan';
insert into country set CountryID = 220, CountryCode = 'TC', CountryName = 'Turks and Caicos Islands';
insert into country set CountryID = 221, CountryCode = 'TV', CountryName = 'Tuvalu';
insert into country set CountryID = 222, CountryCode = 'UM', CountryName = 'US Minor Outlying Islands';
insert into country set CountryID = 223, CountryCode = 'UG', CountryName = 'Uganda';
insert into country set CountryID = 224, CountryCode = 'UA', CountryName = 'Ukraine';
insert into country set CountryID = 225, CountryCode = 'AE', CountryName = 'United Arab Emirates';
insert into country set CountryID = 226, CountryCode = 'GB', CountryName = 'United Kingdom';
insert into country set CountryID = 227, CountryCode = 'US', CountryName = 'United States';
insert into country set CountryID = 228, CountryCode = 'UY', CountryName = 'Uruguay';
insert into country set CountryID = 229, CountryCode = 'UZ', CountryName = 'Uzbekistan';
insert into country set CountryID = 230, CountryCode = 'VU', CountryName = 'Vanuatu';
insert into country set CountryID = 231, CountryCode = 'VA', CountryName = 'Vatican City';
insert into country set CountryID = 232, CountryCode = 'VE', CountryName = 'Venezuela';
insert into country set CountryID = 233, CountryCode = 'VN', CountryName = 'Vietnam';
insert into country set CountryID = 234, CountryCode = 'VG', CountryName = 'Virgin Islands (British)';
insert into country set CountryID = 235, CountryCode = 'VI', CountryName = 'Virgin Islands (U.S.)';
insert into country set CountryID = 236, CountryCode = 'WF', CountryName = 'Wallis and Futuna Islands';
insert into country set CountryID = 237, CountryCode = 'EH', CountryName = 'Western Sahara';
insert into country set CountryID = 238, CountryCode = 'YE', CountryName = 'Yemen';
insert into country set CountryID = 239, CountryCode = 'ZM', CountryName = 'Zambia';
insert into country set CountryID = 240, CountryCode = 'ZW', CountryName = 'Zimbabwe';
insert into `state` set StateCode = 'AL', StateName = 'Alabama', CountryID = 227;
insert into `state` set StateCode = 'AK', StateName = 'Alaska', CountryID = 227;
insert into `state` set StateCode = 'AZ', StateName = 'Arizona', CountryID = 227;
insert into `state` set StateCode = 'AR', StateName = 'Arkansas', CountryID = 227;
insert into `state` set StateCode = 'CA', StateName = 'California', CountryID = 227;
insert into `state` set StateCode = 'CO', StateName = 'Colorado', CountryID = 227;
insert into `state` set StateCode = 'CT', StateName = 'Connecticut', CountryID = 227;
insert into `state` set StateCode = 'DE', StateName = 'Delaware', CountryID = 227;
insert into `state` set StateCode = 'FL', StateName = 'Florida', CountryID = 227;
insert into `state` set StateCode = 'GA', StateName = 'Georgia', CountryID = 227;
insert into `state` set StateCode = 'HI', StateName = 'Hawaii', CountryID = 227;
insert into `state` set StateCode = 'ID', StateName = 'Idaho', CountryID = 227;
insert into `state` set StateCode = 'IL', StateName = 'Illinois', CountryID = 227;
insert into `state` set StateCode = 'IN', StateName = 'Indiana', CountryID = 227;
insert into `state` set StateCode = 'IA', StateName = 'Iowa', CountryID = 227;
insert into `state` set StateCode = 'KS', StateName = 'Kansas', CountryID = 227;
insert into `state` set StateCode = 'KY', StateName = 'Kentucky', CountryID = 227;
insert into `state` set StateCode = 'LA', StateName = 'Louisiana', CountryID = 227;
insert into `state` set StateCode = 'ME', StateName = 'Maine', CountryID = 227;
insert into `state` set StateCode = 'MD', StateName = 'Maryland', CountryID = 227;
insert into `state` set StateCode = 'MA', StateName = 'Massachusetts', CountryID = 227;
insert into `state` set StateCode = 'MI', StateName = 'Michigan', CountryID = 227;
insert into `state` set StateCode = 'MN', StateName = 'Minnesota', CountryID = 227;
insert into `state` set StateCode = 'MS', StateName = 'Mississippi', CountryID = 227;
insert into `state` set StateCode = 'MO', StateName = 'Missouri', CountryID = 227;
insert into `state` set StateCode = 'MT', StateName = 'Montana', CountryID = 227;
insert into `state` set StateCode = 'NE', StateName = 'Nebraska', CountryID = 227;
insert into `state` set StateCode = 'NV', StateName = 'Nevada', CountryID = 227;
insert into `state` set StateCode = 'NH', StateName = 'New Hampshire', CountryID = 227;
insert into `state` set StateCode = 'NJ', StateName = 'New Jersey', CountryID = 227;
insert into `state` set StateCode = 'NM', StateName = 'New Mexico', CountryID = 227;
insert into `state` set StateCode = 'NY', StateName = 'New York', CountryID = 227;
insert into `state` set StateCode = 'NC', StateName = 'North Carolina', CountryID = 227;
insert into `state` set StateCode = 'ND', StateName = 'North Dakota', CountryID = 227;
insert into `state` set StateCode = 'OH', StateName = 'Ohio', CountryID = 227;
insert into `state` set StateCode = 'OK', StateName = 'Oklahoma', CountryID = 227;
insert into `state` set StateCode = 'OR', StateName = 'Oregon', CountryID = 227;
insert into `state` set StateCode = 'PA', StateName = 'Pennsylvania', CountryID = 227;
insert into `state` set StateCode = 'RI', StateName = 'Rhode Island', CountryID = 227;
insert into `state` set StateCode = 'SC', StateName = 'South Carolina', CountryID = 227;
insert into `state` set StateCode = 'SD', StateName = 'South Dakota', CountryID = 227;
insert into `state` set StateCode = 'TN', StateName = 'Tenessee', CountryID = 227;
insert into `state` set StateCode = 'TX', StateName = 'Texas', CountryID = 227;
insert into `state` set StateCode = 'UT', StateName = 'Utah', CountryID = 227;
insert into `state` set StateCode = 'VT', StateName = 'Vermont', CountryID = 227;
insert into `state` set StateCode = 'VA', StateName = 'Virginia', CountryID = 227;
insert into `state` set StateCode = 'WA', StateName = 'Washington', CountryID = 227;
insert into `state` set StateCode = 'WV', StateName = 'West Virginia', CountryID = 227;
insert into `state` set StateCode = 'WI', StateName = 'Wisconsin', CountryID = 227;
insert into `state` set StateCode = 'WY', StateName = 'Wyoming', CountryID = 227;
insert into `state` set StateCode = 'AB', StateName = 'Alberta', CountryID = 39;
insert into `state` set StateCode = 'BC', StateName = 'British Columbia', CountryID = 39;
insert into `state` set StateCode = 'MB', StateName = 'Manitoba', CountryID = 39;
insert into `state` set StateCode = 'NB', StateName = 'New Brunswick', CountryID = 39;
insert into `state` set StateCode = 'NF', StateName = 'Newfoundland and Labrador', CountryID = 39;
insert into `state` set StateCode = 'NWT', StateName = 'Northwest Territories', CountryID = 39;
insert into `state` set StateCode = 'NS', StateName = 'Nova Scotia', CountryID = 39;
insert into `state` set StateCode = 'NU', StateName = 'Nunavut', CountryID = 39;
insert into `state` set StateCode = 'ON', StateName = 'Ontario', CountryID = 39;
insert into `state` set StateCode = 'PE', StateName = 'Prince Edward Island', CountryID = 39;
insert into `state` set StateCode = 'PQ', StateName = 'Quebec', CountryID = 39;
insert into `state` set StateCode = 'SK', StateName = 'Saskatchewan', CountryID = 39;
insert into `state` set StateCode = 'YT', StateName = 'Yukon', CountryID = 39;
